<?php

namespace App\Http\Controllers;

use App\AdminOtherAccount;
use App\AdminReceiptVoucher;
use App\AdminSalesInvoice;
use App\Company;
use App\Customer;
use App\Expense;
use App\ReceiptVoucherExpense;
use App\SaleInvoice;
use App\StaffAndSalesman;
use App\Supplier;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use App\Permission;
use App\Branches;
use App\AdminPeriodClosing;

class AdminReceiptVoucherController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $receipts = AdminReceiptVoucher::with('expense.account')
        ->whereIn('id', function ($query) {
            $query->selectRaw('MIN(id)')
                ->from('admin_receipt_vouchers')
                ->where('branch_id', session()->get('selected_branch'))
                    ->whereNotNull('invoice_no')
                    ->groupBy('invoice_no');
        })
        ->withTrashed()
        ->orderBy('invoice_no', 'desc')->get();


        return view('crusher.trans_receipt_voucher.index', compact('receipts'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        // Retrieve permission titles from Permission table
        $permissionTitles = Permission::where('branch_id', session()->get('selected_branch'))->pluck('name')->toArray();

        // Filter permission titles using hasBranchPermission function
        $filteredPermissionTitles = [];
        $branchId = session()->get('selected_branch');
        foreach ($permissionTitles as $permissionTitle) {
            if (Branches::hasBranchPermission($branchId, $permissionTitle)) {
                $filteredPermissionTitles[] = $permissionTitle;
            }
        }

        $salesInvoices = AdminSalesInvoice::where('branch_id', session()->get('selected_branch'))->groupBy('invoice_no')->get();
        // dd($salesInvoices);
        $currentDate = Carbon::now()->format('Ymd');

        // Get the latest quotation number for the branch
        $latestReceipts = AdminReceiptVoucher::withTrashed()->where('branch_id', session()->get('selected_branch'))
            ->latest('invoice_no')->first();

        // Calculate the new quotation number
        if ($latestReceipts) {
            $lastReceipt = (int)substr($latestReceipts->invoice_no, -4); // Extract the last 4 digits
            $newNumber = $lastReceipt + 1;
            $newReceipt = str_pad($newNumber, 4, '0', STR_PAD_LEFT);
        } else {
            $newReceipt = '0001';
        }


        // // Retrieve customers and include both 'account_name' and 'table_name' attributes
        // $customers = Customer::where('branch_id', session()->get('selected_branch'))
        // ->whereIn('name_of_organisation', $filteredPermissionTitles)
        // ->select('*', 'name_of_organisation as account_name')
        // ->get()
        // ->map(function ($item) {
        //     return $item->setAttribute('table_name', 'App\Customer');
        // });

        // // Retrieve suppliers and include both 'account_name' and 'table_name' attributes
        // $suppliers = Supplier::where('branch_id', session()->get('selected_branch'))
        // ->whereIn('name_of_organisation', $filteredPermissionTitles)
        // ->select('*', 'name_of_organisation as account_name')
        // ->get()
        // ->map(function ($item) {
        //     return $item->setAttribute('table_name', 'App\Supplier');
        // });

        // // Retrieve expenses and set 'table_name' to the fully-qualified model class name
        // $salesmens = StaffAndSalesman::where('branch_id', session()->get('selected_branch'))
        // ->whereIn(DB::raw("CONCAT(first_name, ' ', last_name)"), $filteredPermissionTitles)
        // ->select('*', DB::raw("CONCAT(first_name, ' ', last_name) as account_name"))
        // ->get()
        // ->map(function ($item) {
        //     return $item->setAttribute('table_name', 'App\StaffAndSalesman');
        // });

        // // Retrieve expenses and set 'table_name' to the fully-qualified model class name
        // $expenses = Expense::where('branch_id', session()->get('selected_branch'))
        // ->whereIn('account_name', $filteredPermissionTitles)
        // ->get()
        // ->map(function ($item) {
        //     return $item->setAttribute('table_name', 'App\Expense');
        // });

        // // Retrieve other accounts and set 'table_name' to the fully-qualified model class name
        // $otherAccounts = AdminOtherAccount::where('branch_id', session()->get('selected_branch'))
        // ->whereIn('account_name', $filteredPermissionTitles)
        // ->get()
        // ->map(function ($item) {
        //     return $item->setAttribute('table_name', 'App\AdminOtherAccount');
        // });

        $customers = Customer::where('branch_id', session()->get('selected_branch'))
        ->whereIn(DB::raw("REPLACE(name_of_organisation, ' ', '-')"), $filteredPermissionTitles)
        ->select('*', DB::raw("(name_of_organisation) as account_name"))
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\Customer');
        });

        $suppliers = Supplier::where('branch_id', session()->get('selected_branch'))
        ->whereIn(DB::raw("REPLACE(name_of_organisation, ' ', '-')"), $filteredPermissionTitles)
        ->select('*', DB::raw("(name_of_organisation) as account_name"))
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\Supplier');
        });

        $salesmens = StaffAndSalesman::where('branch_id', session()->get('selected_branch'))
        ->whereIn(DB::raw("CONCAT(REPLACE(first_name, ' ', '-'), '-', REPLACE(last_name, ' ', '-'))"), $filteredPermissionTitles)
        ->select('*', DB::raw("CONCAT(first_name, ' ', last_name) AS account_name"))
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\StaffAndSalesman');
        });

        $expenses = Expense::where('branch_id', session()->get('selected_branch'))
        ->whereIn(DB::raw("REPLACE(account_name, ' ', '-')"), $filteredPermissionTitles)
        ->select('*', DB::raw("(account_name)"))
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\Expense');
        });

        $otherAccounts = AdminOtherAccount::where('branch_id', session()->get('selected_branch'))
        ->whereIn(DB::raw("REPLACE(account_name, ' ', '-')"), $filteredPermissionTitles)
        ->select('*', DB::raw("(account_name)"))
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\AdminOtherAccount');
        });

        // Concatenate all collections into a single collection
        $accounts = $customers->concat($expenses)->concat($suppliers)->concat($otherAccounts)->concat($salesmens);

        $expense = Expense::where(['branch_id' => session()->get('selected_branch'), 'class_of_account_id' => 1]);
        $customer = Customer::where(['branch_id' => session()->get('selected_branch'), 'class_of_account_id' => 1]);
        $Supplier = Supplier::where(['branch_id' => session()->get('selected_branch'), 'class_of_account_id' => 1]);
        $AdminOtherAccount = AdminOtherAccount::where(['branch_id' => session()->get('selected_branch'), 'class_of_account_id' => 1]);
        $staffAndSalesman = StaffAndSalesman::where(['branch_id' => session()->get('selected_branch'), 'class_of_account_id' => 1])
            ->select('*', DB::raw("CONCAT(first_name) as account_name"))
            ->get();


        // Concatenate all Bank accounts collections into a single collection
        $Bankaccounts = $expense->get()->merge($customer->get())->merge($Supplier->get())->merge($AdminOtherAccount->get())->merge($staffAndSalesman);

        $periodClosings = AdminPeriodClosing::where('branch_id', session()->get('selected_branch'))->pluck('to')->toArray();


// dd($Bankaccounts);

        // Concatenate all collections into a single collection
        // $accounts = $customers->concat($expenses)->concat($suppliers)->concat($otherAccounts)->concat($salesmens);

        return view('crusher.trans_receipt_voucher.create', compact('newReceipt', 'customers', 'accounts', 'salesInvoices','Bankaccounts','periodClosings'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        // dd($request);
        $latestNo = AdminReceiptVoucher::withTrashed()->where('branch_id', session()->get('selected_branch'))
        ->latest('invoice_no')->first();

        if ($latestNo) {
        $latestInvoiceNo = $latestNo->invoice_no;

        $latestNumber = (int)preg_replace('/[^0-9]/', '', $latestInvoiceNo);

        $newNumber = $latestNumber + 1;

        $newInvoiceNo = str_pad($newNumber, 4, '0', STR_PAD_LEFT);
        } else {
        $newInvoiceNo = '0001';
        }
        try {
            $validatedData = $request->validate([
                'date' => 'nullable|date',
                // 'invoice_no' => 'nullable|string',
                'payment_method' => 'nullable|in:cash,bank',
                // 'bank_id' => 'nullable|required_if:payment_method,bank|exists:banks,id',
                'bank_id' => 'nullable|nullable:payment_method,bank',
                'cheaque_no' => 'nullable|nullable:payment_method,bank|string',
                'cheaque_date' => 'nullable|nullable:payment_method,bank|date',
                // 'bank_name' => 'nullable|required_if:payment_method,bank|string',
                // 'account_id' => 'nullable|array',
                'account_id' => 'nullable',
                // 'account_type' => 'nullable|array',
                'account_type' => 'nullable',
                'account_name' => 'nullable',
                'amount' => 'nullable|array',
                'amount.*' => 'nullable|numeric',
                'bill_wise_id' => 'nullable|array',
                // 'bill_wise_id.*' => 'nullable|exists:billwise,id',
                'bill_wise_id.*' => 'nullable',
                'inovice_id' => 'nullable|array',
                'inovice_id.*' => 'nullable',
                // 'invoice_id.*' => 'nullable|exists:invoices,id',
                'bank_no' => 'nullable',
                'acc_no' => 'nullable',
                'AmountInWords' => 'nullable',
            ]);

            $branch_id = session()->get('selected_branch');

            $data = [
                'invoice_no' => $newInvoiceNo,
                'date' => $validatedData['date']??(NULL),
                'payment_method' => $validatedData['payment_method']??(NULL),
                'bank_id' => $validatedData['bank_id']??(NULL),
                'cheaque_no' => $validatedData['cheaque_no']??(NULL),
                'cheaque_date' => $validatedData['cheaque_date']??(NULL),
                'account_name' => $validatedData['account_name']??(NULL),
                'account_id' => $validatedData['account_id']??(NULL),
                'bank_no' => $validatedData['bank_no']??(NULL),
                'acc_no' => $validatedData['acc_no']??(NULL),
                'branch_id' => $branch_id,
                'AmountInWords' => $validatedData['AmountInWords']??(NULL),

            ];

                $receiptVoucher = AdminReceiptVoucher::create($data);
            for ($j = 0; $j < count($validatedData['bill_wise_id']); $j++) {
                ReceiptVoucherExpense::create([
                    'invoice_no' => $newInvoiceNo,
                    'receipt_id' => $receiptVoucher->id,
                    'branch_id' => $branch_id,
                    'date' => $validatedData['date']??'',
                    'account_id' => $validatedData['account_id']??'',
                    'account_type' => $validatedData['account_type']??(NULL),
                    'account_name' => $validatedData['account_name']??(NULL),
                    'payment_method' => $validatedData['payment_method'][$j]??(NULL),
                    'amount' => $validatedData['amount'][$j]??(NULL),
                    'bill_wise_id' => $validatedData['bill_wise_id'][$j]??(NULL),
                    'inovice_id' => $validatedData['bill_wise_id'][$j]=='BillWise'?$validatedData['inovice_id'][$j]:(NULL),
                    'bank_no' => $validatedData['bank_no']??(NULL),
                    'acc_no' => $validatedData['acc_no']??(NULL),
                    'AmountInWords' => $validatedData['AmountInWords']??(NULL),
                ]);
            }

            flash()->addSuccess('Record Created');
            return redirect()->route('software.receipt_vouchers.index');
        } catch (\Throwable $th) {
            flash()->addError($th->getMessage());
            return redirect()->back()->withInput();
        }
    }

    public function show($receiptVoucher)
    {
        $receiptVoucher = AdminReceiptVoucher::withTrashed()->find($receiptVoucher);
        $receiptVoucher = $receiptVoucher->withTrashed()->with('expense.account')->where('invoice_no', $receiptVoucher->invoice_no)->where('branch_id', session()->get('selected_branch'))->groupBy('invoice_no')->get();


        $company = Company::where('user_id', auth()->id())->first();
        return view('crusher.trans_receipt_voucher.view', compact('receiptVoucher', 'company'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\AdminReceiptVoucher  $adminReceiptVoucher
     * @return \Illuminate\Http\Response
     */
    public function edit(AdminReceiptVoucher $receiptVoucher)
    {
        // Retrieve permission titles from Permission table
        $permissionTitles = Permission::where('branch_id', session()->get('selected_branch'))->pluck('name')->toArray();

        // Filter permission titles using hasBranchPermission function
        $filteredPermissionTitles = [];
        $branchId = session()->get('selected_branch');
        foreach ($permissionTitles as $permissionTitle) {
            if (Branches::hasBranchPermission($branchId, $permissionTitle)) {
                $filteredPermissionTitles[] = $permissionTitle;
            }
        }

        // // Retrieve customers and include both 'account_name' and 'table_name' attributes
        // $customers = Customer::where('branch_id', session()->get('selected_branch'))
        // ->whereIn('name_of_organisation', $filteredPermissionTitles)
        // ->select('*', 'name_of_organisation as account_name')
        // ->get()
        // ->map(function ($item) {
        //     return $item->setAttribute('table_name', 'App\Customer');
        // });

        // // Retrieve suppliers and include both 'account_name' and 'table_name' attributes
        // $suppliers = Supplier::where('branch_id', session()->get('selected_branch'))
        // ->whereIn('name_of_organisation', $filteredPermissionTitles)
        // ->select('*', 'name_of_organisation as account_name')
        // ->get()
        // ->map(function ($item) {
        //     return $item->setAttribute('table_name', 'App\Supplier');
        // });

        // // Retrieve expenses and set 'table_name' to the fully-qualified model class name
        // $salesmens = StaffAndSalesman::where('branch_id', session()->get('selected_branch'))
        // ->whereIn(DB::raw("CONCAT(first_name, ' ', last_name)"), $filteredPermissionTitles)
        // ->select('*', DB::raw("CONCAT(first_name, ' ', last_name) as account_name"))
        // ->get()
        // ->map(function ($item) {
        //     return $item->setAttribute('table_name', 'App\StaffAndSalesman');
        // });

        // // Retrieve expenses and set 'table_name' to the fully-qualified model class name
        // $expenses = Expense::where('branch_id', session()->get('selected_branch'))
        // ->whereIn('account_name', $filteredPermissionTitles)
        // ->get()
        // ->map(function ($item) {
        //     return $item->setAttribute('table_name', 'App\Expense');
        // });

        // // Retrieve other accounts and set 'table_name' to the fully-qualified model class name
        // $otherAccounts = AdminOtherAccount::where('branch_id', session()->get('selected_branch'))
        // ->whereIn('account_name', $filteredPermissionTitles)
        // ->get()
        // ->map(function ($item) {
        //     return $item->setAttribute('table_name', 'App\AdminOtherAccount');
        // });

        $customers = Customer::where('branch_id', session()->get('selected_branch'))
        ->whereIn(DB::raw("REPLACE(name_of_organisation, ' ', '-')"), $filteredPermissionTitles)
        ->select('*', DB::raw("(name_of_organisation) as account_name"))
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\Customer');
        });

        $suppliers = Supplier::where('branch_id', session()->get('selected_branch'))
        ->whereIn(DB::raw("REPLACE(name_of_organisation, ' ', '-')"), $filteredPermissionTitles)
        ->select('*', DB::raw("(name_of_organisation) as account_name"))
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\Supplier');
        });

        $salesmens = StaffAndSalesman::where('branch_id', session()->get('selected_branch'))
        ->whereIn(DB::raw("CONCAT(REPLACE(first_name, ' ', '-'), '-', REPLACE(last_name, ' ', '-'))"), $filteredPermissionTitles)
        ->select('*', DB::raw("CONCAT(first_name, ' ', last_name) AS account_name"))
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\StaffAndSalesman');
        });

        $expenses = Expense::where('branch_id', session()->get('selected_branch'))
        ->whereIn(DB::raw("REPLACE(account_name, ' ', '-')"), $filteredPermissionTitles)
        ->select('*', DB::raw("(account_name)"))
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\Expense');
        });

        $otherAccounts = AdminOtherAccount::where('branch_id', session()->get('selected_branch'))
        ->whereIn(DB::raw("REPLACE(account_name, ' ', '-')"), $filteredPermissionTitles)
        ->select('*', DB::raw("(account_name)"))
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\AdminOtherAccount');
        });

        $expense = Expense::where(['branch_id' => session()->get('selected_branch'), 'class_of_account_id' => 1]);
        $customer = Customer::where(['branch_id' => session()->get('selected_branch'), 'class_of_account_id' => 1]);
        $Supplier = Supplier::where(['branch_id' => session()->get('selected_branch'), 'class_of_account_id' => 1]);
        $AdminOtherAccount = AdminOtherAccount::where(['branch_id' => session()->get('selected_branch'), 'class_of_account_id' => 1]);
        $staffAndSalesman = StaffAndSalesman::where(['branch_id' => session()->get('selected_branch'), 'class_of_account_id' => 1])
            ->select('*', DB::raw("CONCAT(first_name) as account_name"))
            ->get();

        // Concatenate all Bank accounts collections into a single collection
        $Bankaccounts = $expense->get()->merge($customer->get())->merge($Supplier->get())->merge($AdminOtherAccount->get())->merge($staffAndSalesman);


        // Concatenate all collections into a single collection
        $accounts = $customers->concat($expenses)->concat($suppliers)->concat($otherAccounts)->concat($salesmens);
;
        // $receiptVouchers = $receiptVoucher->with('expense.account')->where('invoice_no', $receiptVoucher->invoice_no)->get();

        $receiptVouchers = AdminReceiptVoucher::where('branch_id', session()->get('selected_branch'))
        ->with('expense.account')
        ->where('invoice_no', $receiptVoucher->invoice_no)
        ->get();


        $salesInvoices = AdminSalesInvoice::where('branch_id', session()->get('selected_branch'))->groupBy('invoice_no')->get();

        $periodClosings = AdminPeriodClosing::where('branch_id', session()->get('selected_branch'))->pluck('to')->toArray();


        return view('crusher.trans_receipt_voucher.edit', compact('accounts', 'receiptVouchers', 'salesInvoices','Bankaccounts','periodClosings'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\AdminReceiptVoucher  $adminReceiptVoucher
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, AdminReceiptVoucher $receiptVoucher)
    {

        // dd($request);
        try {
            $validatedData = $request->validate([
                'date' => 'nullable|date',
                'invoice_no' => 'nullable|string',
                'payment_method' => 'required|in:cash,bank',
                // 'bank_id' => 'nullable|required_if:payment_method,bank|exists:banks,id',
                'bank_id' => 'nullable|nullable:payment_method,bank',
                'cheaque_no' => 'nullable|nullable:payment_method,bank|string',
                'cheaque_date' => 'nullable|nullable:payment_method,bank|date',
                'bank_name' => 'nullable',
                // 'account_id' => 'nullable|array',
                'account_id' => 'nullable',
                // 'account_type' => 'nullable|array',
                'account_type' => 'nullable',
                'account_name' => 'nullable',
                'amount' => 'nullable|array',
                'amount.*' => 'nullable|numeric',
                'bill_wise_id' => 'nullable|array',
                // 'bill_wise_id.*' => 'nullable|exists:billwise,id',
                'bill_wise_id.*' => 'nullable',
                'inovice_id' => 'nullable|array',
                'inovice_id.*' => 'nullable',
                // 'invoice_id.*' => 'nullable|exists:invoices,id',
                'bank_no' => 'nullable',
                'acc_no' => 'nullable',
                'AmountInWords' => 'nullable',
            ]);
            // dd($validatedData);

            $branch_id = session()->get('selected_branch');

            $data = [
                'invoice_no' => $validatedData['invoice_no']??'',
                'date' => $validatedData['date']??'',
                'payment_method' => $validatedData['payment_method']??'',
                'bank_id' => $validatedData['bank_id']??'',
                'bank_no' => $validatedData['bank_no']??'',
                'acc_no' => $validatedData['acc_no']??'',
                'bank_name' => $validatedData['bank_name']??'',
                'cheaque_no' => $validatedData['cheaque_no']??'',
                'cheaque_date' => $validatedData['cheaque_date']??"",
                'account_name' => $validatedData['account_name']??"",
                'account_id' => $validatedData['account_id']??'',
                'AmountInWords' => $validatedData['AmountInWords']??"",
                'branch_id' => $branch_id,
            ];
            $receiptVoucher->with('expense.account')->where('branch_id', session()->get('selected_branch'))->where('invoice_no', $receiptVoucher->invoice_no)->forceDelete();


            $receiptVoucher = AdminReceiptVoucher::create($data);
            ReceiptVoucherExpense::where('branch_id', session()->get('selected_branch'))->where('receipt_id', $receiptVoucher->id)->forceDelete();
            for ($j = 0; $j < count($validatedData['bill_wise_id']); $j++) {
                ReceiptVoucherExpense::create([
                    'receipt_id' => $receiptVoucher->id,
                    'branch_id' => $branch_id,
                    'date' => $validatedData['date']??'',
                    'invoice_no' => $validatedData['invoice_no']??'',
                    'account_id' => $validatedData['account_id']??'',
                    'account_type' => $validatedData['account_type']??'',
                    'account_name' => $validatedData['account_name']??'',
                    'bank_name' => $validatedData['bank_name']??'',
                    'bank_no' => $validatedData['bank_no']??'',
                    'acc_no' => $validatedData['acc_no']??'',
                    'payment_method' => $validatedData['payment_method'][$j]??'',
                    'amount' => $validatedData['amount'][$j]??'',
                    'AmountInWords' => $validatedData['AmountInWords']??(NULL),
                    'bill_wise_id' => $validatedData['bill_wise_id'][$j]??'',
                    'bill_wise_id' => $validatedData['bill_wise_id'][$j]??(NULL),
                    'inovice_id' => $validatedData['bill_wise_id'][$j]=='BillWise'?$validatedData['inovice_id'][$j]:(NULL),
                ]);
            }

            flash()->addSuccess('Record Updated');
            return redirect()->route('software.receipt_vouchers.index');
        } catch (\Throwable $th) {
            flash()->addError($th->getMessage());
            return redirect()->back()->withInput();
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\AdminReceiptVoucher  $adminReceiptVoucher
     * @return \Illuminate\Http\Response
     */
    public function destroy(AdminReceiptVoucher $adminReceiptVoucher)
    {
        //
    }

    public function softDelete($receiptVoucher)
    {
        $receiptVoucher = AdminReceiptVoucher::findOrFail($receiptVoucher);
        $receiptVoucher->where('branch_id', session()->get('selected_branch'))->where('invoice_no', $receiptVoucher->invoice_no)->delete();
        flash()->addSuccess('Success');
        return redirect()->route('software.receipt_vouchers.index');
    }
}
