<?php

namespace App\Http\Controllers;

use App\Branches;
use App\Expense;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Http\Request;
use App\Http\Requests\StoreExpensesRequest;
use App\Http\Requests\UpdateExpensesRequest;
use App\Permission;
use App\BranchPermission;
use App\AssignedPermission;

class ExpensesMasterController extends Controller
{
    use SoftDeletes;

    public function index()
    {
        // $expenses = Expense::where('branch_id', session()->get('selected_branch'))->orderBy('id', 'desc')
        // ->get();

        //   $permissionTitles = Permission::where('branch_id', session()->get('selected_branch'))->pluck('name')->toArray();

        //   $filteredPermissionTitles = [];
        //   $branchId = session()->get('selected_branch');
        //   foreach ($permissionTitles as $permissionTitle) {
        //       if (Branches::hasBranchPermission($branchId, $permissionTitle)) {
        //           $filteredPermissionTitles[] = $permissionTitle;
        //       }
        //   }

        //   $expenses = Expense::where('branch_id', $branchId)
        //       ->whereIn('account_name', $filteredPermissionTitles)
        //       ->orderBy('id', 'desc')
        //       ->get();


        $permissionTitles = Permission::where('branch_id', session()->get('selected_branch'))->pluck('name')->toArray();

        $filteredPermissionTitles = [];
        $branchId = session()->get('selected_branch');
        foreach ($permissionTitles as $permissionTitle) {
            if (Branches::hasBranchPermission($branchId, $permissionTitle)) {
                $filteredPermissionTitles[] = $permissionTitle;
            }
        }

        $expenses = Expense::where('branch_id', $branchId)
            ->orderBy('id', 'desc')
            ->get();

        foreach ($expenses as $expense) {
            $expense->account_name = str_replace(' ', '-', $expense->account_name);
        }

        $filteredExpenses = $expenses->filter(function ($customer) use ($filteredPermissionTitles) {
            return in_array($customer->account_name, $filteredPermissionTitles);
        });

        return view('crusher.expenses_master.index', compact('expenses'));
    }

    public function create()
    {
        return view('crusher.expenses_master.create');
    }

    function store(StoreExpensesRequest $request)
    {
        $masterName = 'expense';
        $latestAccount = Expense::withTrashed()->where('branch_id', session()->get('selected_branch'))
            ->latest('account_no')->first();

        if ($latestAccount) {
            $explodedAccountNo = explode('-', $latestAccount->account_no);
            $lastAccountNumber = end($explodedAccountNo);
            $newAccountNumber = $masterName . '-' . str_pad((int)$lastAccountNumber + 1, 4, '0', STR_PAD_LEFT);
        } else {
            $newAccountNumber = $masterName . '-0001';
        }

        // dd($newAccountNumber);

        try {
            $validatedData = $request->validated();
            $validatedData['branch_id'] = session()->get('selected_branch');
            $validatedData['account_no'] = $newAccountNumber;

            Expense::create($validatedData);

            // use App\Permission;
            // use App\BranchPermission;
            // use App\AssignedPermission;

            // $name = $request->account_name;

            $name = str_replace(' ', '-', $request->account_name);
            $selectedBranchId = session('selected_branch');

            $permission = Permission::create([
                'name' => $name,
                'guard_name' => 'web',
                'type' => 'Ledger Expense',
                'branch_id' => $selectedBranchId,
            ]);

            $BranchPermission = BranchPermission::create([
                'branch_id' => $permission->branch_id,
                'permission_id' => $permission->id,
            ]);

            if (auth()->check() && auth()->user()->role == 'subadmin') {
                $subadminId = auth()->user()->id;

                AssignedPermission::create([
                    'subadmin_id' => $subadminId,
                    'branch_permission_id' => $BranchPermission->id
                ]);
            } else {

            }

            flash()->addSuccess('Record Created');
            return redirect()->route('software.expense.index');
        } catch (\Throwable $th) {
            flash()->addError($th->getMessage());
            return redirect()->back()->withInput();
        }
    }

    public function edit($expense)
    {
        $expense = Expense::find($expense);
        return view('crusher.expenses_master.edit', compact('expense'));
    }

    function update(UpdateExpensesRequest $request, $expense)
    {
        try {
            $validatedData = $request->validated();
            $validatedData['branch_id'] = session()->get('selected_branch');

            Expense::find($expense)->update($validatedData);

            flash()->addSuccess('Record Updated');
            return redirect()->route('software.expense.index');
        } catch (\Throwable $th) {
            flash()->addError($th->getMessage());
            return redirect()->back()->withInput();
        }
    }

    public function show($expense)
    {
        $expense = Expense::find($expense);
        return view('crusher.expenses_master.view', compact('expense'));
    }

    public function softDelete($expense)
    {
        $expense = Expense::findOrFail($expense);
        $expense->delete();
        flash()->addSuccess('Success');
        return redirect()->route('software.expense.index');
    }
}
