<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\AccountMaster;
use App\AccountMastersAccountsDetail;
use App\ClassOfAccount;
use App\Currency;
use App\Http\Controllers\Controller;
use App\PurchaseInvoice;
use App\PurchaseReturnVoucher;
use App\SaleInvoice;
use App\SalesReturnVoucher;
use App\Services\Utils;
use Carbon\Carbon;
use PDF;
use Auth;
use App\Customer;
use App\Expense;
use App\Supplier;
use App\StaffAndSalesman;
use App\AdminOtherAccount;
use App\AdminSalesInvoice;
use App\AdminJournalVoucher;
use App\AdminReceiptVoucher;
use App\ReceiptVoucherExpense;
use App\PaymentVoucherExpense ;
use App\AdminPeriodClosing;
use App\Company;
use App\DeliveryNote;
use App\CreditNote;
use App\DebitNote;
use App\OpeningBalance;
use App\PurchaseOrder;
use App\Quotation;
use App\WarehouseTransfer;
use App\AdminPurchaesInvoice;
use App\AdminPaymentVoucher;
use App\AdminTermsAndCondition;
use Illuminate\Support\Facades\DB;
use App\Services\CashReportService;
use App\Services\VatReportService;
use App\Services\DiscountReportService;

class StatmentOfAccountController extends Controller
{
    protected $discountReportService;
    protected $vatReportService;
    protected $cashReportService;

    public function __construct(VatReportService $vatReportService,CashReportService $cashReportService,DiscountReportService $discountReportService) {
        $this->vatReportService = $vatReportService;
        $this->cashReportService = $cashReportService;
        $this->discountReportService = $discountReportService;

    }


    public function display()
    {
        $user = Auth::user();
        // if (!$user->can('reports.statement_account')) {
        //     //     abort(403, 'Unauthorized action.');
        //     // }

        $accounts = [];

        $customers = Customer::where('branch_id', session()->get('selected_branch'))
            ->select('*', 'name_of_organisation as account_name')
            ->get()
            ->map(function ($item) {
                return $item->setAttribute('table_name', 'App\Customer');
            });

        $salesmens = StaffAndSalesman::where('branch_id', session()->get('selected_branch'))
            ->select('*', DB::raw("CONCAT(first_name, ' ', last_name) as account_name"))
            ->get()
            ->map(function ($item) {
                return $item->setAttribute('table_name', 'App\StaffAndSalesman');
            });

        $suppliers = Supplier::where('branch_id', session()->get('selected_branch'))
            ->select('*', 'name_of_organisation as account_name')
            ->get()
            ->map(function ($item) {
                return $item->setAttribute('table_name', 'App\Supplier');
            });

        $expenses = Expense::where('branch_id', session()->get('selected_branch'))
            ->get()
            ->map(function ($item) {
                return $item->setAttribute('table_name', 'App\Expense');
            });

        $otherAccounts = AdminOtherAccount::where('branch_id', session()->get('selected_branch'))
            ->get()
            ->map(function ($item) {
                return $item->setAttribute('table_name', 'App\AdminOtherAccount');
            });

        $accounts = $customers->concat($expenses)->concat($suppliers)->concat($otherAccounts)->concat($salesmens);

        $class_of_accounts = ClassOfAccount::all();

        $periodClosings = AdminPeriodClosing::where('branch_id', session()->get('selected_branch'))->pluck('to')->toArray();

        // dd($periodClosings);

        return view('crusher.reports.statement_account', compact('accounts', 'class_of_accounts','periodClosings'));
    }


    public function index_class(Request $request)
    {
        // dd($request);

        $from_date = $request->from_date;
        $to_date = $request->to_date;

        $classOfAccountId = $request->class_of_account;

        // dd($classOfAccountId);

        $periodClosingDate = AdminPeriodClosing::latest()->value('to');

        // dd($periodClosingDate);

        if ($classOfAccountId == 6) {
            if ($periodClosingDate && strtotime($periodClosingDate)) {
                $currentYearFirstDate = $periodClosingDate;
                $oneDayPreviousDate = date('Y-m-d', strtotime('-1 day', strtotime($currentYearFirstDate)));

            }
        } else {
            $currentYearFirstDate = "2003-01-01";
            $oneDayPreviousDate = date('Y-m-d', strtotime('-1 day', strtotime($from_date)));
        }

        // $currentYearFirstDate = date("2003-01-01");
        // $oneDayPreviousDate = date('Y-m-d', strtotime('-1 day', strtotime($from_date)));

        // dd($currentYearFirstDate,$oneDayPreviousDate);

        // Vat Report Amount --------------------------------

        list($debitVatReportCB,$creditVatReportCB) = $this->vatReportService->vatReportClosingBalance($request, $request->from_date, $request->to_date);

        // dd($debitVatReportCB,$creditVatReportCB);

        // Cash Report Data -----------------------------------------------------

        list($debitCashReportCB,$creditCashReportCB) = $this->cashReportService->CashReportServiceClosingBalance($request, $request->from_date, $request->to_date);

        // Vat Report Data -----------------------------------------------------

        list($debitDiscountReportCB,$creditDiscountReportCB) = $this->discountReportService->DiscountReportServiceClosingBalance($request, $request->from_date, $request->to_date);

        // $classOfAccountId = $request->class_of_account;

        $ClassOfAccount = ClassOfAccount::find($classOfAccountId);

        $customers = Customer::where('branch_id', session()->get('selected_branch'))->where('class_of_account_id', $classOfAccountId)->get(['id', 'name_of_organisation as account_name','opening_balance','type','date']);
        $suppliers = Supplier::where('branch_id', session()->get('selected_branch'))->where('class_of_account_id', $classOfAccountId)->get(['id', 'name_of_organisation as account_name','opening_balance','type','date']);
        $expenses = Expense::where('branch_id', session()->get('selected_branch'))->where('class_of_account_id', $classOfAccountId)->get(['id', 'account_name','opening_balance','type','date']);
        $adminOtherAccounts = AdminOtherAccount::where('branch_id', session()->get('selected_branch'))->where('class_of_account_id', $classOfAccountId)->get(['id', 'account_name','opening_balance','type','date']);
        $staffAndSalesman = StaffAndSalesman::where('branch_id', session()->get('selected_branch'))->where('class_of_account_id', $classOfAccountId)->get([
            'id',DB::raw("CONCAT(first_name, ' ', last_name) AS account_name"),'date_of_joining as date']);
        $allAccounts = $customers->concat($suppliers)->concat($expenses)->concat($adminOtherAccounts)->concat($staffAndSalesman);

        // dd($allAccounts);

        $totalDebit = [];
        $totalCredit = [];
        $obtotalDebit = [];
        $obtotalCredit = [];

        foreach ($allAccounts as $account) {
            $PurchaesInvoice = AdminPurchaesInvoice::where('account_name', $account->account_name)
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $from_date . ' 00:00:00')
                ->where('date', '<=', $to_date . ' 23:59:59')
                ->whereNull('deleted_at')
                ->groupBy('invoice_no')
                ->get();

            $SaleInvoice = AdminSalesInvoice::where('account_name', $account->account_name)
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $from_date . ' 00:00:00')
                ->where('date', '<=', $to_date . ' 23:59:59')
                ->whereNull('deleted_at')
                ->groupBy('invoice_no')
                ->get();

            $PaymentVoucherForCash = PaymentVoucherExpense::where(function($query) use ($account) {
                    $query->where('account_name', $account->account_name);
                })
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $from_date . ' 00:00:00')
                ->where('date', '<=', $to_date . ' 23:59:59')
                ->whereNull('deleted_at')
                ->groupBy('invoice_no')
                ->get();
            $PaymentVoucherForBank = PaymentVoucherExpense::where(function($query) use ($account) {
                    $query->where('bank_name', $account->account_name);
                })
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $from_date . ' 00:00:00')
                ->where('date', '<=', $to_date . ' 23:59:59')
                ->whereNull('deleted_at')
                ->groupBy('invoice_no')
                ->get();

            $ReceiptVoucherForBank = ReceiptVoucherExpense::where(function($query) use ($account) {
                    $query->where('bank_name', $account->account_name);
                })
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $from_date . ' 00:00:00')
                ->where('date', '<=', $to_date . ' 23:59:59')
                ->whereNull('deleted_at')
                ->groupBy('invoice_no')
                ->get();
            $ReceiptVoucherForCash = ReceiptVoucherExpense::where(function($query) use ($account) {
                    $query->where('account_name', $account->account_name);
                })
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $from_date . ' 00:00:00')
                ->where('date', '<=', $to_date . ' 23:59:59')
                ->whereNull('deleted_at')
                ->groupBy('invoice_no')
                ->get();

            $CreditNote = CreditNote::where('account_name', $account->account_name)
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $from_date . ' 00:00:00')
                ->where('date', '<=', $to_date . ' 23:59:59')
                ->whereNull('deleted_at')
                ->groupBy('invoice_no')
                ->get();

            $DebitNote = DebitNote::where('account_name', $account->account_name)
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $from_date . ' 00:00:00')
                ->where('date', '<=', $to_date . ' 23:59:59')
                ->whereNull('deleted_at')
                ->groupBy('invoice_no')
                ->get();

            $JournalVoucherForDebit = AdminJournalVoucher::where('account_name', $account->account_name)
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $from_date . ' 00:00:00')
                ->where('date', '<=', $to_date . ' 23:59:59')
                ->where('type', 'debit')
                ->whereNull('deleted_at')
                ->groupBy('invoice_no')
                ->get();

            $JournalVoucherForCredit = AdminJournalVoucher::where('account_name', $account->account_name)
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $from_date . ' 00:00:00')
                ->where('date', '<=', $to_date . ' 23:59:59')
                ->where('type', 'credit')
                ->whereNull('deleted_at')
                ->groupBy('invoice_no')
                ->get();

                // dd($JournalVoucherForDebit,$JournalVoucherForCredit);

            $TotalPurchaesInvoice = $PurchaesInvoice->sum('total_net_amount');
            $TotalDebitNote = $DebitNote->sum('total_net_amount');
            // $TotalPaymentVoucherForCash = $PaymentVoucherForCash->sum('amount');

            if ($classOfAccountId == 6) {

                $TotalPaymentVoucherForCash = $PaymentVoucherForCash->sum(function($item) {
                    return $item->amount;
                });
                $TotalPaymentVoucherForBank = $PaymentVoucherForBank->sum(function($item) {
                    return $item->amount;
                });

            } else {
                $TotalPaymentVoucherForCash = $PaymentVoucherForCash->sum(function($item) {
                    return $item->amount + $item->new_vat_amount;
                });
                $TotalPaymentVoucherForBank = $PaymentVoucherForBank->sum(function($item) {
                    return $item->amount + $item->new_vat_amount;
                });
            }

            // $TotalPaymentVoucherForBank = $PaymentVoucherForBank->sum('amount');
            $TotalJournalVoucherForDebit = $JournalVoucherForDebit->sum('amount');

            $TotalSaleInvoice = $SaleInvoice->sum('total_net_amount');
            $TotalReceiptVoucherForBank = $ReceiptVoucherForBank->sum('amount');
            $TotalReceiptVoucherForCash = $ReceiptVoucherForCash->sum('amount');
            $TotalJournalVoucherForCredit = $JournalVoucherForCredit->sum('amount');
            $TotalCreditNote = $CreditNote->sum('total_net_amount');

            $totalDebitValue = $TotalSaleInvoice + $TotalPaymentVoucherForCash + $TotalDebitNote + $TotalJournalVoucherForDebit + $TotalReceiptVoucherForBank;

            $totalCreditValue = $TotalPurchaesInvoice + $TotalReceiptVoucherForCash + $TotalCreditNote + $TotalJournalVoucherForCredit + $TotalPaymentVoucherForBank;

            // dd($totalDebitValue,$totalCreditValue);


            $totalDebit[] = [
                'account_name' => $account->account_name,
                'type' => $account->type,
                'opening_balance' => $account->opening_balance,
                'DebitBalance' => $totalDebitValue,
            ];

            // Check if the account type is 'Debit' and update 'DebitBalance' accordingly
            if (($account->type === 'Debit' || $account->type === 'debit') && $account->date >= $from_date && $account->date <= $to_date) {
                $totalDebit[count($totalDebit) - 1]['DebitBalance'] += $account->opening_balance;
            }

            $totalCredit[] = [
                'account_name' => $account->account_name,
                'type' => $account->type,
                'opening_balance' => $account->opening_balance,
                'creditBalance' => $totalCreditValue,
            ];

            // Check if the account type is 'Credit' and update 'creditBalance' accordingly
            if (($account->type === 'Credit' || $account->type === 'credit') && $account->date >= $from_date && $account->date <= $to_date) {
                $totalCredit[count($totalCredit) - 1]['creditBalance'] += $account->opening_balance;
            }

            }

            // dd($totalDebit,$totalCredit);

        foreach ($allAccounts as $account) {
            $obPurchaesInvoice = AdminPurchaesInvoice::where('account_name', $account->account_name)
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
                ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
                ->whereNull('deleted_at')
                ->groupBy('invoice_no')
                ->get();

            $obSaleInvoice = AdminSalesInvoice::where('account_name', $account->account_name)
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
                ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
                ->whereNull('deleted_at')
                ->groupBy('invoice_no')
                ->get();

            //  $obReceiptVoucher = ReceiptVoucherExpense::where(function($query) use ($account) {
            //         $query->where('account_name', $account->account_name)
            //             ->orWhere('bank_name', $account->account_name);
            //     })
            //     ->where('branch_id', session()->get('selected_branch'))
            //     ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
            //     ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
            //         ->whereNull('deleted_at')
            //         ->groupBy('invoice_no')

            //     ->get();

            $obPaymentVoucherForCash = PaymentVoucherExpense::where(function($query) use ($account) {
                    $query->where('account_name', $account->account_name);
                })
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
                ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
                ->whereNull('deleted_at')
                ->groupBy('invoice_no')
                ->get();
            $obPaymentVoucherForBank = PaymentVoucherExpense::where(function($query) use ($account) {
                    $query->where('bank_name', $account->account_name);
                })
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
                ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
                ->whereNull('deleted_at')
                ->groupBy('invoice_no')
                ->get();

            $obReceiptVoucherForBank = ReceiptVoucherExpense::where(function($query) use ($account) {
                    $query->where('bank_name', $account->account_name);
                })
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
                ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
                ->whereNull('deleted_at')
                ->groupBy('invoice_no')
                ->get();
            $obReceiptVoucherForCash = ReceiptVoucherExpense::where(function($query) use ($account) {
                    $query->where('account_name', $account->account_name);
                })
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
                ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
                ->whereNull('deleted_at')
                ->groupBy('invoice_no')
                ->get();

            $obCreditNote = CreditNote::where('account_name', $account->account_name)
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
                ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
                ->whereNull('deleted_at')
                ->groupBy('invoice_no')
                ->get();

            $obDebitNote = DebitNote::where('account_name', $account->account_name)
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
                ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
                ->whereNull('deleted_at')
                ->groupBy('invoice_no')
                ->get();
            $obJournalVoucherForDebit = AdminJournalVoucher::where('account_name', $account->account_name)
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
                ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
                ->where('type', 'debit')
                ->whereNull('deleted_at')
                ->groupBy('invoice_no')
                ->get();

            $obJournalVoucherForCredit = AdminJournalVoucher::where('account_name', $account->account_name)
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
                ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
                ->where('type', 'credit')
                ->whereNull('deleted_at')
                ->groupBy('invoice_no')
                ->get();

                // dd($obJournalVoucherForDebit,$obJournalVoucherForCredit);

            $TotalPurchaesInvoice = $obPurchaesInvoice->sum('total_net_amount');
            $obTotalDebitNote = $obDebitNote->sum('total_net_amount');
            // $obTotalPaymentVoucherForCash = $obPaymentVoucherForCash->sum('amount')->sum('new_vat_amount');

            if ($classOfAccountId == 6) {

                $obTotalPaymentVoucherForCash = $obPaymentVoucherForCash->sum(function($item) {
                    return $item->amount;
                });
                $obTotalPaymentVoucherForBank = $obPaymentVoucherForBank->sum(function($item) {
                    return $item->amount;
                });

            } else {
                $obTotalPaymentVoucherForCash = $obPaymentVoucherForCash->sum(function($item) {
                    return $item->amount + $item->new_vat_amount;
                });
                $obTotalPaymentVoucherForBank = $obPaymentVoucherForBank->sum(function($item) {
                    return $item->amount + $item->new_vat_amount;
                });
            }

            // $obTotalPaymentVoucherForBank = $obPaymentVoucherForBank->sum('amount');
            $TotalobJournalVoucherForDebit = $obJournalVoucherForDebit->sum('amount');

            $TotalSaleInvoice = $obSaleInvoice->sum('total_net_amount');
            $TotalobReceiptVoucherForBank = $obReceiptVoucherForBank->sum('amount');
            $TotalobReceiptVoucherForCash = $obReceiptVoucherForCash->sum('amount');
            $TotalobJournalVoucherForCredit = $obJournalVoucherForCredit->sum('amount');
            $TotalCreditNote = $obCreditNote->sum('total_net_amount');

            $obTotalDebitValue = $TotalSaleInvoice + $obTotalPaymentVoucherForCash + $obTotalDebitNote + $TotalobJournalVoucherForDebit + $TotalobReceiptVoucherForBank;

            $obTotalCreditValue = $TotalPurchaesInvoice  + $TotalobReceiptVoucherForCash + $TotalCreditNote + $TotalobJournalVoucherForCredit + $obTotalPaymentVoucherForBank;

            // dd($obTotalDebitValue,$obTotalCreditValue);

            $Debit = null;
            $Credit = null;

            if ($obTotalDebitValue > $obTotalCreditValue) {
                $Debit = $obTotalDebitValue - $obTotalCreditValue;
            } elseif ($obTotalDebitValue < $obTotalCreditValue) {
                $Credit = $obTotalCreditValue - $obTotalDebitValue;
            }

            $obDebitBalance = $Debit;
            $obcreditBalance = $Credit;

            $obtotalDebit[] = [
                'account_name' => $account->account_name,
                'type' => $account->type,
                'opening_balance' => $account->opening_balance,
                'DebitBalance' => $obDebitBalance,
            ];

            if (($account->type === 'Debit' || $account->type === 'debit') && $account->date >= $currentYearFirstDate && $account->date <= $oneDayPreviousDate) {
                $obtotalDebit[count($obtotalDebit) - 1]['DebitBalance'] += $account->opening_balance;
            }

            $obtotalCredit[] = [
                'account_name' => $account->account_name,
                'type' => $account->type,
                'opening_balance' => $account->opening_balance,
                'creditBalance' => $obcreditBalance,
            ];

            if (($account->type === 'Credit' || $account->type === 'credit') && $account->date >= $currentYearFirstDate && $account->date <= $oneDayPreviousDate) {
                $obtotalCredit[count($obtotalCredit) - 1]['creditBalance'] += $account->opening_balance;
            }


            }

        return view('crusher.reports.index_class_of_account', compact('from_date', 'to_date', 'totalDebit','totalCredit','allAccounts','ClassOfAccount','obtotalDebit','obtotalCredit','debitCashReportCB','creditCashReportCB','debitVatReportCB',
        'creditVatReportCB'));
    }

    public function index_ledger_billwise(Request $request)
    {
        $from_date = $request->from_date;
        $to_date = $request->to_date;
        $ledger_class = $request->ledger_class;

        $customer = Customer::find($ledger_class);
        $staffAndSalesman = StaffAndSalesman::find($ledger_class);
        $supplier = Supplier::find($ledger_class);
        $expense = Expense::find($ledger_class);
        $adminOtherAccount = AdminOtherAccount::find($ledger_class);

        $matchedAccount = null;
        $PurchaesInvoice = null;

        $PurchaesInvoice = AdminPurchaesInvoice::where('account_name', $ledger_class)
            ->where('branch_id', session()->get('selected_branch'))
            ->where('date', '>=', $from_date . ' 00:00:00')
            ->where('date', '<=', $to_date . ' 23:59:59')
            ->whereNull('deleted_at')
            ->groupBy('invoice_no')
            ->get();

        $SaleInvoice = AdminSalesInvoice::where('account_name', $ledger_class)
            ->where('branch_id', session()->get('selected_branch'))
            ->where('date', '>=', $from_date . ' 00:00:00')
            ->where('date', '<=', $to_date . ' 23:59:59')
            ->whereNull('deleted_at')
            ->groupBy('invoice_no')
            ->get();

        $allData = $PurchaesInvoice->concat($SaleInvoice);
        // dd($allData);

        // if ($customer || $staffAndSalesman || $supplier || $expense || $adminOtherAccount) {
        //     if ($customer) {
        //         $matchedAccount = $customer;
        //     } elseif ($staffAndSalesman) {
        //         $matchedAccount = $staffAndSalesman;
        //     } elseif ($supplier) {
        //         $matchedAccount = $supplier;
        //     } elseif ($expense) {
        //         $matchedAccount = $expense;
        //     } elseif ($adminOtherAccount) {
        //         $matchedAccount = $adminOtherAccount;
        //     }

        //     $PurchaesInvoice = AdminPurchaesInvoice::where('account_id', $ledger_class)
        //         ->where('branch_id', session()->get('selected_branch'))
        //         ->where('date', '>=', $from_date . ' 00:00:00')
        //         ->where('date', '<=', $to_date . ' 23:59:59')
        //          ->groupBy('invoice_no')
        //         ->get();

        //     $SaleInvoice = AdminSalesInvoice::where('account_id', $ledger_class)
        //         ->where('branch_id', session()->get('selected_branch'))
        //         ->where('date', '>=', $from_date . ' 00:00:00')
        //         ->where('date', '<=', $to_date . ' 23:59:59')
        //          ->groupBy('invoice_no')
        //         ->get();
        // }

        // $allData = $PurchaesInvoice->concat($SaleInvoice);
        // dd($allData);
        return view('crusher.reports.index_ledger_billwise', compact('from_date','to_date', 'ledger_class','allData','matchedAccount','PurchaesInvoice','SaleInvoice'));
    }

    public function index_ledger_vatwise(request $request)
    {
        $from_date = $request->from_date;
        $to_date = $request->to_date;
        $ledger_class = $request->ledger_class;

        $customer = Customer::find($ledger_class);
        $staffAndSalesman = StaffAndSalesman::find($ledger_class);
        $supplier = Supplier::find($ledger_class);
        $expense = Expense::find($ledger_class);
        $adminOtherAccount = AdminOtherAccount::find($ledger_class);

        $matchedAccount = null;
        $PurchaesInvoice = null;

        if ($customer || $staffAndSalesman || $supplier || $expense || $adminOtherAccount) {
            if ($customer) {
                $matchedAccount = $customer;
            } elseif ($staffAndSalesman) {
                $matchedAccount = $staffAndSalesman;
            } elseif ($supplier) {
                $matchedAccount = $supplier;
            } elseif ($expense) {
                $matchedAccount = $expense;
            } elseif ($adminOtherAccount) {
                $matchedAccount = $adminOtherAccount;
            }

            $PurchaesInvoice = AdminPurchaesInvoice::where('account_id', $ledger_class)
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $from_date . ' 00:00:00')
                ->where('date', '<=', $to_date . ' 23:59:59')
                 ->groupBy('invoice_no')
                ->get();

            $SaleInvoice = AdminSalesInvoice::where('account_id', $ledger_class)
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $from_date . ' 00:00:00')
                ->where('date', '<=', $to_date . ' 23:59:59')
                 ->groupBy('invoice_no')
                ->get();

        }
        return view('crusher.reports.index_ledger_vatwise', compact('from_date', 'to_date', 'ledger_class', 'matchedAccount', 'PurchaesInvoice','SaleInvoice'));

    }

    public function view1()
    {
        return view('crusher.reports.statement_account_1');
    }

    public function ledgerReport(Request $request)
    {
        // dd($request);
        $lastFromDate = date("2003-01-01");
        $from_date = $request->from_date;
        $to_date = $request->to_date;
        $lastDay = Carbon::parse($to_date)->subDay()->format('Y-m-d');
        // dd($lastDay, $lastFromDate);

        $classOfAccountId = $request->class_of_account_id;

        // dd($classOfAccountId);

        $periodClosingDate = AdminPeriodClosing::latest()->value('to');

        // dd($periodClosingDate);

        if ($classOfAccountId == 6 || $periodClosingDate) {
            if ($periodClosingDate && strtotime($periodClosingDate)) {
                $currentYearFirstDate = $periodClosingDate;
                $oneDayPreviousDate = date('Y-m-d', strtotime('-1 day', strtotime($currentYearFirstDate)));
            }
        } else {
            $currentYearFirstDate = "2003-01-01";
            $oneDayPreviousDate = date('Y-m-d', strtotime('-1 day', strtotime($from_date)));
        }

        // $currentYearFirstDate = date("2003-01-01");
        // $oneDayPreviousDate = date('Y-m-d', strtotime('-1 day', strtotime($from_date)));

        $ledger_class = $request->ledger_class;
        // $classOfAccountName = $request->ledger_class;

        // dd($classOfAccountName);

        // if ($periodClosingDate) {
        //     $currentYearFirstDate = $periodClosingDate;
        // } else {
        //     $currentYearFirstDate = date("2003-01-01");
        // }

        $customer = Customer::where('branch_id', session()->get('selected_branch'))
            // ->where('date', '>=', $from_date . ' 00:00:00')
            // ->where('date', '<=', $to_date . ' 23:59:59')
            ->where('name_of_organisation', $ledger_class)
            ->first();

        $staffAndSalesman = StaffAndSalesman::where('branch_id', session()->get('selected_branch'))
            ->whereRaw("CONCAT(first_name, ' ', last_name) = '$ledger_class'")
            ->first();

        $supplier = Supplier::where('branch_id', session()->get('selected_branch'))
            // ->where('date', '>=', $from_date . ' 00:00:00')
            // ->where('date', '<=', $to_date . ' 23:59:59')
            ->where('name_of_organisation', $ledger_class)
            ->first();
        $expense = Expense::where('branch_id', session()->get('selected_branch'))
            // ->where('date', '>=', $from_date . ' 00:00:00')
            // ->where('date', '<=', $to_date . ' 23:59:59')
            ->where('account_name', $ledger_class)
            ->first();
        $adminOtherAccount = AdminOtherAccount::where('branch_id', session()->get('selected_branch'))
            // ->where('date', '>=', $from_date . ' 00:00:00')
            // ->where('date', '<=', $to_date . ' 23:59:59')
            ->where('account_name', $ledger_class)
            ->first();
        $matchedAccount = null;
        $PurchaesInvoice = null;
        $JournalVoucher = null;
        $ReceiptVoucher = null;
        $PaymentVoucher = null;
        $DeliveryNote = null;
        $CreditNote = null;
        $DebitNote = null;
        $PurchaseOrder = null;
        $Quotation = null;
        $openingBalance = null;
        $SaleInvoice     = null;
        $ObDebit = null;
        $ObCredit = null;
        $CreateDebitOpeningBalance = null;
        $CreateCreditOpeningBalance = null;
        $obCreateDebitOpeningBalance = null;
        $obCreateCreditOpeningBalance = null;

        if ($customer || $staffAndSalesman || $supplier || $expense || $adminOtherAccount) {
            if ($customer) {
                $matchedAccount = $customer;
            } elseif ($staffAndSalesman) {
                $matchedAccount = $staffAndSalesman;
            } elseif ($supplier) {
                $matchedAccount = $supplier;
            } elseif ($expense) {
                $matchedAccount = $expense;
            } elseif ($adminOtherAccount) {
                $matchedAccount = $adminOtherAccount;
            }

            if (!empty($matchedAccount)) {
                $debitCardValue = optional($matchedAccount)->type;
                $matchedAccountDate = optional($matchedAccount)->date;

                if ($matchedAccountDate >= $from_date &&
                    $matchedAccountDate <= $to_date) {
                    if ($debitCardValue === 'Debit' || $debitCardValue === 'debit') {
                        $CreateDebitOpeningBalance = optional($matchedAccount)->opening_balance;
                    } elseif ($debitCardValue === 'Credit' || $debitCardValue === 'credit') {
                        $CreateCreditOpeningBalance = optional($matchedAccount)->opening_balance;
                    }
                }
            }

            $PurchaesInvoice = AdminPurchaesInvoice::where('account_name', $ledger_class)
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $from_date . ' 00:00:00')
                ->where('date', '<=', $to_date . ' 23:59:59')
                ->whereNull('deleted_at')
                ->groupBy('invoice_no')
                ->get();

            $SaleInvoice = AdminSalesInvoice::where('account_name', $ledger_class)
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $from_date . ' 00:00:00')
                ->where('date', '<=', $to_date . ' 23:59:59')
                ->whereNull('deleted_at')
                 ->groupBy('invoice_no')
                ->get();
            $JournalVoucher = AdminJournalVoucher::where('account_name', $ledger_class)
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $from_date . ' 00:00:00')
                ->where('date', '<=', $to_date . ' 23:59:59')
                ->whereNull('deleted_at')
                 ->groupBy('invoice_no')
                ->get();

                // dd($JournalVoucher);
            // $ReceiptVoucher = ReceiptVoucherExpense::where('account_name', $ledger_class)
            //     ->where('branch_id', session()->get('selected_branch'))
            //     ->where('date', '>=', $from_date . ' 00:00:00')
            //     ->where('date', '<=', $to_date . ' 23:59:59')
            //     ->whereNull('deleted_at')
            //     ->groupBy('invoice_no')
            //     ->get();
            // // $ReceiptVoucherForBankWise = ReceiptVoucherExpense::where('bank_name', $ledger_class)
            // //     ->where('branch_id', session()->get('selected_branch'))
            // //     ->where('date', '>=', $from_date . ' 00:00:00')
            // //     ->where('date', '<=', $to_date . ' 23:59:59')
            // //     ->whereNull('deleted_at')
            // //     ->groupBy('invoice_no')
            // //     ->get();

            $ReceiptVoucher = ReceiptVoucherExpense::where(function($query) use ($ledger_class) {
                    $query->where('account_name', $ledger_class)
                    ->orWhere('bank_name', $ledger_class);
                })
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $from_date . ' 00:00:00')
                ->where('date', '<=', $to_date . ' 23:59:59')
                ->whereNull('deleted_at')
                ->groupBy('invoice_no')
                ->get();

            // $ReceiptVoucherForCash = ReceiptVoucherExpense::where(function($query) use ($ledger_class) {
            //     $query->where('account_name', $ledger_class);
            //     })
            //     ->where('branch_id', session()->get('selected_branch'))
            //     ->where('date', '>=', $from_date . ' 00:00:00')
            //     ->where('date', '<=', $to_date . ' 23:59:59')
            //     ->whereNull('deleted_at')
            //     ->groupBy('invoice_no')
            //     ->get();

            // $ReceiptVoucherForBank = ReceiptVoucherExpense::where(function($query) use ($ledger_class) {
            //     $query->where('bank_name', $ledger_class);
            //     })
            //     ->where('branch_id', session()->get('selected_branch'))
            //     ->where('date', '>=', $from_date . ' 00:00:00')
            //     ->where('date', '<=', $to_date . ' 23:59:59')
            //     ->whereNull('deleted_at')
            //     ->groupBy('invoice_no')
            //     ->get();

            // dd($ReceiptVoucher);

            $PaymentVoucher = PaymentVoucherExpense::where(function($query) use ($ledger_class) {
                    $query->where('account_name', $ledger_class)
                        ->orWhere('bank_name', $ledger_class);
                })
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $from_date . ' 00:00:00')
                ->where('date', '<=', $to_date . ' 23:59:59')
                ->whereNull('deleted_at')
                ->groupBy('invoice_no')
                ->get();

            // dd($PaymentVoucher);

            // $PaymentVoucherForBankWise = adminPaymentVoucher::where('bank_name', $ledger_class)
            //     ->where('branch_id', session()->get('selected_branch'))
            //     ->where('date', '>=', $from_date . ' 00:00:00')
            //     ->where('date', '<=', $to_date . ' 23:59:59')
            //     ->whereNull('deleted_at')
            //     ->groupBy('invoice_no')
            //     ->get();
            // dd($PaymentVoucherForBankWise);

            $CreditNote = CreditNote::where('account_name', $ledger_class)
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $from_date . ' 00:00:00')
                ->where('date', '<=', $to_date . ' 23:59:59')
                    ->whereNull('deleted_at')
                ->groupBy('invoice_no')
                    ->get();
            $DebitNote = DebitNote::where('account_name', $ledger_class)
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $from_date . ' 00:00:00')
                ->where('date', '<=', $to_date . ' 23:59:59')
                    ->whereNull('deleted_at')
                ->groupBy('invoice_no')
                    ->get();

            $PurchaseOrder = PurchaseOrder::where('account_name', $ledger_class)
                ->where('branch_id', session()->get('selected_branch'))
                ->where('created_at', '>=', $from_date . ' 00:00:00')
                ->where('created_at', '<=', $to_date . ' 23:59:59')
                    ->whereNull('deleted_at')
                ->groupBy('invoice_no')
                    ->get();
            $Quotation = Quotation::where('account_name', $ledger_class)
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $from_date . ' 00:00:00')
                ->where('date', '<=', $to_date . ' 23:59:59')
                    ->whereNull('deleted_at')
                ->groupBy('quotation_no')
                    ->get();


            $allData = $PurchaesInvoice ->concat($SaleInvoice)->concat($JournalVoucher)->concat($ReceiptVoucher)->concat($PaymentVoucher)->concat($CreditNote)->concat($DebitNote)->concat($PurchaseOrder)->concat($Quotation);

            // dd($allData);

            // OPENING BALANCE
            $ObPurchaesInvoice = AdminPurchaesInvoice::where('account_name', $ledger_class)
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
                ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
                ->whereNull('deleted_at')
                ->groupBy('invoice_no')
                ->get()
                ->sum('total_purchase_amount_with_cf');
            // dd($ObPurchaesInvoice);

            $ObSaleInvoice = AdminSalesInvoice::where('account_name', $ledger_class)
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
                ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
                ->whereNull('deleted_at')
                ->groupBy('invoice_no')
                ->get()
                ->sum('total_net_amount');
            $ObJournalVoucherForDebit = AdminJournalVoucher::where('account_name', $ledger_class)
                ->where('branch_id', session()->get('selected_branch'))
                ->where('type','debit')
                ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
                ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
                ->whereNull('deleted_at')
                 ->groupBy('invoice_no')
                ->get()
                ->sum('amount');
            // $ObJournalVoucherForCredit = null;
            $ObJournalVoucherForCredit = AdminJournalVoucher::where('account_name', $ledger_class)
                ->where('branch_id', session()->get('selected_branch'))
                ->where('type','credit')
                ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
                ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
                ->whereNull('deleted_at')
                 ->groupBy('invoice_no')
                ->get()
                ->sum('amount');

            // $ObReceiptVoucher = ReceiptVoucherExpense::where('account_id', $ledger_class)
            //     // ->where('branch_id', session()->get('selected_branch'))
            //     ->where('created_at', '>=', $currentYearFirstDate . ' 00:00:00')
            //     ->where('created_at', '<=', $oneDayPreviousDate . ' 23:59:59')
            //      ->groupBy('inovice_id')
            //     ->get()
            //     ->sum('amount');

            // $ObReceiptVoucher = AdminReceiptVoucher::with('expense')
            // ->where('branch_id', session()->get('selected_branch'))
            // ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
            // ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
            // ->whereHas('expense', function ($query) use ($ledger_class) {
            //     $query->where('account_name', $ledger_class);
            // })
            // ->groupBy('invoice_no')
            // ->get()
            // ->sum('amount');
            // $ObPaymentVoucher = AdminPaymentVoucher::with('expense')
            // ->where('branch_id', session()->get('selected_branch'))
            // ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
            // ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
            // ->whereHas('expense', function ($query) use ($ledger_class) {
            //     $query->where('account_name', $ledger_class);
            // })
            //  ->groupBy('invoice_no')
            // ->get()
            // ->sum('amount');

            // $ObPaymentVoucher = PaymentVoucherExpense::where('account_id', $ledger_class)
            //     // ->where('branch_id', session()->get('selected_branch'))
            //     ->where('created_at', '>=', $currentYearFirstDate . ' 00:00:00')
            //     ->where('created_at', '<=', $oneDayPreviousDate . ' 23:59:59')
            //      ->groupBy('inovice_id')
            //     ->get()
            //     ->sum('amount');

            $ObReceiptVoucherForCash = ReceiptVoucherExpense::where(function($query) use ($ledger_class) {
                $query->where('account_name', $ledger_class);
                    // ->orWhere('bank_name', $ledger_class);
            })
            ->where('branch_id', session()->get('selected_branch'))
            // ->where('payment_method','cash')
            ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
            ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
            ->whereNull('deleted_at')
            ->groupBy('invoice_no')
            ->get()
            ->sum('amount');
            $ObReceiptVoucherForBank = ReceiptVoucherExpense::where(function($query) use ($ledger_class) {
                $query->where('bank_name', $ledger_class);
                    // ->orWhere('bank_name', $ledger_class);
            })
            ->where('branch_id', session()->get('selected_branch'))
            // ->where('payment_method','bank')
            ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
            ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
            ->whereNull('deleted_at')
            ->groupBy('invoice_no')
            ->get()
            ->sum('amount');

            $ObPaymentVoucherForCash = PaymentVoucherExpense::where(function($query) use ($ledger_class) {
                $query->where('bank_name', $ledger_class);
                // ->orWhere('bank_name', $ledger_class);
            })
            ->where('branch_id', session()->get('selected_branch'))
            // ->where('payment_method','cash')
            ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
            ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
            ->whereNull('deleted_at')
            ->groupBy('invoice_no')
            ->get();
            // ->sum(function ($voucher) {
            //     return $voucher->amount + $voucher->new_vat_amount;
            // });
            $ObPaymentVoucherForBank = PaymentVoucherExpense::where(function($query) use ($ledger_class) {
                $query->where('account_name', $ledger_class);
                // ->orWhere('bank_name', $ledger_class);
            })
            ->where('branch_id', session()->get('selected_branch'))
            ->where('payment_method','bank')
            ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
            ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
            ->whereNull('deleted_at')
            ->groupBy('invoice_no')
            ->get();
            // ->sum(function ($voucher) {
            //     return $voucher->amount + $voucher->new_vat_amount;
            // });
            // dd($ObReceiptVoucher,$ObPaymentVoucher);
            if ($classOfAccountId == 6) {

                $obTotalPaymentVoucherForCash = $ObPaymentVoucherForCash->sum(function($item) {
                    return $item->amount;
                });
                $obTotalPaymentVoucherForBank = $ObPaymentVoucherForBank->sum(function($item) {
                    return $item->amount;
                });

            } else {
                $obTotalPaymentVoucherForCash = $ObPaymentVoucherForCash->sum(function($item) {
                    return $item->amount + $item->new_vat_amount;
                });
                $obTotalPaymentVoucherForBank = $ObPaymentVoucherForBank->sum(function($item) {
                    return $item->amount + $item->new_vat_amount;
                });
            }
            $ObCreditNote = CreditNote::where('account_name', $ledger_class)
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
                ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
                ->whereNull('deleted_at')
                 ->groupBy('invoice_no')
                ->get()
                ->sum('total_net_amount');

            $ObDebitNote = DebitNote::where('account_name', $ledger_class)
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
                ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
                ->whereNull('deleted_at')
                 ->groupBy('invoice_no')
                ->get()
                ->sum('total_net_amount');

            // $ObPurchaseOrder = PurchaseOrder::where('account_name', $ledger_class)
            // ->where('branch_id', session()->get('selected_branch'))
            // ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
            // ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
            //     ->whereNull('deleted_at')
            //  ->groupBy('invoice_no')
            //  ->get()
            // ->sum('total_net_amount');

            // $ObQuotation = Quotation::where('account_name', $ledger_class)
            //     ->where('branch_id', session()->get('selected_branch'))
            //     ->where('created_at', '>=', $currentYearFirstDate . ' 00:00:00')
            //     ->where('created_at', '<=', $oneDayPreviousDate . ' 23:59:59')
            //     ->whereNull('deleted_at')
            //      ->groupBy('quotation_no')
            //     ->get()
            //     ->sum('total_net_amount');


            if (!empty($matchedAccount)) {
                $obDebitCardValue = optional($matchedAccount)->type;
                $obMatchedAccountDate = optional($matchedAccount)->date;

                if ($obMatchedAccountDate >= $currentYearFirstDate &&
                    $obMatchedAccountDate <= $oneDayPreviousDate) {
                    if ($obDebitCardValue === 'Debit' || $obDebitCardValue === 'debit') {
                        $obCreateDebitOpeningBalance = optional($matchedAccount)->opening_balance;
                    } elseif ($obDebitCardValue === 'Credit' || $obDebitCardValue === 'credit') {
                        $obCreateCreditOpeningBalance = optional($matchedAccount)->opening_balance;
                    }
                }
            }

            // Opening Balance

            // $debitTotal = $CreateDebitOpeningBalance + $SaleInvoiceTotal + $JournalVoucherTotalForDebit + $PaymentVoucherTotalForCash + $DebitNoteTotal + $ReceiptVoucherTotalForBank;

            // $creditTotal = $CreateCreditOpeningBalance + $PurchaesInvoiceTotal + $ReceiptVoucherTotalForCash + $JournalVoucherTotalForCredit + $CreditNoteTotal + $PaymentVoucherTotalForBank;


            $obDebitTotal = $obCreateDebitOpeningBalance + $ObSaleInvoice + $ObJournalVoucherForDebit + $obTotalPaymentVoucherForBank + $ObDebitNote + $ObReceiptVoucherForBank;

            $obCreditTotal = $obCreateCreditOpeningBalance + $ObPurchaesInvoice + $ObReceiptVoucherForCash + $ObCreditNote + $ObJournalVoucherForCredit + $obTotalPaymentVoucherForCash;

            // dd($obCreateDebitOpeningBalance,$ObSaleInvoice,$ObJournalVoucherForDebit,$ObPaymentVoucherForBank,$ObDebitNote,$ObReceiptVoucherForBank);
            // dd($obDebitTotal,$obCreditTotal);

            // $openingBalance = $debitTotal - $creditTotal;

            if ($obDebitTotal > $obCreditTotal) {
                $ObDebit = $obDebitTotal - $obCreditTotal;
            } elseif ($obDebitTotal < $obCreditTotal) {
                $ObCredit = $obCreditTotal - $obDebitTotal;
            }

            $DebitopeningBalance = $ObDebit;
            $creditOpeningBalance = $ObCredit;

        }


        return view('crusher.reports.ledger-report', compact('from_date', 'to_date', 'ledger_class', 'matchedAccount', 'PurchaesInvoice','JournalVoucher','ReceiptVoucher','PaymentVoucher','DeliveryNote','CreditNote','DebitNote','PurchaseOrder','Quotation', 'openingBalance','SaleInvoice','DebitopeningBalance','creditOpeningBalance','allData','CreateDebitOpeningBalance','CreateCreditOpeningBalance','classOfAccountId'));
    }
    public function vatLedgerReport(Request $request)
    {
        $lastFromDate = date("2003-01-01");
        $from_date = $request->from_date;
        $to_date = $request->to_date;
        $lastDay = Carbon::parse($to_date)->subDay()->format('Y-m-d');
        // dd($lastDay, $lastFromDate);

        $currentYearFirstDate = date("2003-01-01");
        $oneDayPreviousDate = date('Y-m-d', strtotime('-1 day', strtotime($from_date)));

        $ledger_class = $request->ledger_class;

        $customer = Customer::where('branch_id', session()->get('selected_branch'))
            // ->where('id', $ledger_class)
            ->get();

        $staffAndSalesman = StaffAndSalesman::where('branch_id', session()->get('selected_branch'))
            // ->where('id', $ledger_class)
            ->get();
        $supplier = Supplier::where('branch_id', session()->get('selected_branch'))
            // ->where('id', $ledger_class)
            ->get();
        $expense = Expense::where('branch_id', session()->get('selected_branch'))
            // ->where('id', $ledger_class)
            ->get();
        $adminOtherAccount = AdminOtherAccount::where('branch_id', session()->get('selected_branch'))
            // ->where('id', $ledger_class)
            ->get();

        $matchedAccount = null;
        $PurchaesInvoice = null;
        $JournalVoucher = null;
        $ReceiptVoucher = null;
        $PaymentVoucher = null;
        $DeliveryNote = null;
        $CreditNote = null;
        $DebitNote = null;
        $PurchaseOrder = null;
        $Quotation = null;
        $openingBalance = null;
        $SaleInvoice     = null;
        $ObDebit = null;
        $ObCredit = null;
        $CreateDebitOpeningBalance = null;
        $CreateCreditOpeningBalance = null;

        if ($customer || $staffAndSalesman || $supplier || $expense || $adminOtherAccount) {
            if ($customer) {
                $matchedAccount = $customer;
            } elseif ($staffAndSalesman) {
                $matchedAccount = $staffAndSalesman;
            } elseif ($supplier) {
                $matchedAccount = $supplier;
            } elseif ($expense) {
                $matchedAccount = $expense;
            } elseif ($adminOtherAccount) {
                $matchedAccount = $adminOtherAccount;
            }

            $PurchaesInvoice = AdminPurchaesInvoice::where('account_id', $ledger_class)
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $from_date . ' 00:00:00')
                ->where('date', '<=', $to_date . ' 23:59:59')
                 ->groupBy('invoice_no')
                ->get();

            $SaleInvoice = AdminSalesInvoice::where('account_id', $ledger_class)
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $from_date . ' 00:00:00')
                ->where('date', '<=', $to_date . ' 23:59:59')
                 ->groupBy('invoice_no')
                ->get();
            $JournalVoucher = AdminJournalVoucher::where('account_id', $ledger_class)
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $from_date . ' 00:00:00')
                ->where('date', '<=', $to_date . ' 23:59:59')
                 ->groupBy('invoice_no')
                ->get();
                $ReceiptVoucher = AdminReceiptVoucher::with('expense')
                ->where('branch_id', session()->get('selected_branch'))
                ->where('created_at', '>=', $from_date . ' 00:00:00')
                ->where('created_at', '<=', $to_date . ' 23:59:59')
                ->whereHas('expense', function ($query) use ($ledger_class) {
                    $query->where('account_id', $ledger_class);
                })
                ->groupBy('invoice_no')
                ->get();

            $PaymentVoucher = AdminPaymentVoucher::with('expense')
            ->where('branch_id', session()->get('selected_branch'))
            ->where('created_at', '>=', $from_date . ' 00:00:00')
            ->where('created_at', '<=', $to_date . ' 23:59:59')
            ->whereHas('expense', function ($query) use ($ledger_class) {
                $query->where('account_id', $ledger_class);
            })
             ->groupBy('invoice_no')
                ->get();
            $CreditNote = CreditNote::where('account_id', $ledger_class)
            ->where('branch_id', session()->get('selected_branch'))
            ->where('created_at', '>=', $from_date . ' 00:00:00')
            ->where('created_at', '<=', $to_date . ' 23:59:59')
             ->groupBy('invoice_no')
                ->get();
            $DebitNote = DebitNote::where('account_id', $ledger_class)
            ->where('branch_id', session()->get('selected_branch'))
            ->where('created_at', '>=', $from_date . ' 00:00:00')
            ->where('created_at', '<=', $to_date . ' 23:59:59')
             ->groupBy('invoice_no')
                ->get();

            $PurchaseOrder = PurchaseOrder::where('account_id', $ledger_class)
            ->where('branch_id', session()->get('selected_branch'))
            ->where('created_at', '>=', $from_date . ' 00:00:00')
            ->where('created_at', '<=', $to_date . ' 23:59:59')
             ->groupBy('invoice_no')
                ->get();
            $Quotation = Quotation::where('account_id', $ledger_class)
            ->where('branch_id', session()->get('selected_branch'))
            ->where('date', '>=', $from_date . ' 00:00:00')
            ->where('date', '<=', $to_date . ' 23:59:59')
             ->groupBy('quotation_no')
                ->get();

            // OPENING BALANCE
            $ObPurchaesInvoice = AdminPurchaesInvoice::where('account_id', $ledger_class)
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
                ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
                //  ->groupBy('invoice_no')
                ->sum('total_net_amount');
            // dd($ObPurchaesInvoice);

            $ObSaleInvoice = AdminSalesInvoice::where('account_id', $ledger_class)
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
                ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
                //  ->groupBy('invoice_no')
                ->sum('total_net_amount')
                ;
            $ObJournalVoucher = AdminJournalVoucher::where('account_id', $ledger_class)
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
                ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
                //  ->groupBy('invoice_no')
                ->sum('amount');

            $ObReceiptVoucher = ReceiptVoucherExpense::where('account_id', $ledger_class)
                // ->where('branch_id', session()->get('selected_branch'))
                ->where('created_at', '>=', $currentYearFirstDate . ' 00:00:00')
                ->where('created_at', '<=', $oneDayPreviousDate . ' 23:59:59')
                //  ->groupBy('inovice_id')
                ->sum('amount');

            $ObPaymentVoucher = PaymentVoucherExpense::where('account_id', $ledger_class)
                // ->where('branch_id', session()->get('selected_branch'))
                ->where('created_at', '>=', $currentYearFirstDate . ' 00:00:00')
                ->where('created_at', '<=', $oneDayPreviousDate . ' 23:59:59')
                //  ->groupBy('inovice_id')
                ->sum('amount');

            $ObCreditNote = CreditNote::where('account_id', $ledger_class)
                ->where('branch_id', session()->get('selected_branch'))
                ->where('created_at', '>=', $currentYearFirstDate . ' 00:00:00')
                ->where('created_at', '<=', $oneDayPreviousDate . ' 23:59:59')
                //  ->groupBy('invoice_no')
                ->sum('total_net_amount');

            $ObDebitNote = DebitNote::where('account_id', $ledger_class)
                ->where('branch_id', session()->get('selected_branch'))
                ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
                ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
                //  ->groupBy('invoice_no')
                ->sum('total_net_amount');

            $ObPurchaseOrder = PurchaseOrder::where('account_id', $ledger_class)
            ->where('branch_id', session()->get('selected_branch'))
            ->where('date', '>=', $currentYearFirstDate . ' 00:00:00')
            ->where('date', '<=', $oneDayPreviousDate . ' 23:59:59')
            //  ->groupBy('invoice_no')
            ->sum('total_net_amount');

            $ObQuotation = Quotation::where('account_id', $ledger_class)
                ->where('branch_id', session()->get('selected_branch'))
                ->where('created_at', '>=', $currentYearFirstDate . ' 00:00:00')
                ->where('created_at', '<=', $oneDayPreviousDate . ' 23:59:59')
                //  ->groupBy('quotation_no')
                ->sum('total_net_amount');

            if (!empty($matchedAccount)) {
                $debitCardValue = optional($matchedAccount)->debit_card;
                $matchedAccountDate = optional($matchedAccount)->date;

                if ($matchedAccountDate >= $currentYearFirstDate &&
                    $matchedAccountDate <= $oneDayPreviousDate) {
                    if ($debitCardValue === 'Debit') {
                        $CreateDebitOpeningBalance = optional($matchedAccount)->opening_balance;
                    } elseif ($debitCardValue === 'Credit') {
                        $CreateCreditOpeningBalance = optional($matchedAccount)->opening_balance;
                    }
                }
            }

            // Opening Balance

            $debitTotal = $CreateDebitOpeningBalance + $ObSaleInvoice + $ObJournalVoucher + $ObPaymentVoucher + $ObCreditNote + $ObPurchaseOrder + $ObDebitNote  + $ObQuotation;
            $creditTotal = $ObPurchaesInvoice + $ObReceiptVoucher + $CreateCreditOpeningBalance;
            // $openingBalance = $debitTotal - $creditTotal;

            if ($debitTotal > $creditTotal) {
                $ObDebit = $debitTotal - $creditTotal;
            } elseif ($debitTotal < $creditTotal) {
                $ObCredit = $creditTotal - $debitTotal;
            }

            $DebitopeningBalance = $ObDebit;
            $creditOpeningBalance = $ObCredit;

            // dd($DebitopeningBalance,$creditOpeningBalance);

            // dd($debitTotal,$creditTotal);

            // dd($ObSaleInvoice);

            // dd($openingBalance);

            // dd($currentYearFirstDate,$oneDayPreviousDate,$ObSaleInvoice,$ObJournalVoucher,$ObReceiptVoucher,$ObPaymentVoucher,$ObCreditNote,$ObDebitNote,$ObPurchaseOrder,$ObQuotation);

            // dd($ObPurchaesInvoice);
            // dd($ObSaleInvoice, $ObJournalVoucher, $ObReceiptVoucher, $ObPaymentVoucher, $ObCreditNote, $ObDebitNote, $ObPurchaseOrder, $ObQuotation, $ObPurchaesInvoice);
        }


        return view('crusher.reports.vat_ledger-report', compact('from_date', 'to_date', 'ledger_class', 'matchedAccount', 'PurchaesInvoice','JournalVoucher','ReceiptVoucher','PaymentVoucher','DeliveryNote','CreditNote','DebitNote','PurchaseOrder','Quotation', 'openingBalance','SaleInvoice','DebitopeningBalance','creditOpeningBalance'));
    }

}
