<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\ClientModel;
use App\User;
use App\Testimonial;
use App\Trusted_logo;
use App\Feature;
use App\Contact_to_ledgematic;
use App\Branches;
use App\Company;
use App\Newsletter;
use Hash;
use Carbon\Carbon;
use Illuminate\Support\Facades\DB;

class WebsiteContactController extends Controller
{
    public function indexLedgematic()
    {
        $data['trustedLogosRowOne'] = Trusted_logo::where('line', '1')->get();
        $data['trustedLogosRowTwo'] = Trusted_logo::where('line', '2')->get();

        $data['FeatureRowOne'] = Feature::where('row', '1')->get();
        $data['FeatureRowTwo'] = Feature::where('row', '2')->get();

        $data['Testimonial'] = Testimonial::get();

        return view('index')->with($data);
    }


    public function bookDemoIndex()
    {
        $data['clients'] = User::whereIn('role', ['Admin', 'Superadmin'])->get();

        return view('super_admin.website_contact.book-demo-index')->with($data);
    }

    public function newsletterIndex()
    {
        $data['Newsletters'] = Newsletter::get();

        return view('super_admin.newsletter.index')->with($data);
    }
    public function testimonialsIndex()
    {
        $data['testimonials'] = Testimonial::get();

        return view('super_admin.testimonial.index')->with($data);
    }
    public function testimonialsAdd()
    {
        return view('super_admin.testimonial.add');
    }

        public function testimonialStore(Request $request)
    {
        // dd($request);

        if ($request->hasFile('image')) {
            $imageName = time() . '.' . $request->image->getClientOriginalExtension();
            $request->image->move(public_path('testimonial'), $imageName);

            $insertData['image'] = $imageName;
        } else {
            $insertData['image'] = null;
        }

        $insertData['name'] = $request->name;
        $insertData['designation'] = $request->designation;
        $insertData['message'] = $request->message;

        Testimonial::create($insertData);

        flash()->addSuccess('Record Created');

        return redirect('testimonials-index');
    }
    public function testimonialEdit(Request $request,$id)
    {
        $data['testimonials'] = Testimonial::where('id',$id)->first();
        return view('super_admin.testimonial.edit')->with($data);
    }
        public function testimonialUpdate(Request $request, $id)
    {
        $validatedData = $request->validate([
            'name' => 'required|string|max:255',
            'designation' => 'required|string|max:255',
            'message' => 'required|string',
            'image' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048',
        ]);

        $updateData = [
            'name' => $validatedData['name'],
            'designation' => $validatedData['designation'],
            'message' => $validatedData['message'],
        ];

        if ($request->hasFile('image')) {
            $imageName = time() . '.' . $request->image->getClientOriginalExtension();
            $request->image->move(public_path('testimonial'), $imageName);
            $updateData['image'] = $imageName;
        }

        Testimonial::where('id', $id)->update($updateData);

        flash()->addSuccess('Record Updated');

        return redirect('testimonials-index');
    }

    public function deleteTestimonial($id)
    {
        try {
            $Testimonial = Testimonial::find($id);

            if (!$Testimonial) {
                session()->flash('error', 'Testimonial not found');
            } else {
                $Testimonial->delete();
                session()->flash('success', 'Testimonial deleted successfully');
            }

            return redirect()->back();
        } catch (\Exception $e) {
            session()->flash('error', 'An error occurred while deleting the Testimonial');
            return redirect()->back();
        }
    }
    public function deleteNewsletter($id)
    {
        try {
            $Newsletter = Newsletter::find($id);

            if (!$Newsletter) {
                session()->flash('error', 'Newsletter not found');
            } else {
                $Newsletter->delete();
                session()->flash('success', 'Newsletter deleted successfully');
            }

            return redirect()->back();
        } catch (\Exception $e) {
            session()->flash('error', 'An error occurred while deleting the Newsletter');
            return redirect()->back();
        }
    }

    public function trustedLogoIndex()
    {
        $data['trustedlogo'] = Trusted_logo::get();

        return view('super_admin.trusted_logo.index')->with($data);
    }
    public function trustedLogoAdd()
    {
        return view('super_admin.trusted_logo.add');
    }
    public function trustedLogoStore(Request $request)
    {
        // dd($request);

        if ($request->hasFile('image')) {
            $imageName = time() . '.' . $request->image->getClientOriginalExtension();
            $request->image->move(public_path('trustedlogo'), $imageName);

            $insertData['image'] = $imageName;
        } else {
            $insertData['image'] = null;
        }

        $insertData['line'] = $request->line;

        Trusted_logo::create($insertData);

        flash()->addSuccess('Record Created');

        return redirect('trusted-logo-index');
    }
    public function trustedLogoEdit(Request $request,$id)
    {
        $data['trustedlogo'] = Trusted_logo::where('id',$id)->first();
        return view('super_admin.trusted_logo.edit')->with($data);
    }

    public function trustedLogoUpdate(Request $request, $id)
    {
        $validatedData = $request->validate([
            'line' => 'required|string|max:255',
            'image' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048',
        ]);

        $updateData = [
            'line' => $validatedData['line'],
        ];

        if ($request->hasFile('image')) {
            $imageName = time() . '.' . $request->image->getClientOriginalExtension();
            $request->image->move(public_path('trustedlogo'), $imageName);
            $updateData['image'] = $imageName;
        }

        Trusted_logo::where('id', $id)->update($updateData);

        flash()->addSuccess('Record Updated');

        return redirect('trusted-logo-index');
    }

    public function deleteTrustedLogo($id)
    {
        try {
            $trustedlogo = Trusted_logo::find($id);

            if (!$trustedlogo) {
                session()->flash('error', 'trusted logo not found');
            } else {
                $trustedlogo->delete();
                session()->flash('success', 'trusted logo deleted successfully');
            }

            return redirect()->back();
        } catch (\Exception $e) {
            session()->flash('error', 'An error occurred while deleting the trusted logo');
            return redirect()->back();
        }
    }

    public function featuresIndex()
    {
        $data['Features'] = Feature::get();

        return view('super_admin.features.index')->with($data);
    }
    public function featuresAdd()
    {
        return view('super_admin.features.add');
    }
    public function featuresStore(Request $request)
    {
        // dd($request);

        $insertData['heading'] = $request->heading;
        $insertData['description'] = $request->description;
        $insertData['row'] = $request->row;

        Feature::create($insertData);

        flash()->addSuccess('Record Created');

        return redirect('features-index');
    }
    public function subscribeToNewsletter(Request $request)
    {
        // dd($request);
        $insertData['email'] = $request->email;

        Newsletter::create($insertData);

        flash()->addSuccess('Submit Successfully');

        return redirect()->back();
    }
    public function featuresEdit(Request $request,$id)
    {
        $data['Features'] = Feature::where('id',$id)->first();
        return view('super_admin.features.edit')->with($data);
    }
    public function featuresUpdate(Request $request, $id)
    {
        // dd($request);
        // $validatedData = $request->validate([
        //     'heading' => 'required|string|max:255',
        //     'description' => 'required|string|max:255',
        //     'row' => 'required|string|max:255',
        // ]);

        $updateData = [
            'heading' => $request['heading'],
            'description' => $request['description'],
            'row' => $request['row'],
        ];

        Feature::where('id', $id)->update($updateData);

        flash()->addSuccess('Record Updated');

        return redirect('features-index');
    }
    public function deletefeatures($id)
    {
        try {
            $Feature = Feature::find($id);

            if (!$Feature) {
                session()->flash('error', 'Feature not found');
            } else {
                $Feature->delete();
                session()->flash('success', 'Feature deleted successfully');
            }

            return redirect()->back();
        } catch (\Exception $e) {
            session()->flash('error', 'An error occurred while deleting the Feature');
            return redirect()->back();
        }
    }
    public function contactToLedgematic(Request $request)
    {
        // dd($request);

        $insertData['name'] = $request->name;
        $insertData['email'] = $request->email;
        $insertData['message'] = $request->message;

            Contact_to_ledgematic::create($insertData);

        flash()->addSuccess('Record Created');

        return redirect()->back();
    }
    public function contactFormIndex()
    {
        $data['Contact_to_ledgematics'] = Contact_to_ledgematic::get();

        return view('super_admin.website_contact.contact-form-index')->with($data);
    }
    public function deleteContactForm($id)
    {
        try {
            $Contact_to_ledgematic = Contact_to_ledgematic::find($id);

            if (!$Contact_to_ledgematic) {
                session()->flash('error', 'Contact_to_ledgematic not found');
            } else {
                $Contact_to_ledgematic->delete();
                session()->flash('success', 'Contact deleted successfully');
            }

            return redirect()->back();
        } catch (\Exception $e) {
            session()->flash('error', 'An error occurred while deleting the Contact');
            return redirect()->back();
        }
    }
}
