<?php

use App\Http\Controllers\MainMenuStockSearchController;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\receivedController;
use App\Http\Controllers\ExpiryCheckController;
use App\Http\Controllers\SuperAdminT_c;


/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::get('/view-invoice/{id}/view_signatures', 'HomeController@view_signature');
Route::get('/item-units/{id}', 'Master\ItemUnitController@item_unit');

Route::get('search-keyword-number', 'MainMenu\SearchKeywordNumberController@search');
Route::post('search-keyword-number/search-result', 'MainMenu\SearchKeywordNumberController@searchResult');

Route::get('stock-search', 'MainMenu\StockSearchController@search');
Route::post('stock-search-result', 'MainMenu\StockSearchController@search_result');

//View Edit & Print Invoice
Route::get('view-edit-print-invoice-voucher', 'MainMenu\SearchInvoiceController@search');
Route::post('view-edit-print-invoice-voucher', 'MainMenu\SearchInvoiceController@search_result');

Route::get('/logout', 'Auth\LoginController@logout');


// Route::get('', function () {
//     $posts = DB::table('sa_received_voucher')->get();
    
//     return view('super_admin/superadmin-received-voucher',[
//         'posts' => $posts
//     ]);
// });

// Route::get('/received/voucher', 'receivedController@voucher');
Route::get('/received/voucher',[receivedController::class,'voucher']);

Route::get('/termscondition',[SuperAdminT_c::class,'edit']);
Route::post('termscondition/{id}', 'SuperAdminT_c@update');

Route::get('/check_expiry',[ExpiryCheckController::class,'check']);

Route::get('/client/index',[ExpiryCheckController::class,'index']);

Route::post('/upload-img',[ExpiryCheckController::class,'upload']);


Auth::routes();

Route::group(['middleware' => ['auth']], function() {


    Route::get('/', function () {
        return view('user.main_menu.index');
    });

    Route::get('/superindex', function () {
        return view('super_admin.superadmin-index');
    });

    Route::get('/dashboard', 'DashboardController@index');

    Route::get('/country/locations/{country_id}', 'MainMenu\CountryAndLocationController@countryLocations');
    Route::get('/country/locations/specific/{country_id}', 'MainMenu\CountryAndLocationController@countryLocationsSpecific');
    Route::get('/location/currency/{location_id}', 'MainMenu\CountryAndLocationController@locationCurrency');
    Route::get('/users-permission/{location_id}/{admin_user}/{id}', 'MainMenu\CountryAndLocationController@locationUsers');
    Route::get('/account-masters/maintain-account/purchase/{account_id}', 'MainMenu\CountryAndLocationController@maintain_account_purchase');
    Route::post('/account-masters/maintain-account/purchase', 'MainMenu\CountryAndLocationController@maintain_account_purchase_new');
    Route::get('/account-masters/maintain-account/sale/{account_id}', 'MainMenu\CountryAndLocationController@maintain_account_sale');
    Route::post('/account-masters/maintain-account/sale', 'MainMenu\CountryAndLocationController@maintain_account_sale_new');
    Route::get('/purchase-invoice/amount/purchase/{id}', 'MainMenu\CountryAndLocationController@amount_purchase');
    Route::get('/sale-invoice/amount/sale/{id}', 'MainMenu\CountryAndLocationController@amount_sale');
    Route::get('/warehouse-items/{id}', 'MainMenu\CountryAndLocationController@warehouseItem');

    Route::get('/purchase-invoice/item/{imei_serial_no}', 'Transaction\WarehouseStockTransferController@purchaseInvoiceItem');


    Route::get('/change-password', 'DashboardController@changePassword');
    Route::post('/change-password', 'DashboardController@updatePassword');


    Route::group(['prefix' => 'main-menu'], function () {

        //User and Privilege Controller
        Route::get('/users-and-privileges', 'MainMenu\UserAndPrivilegeController@index');

        Route::get('/users-and-privileges/super-users', 'MainMenu\UserAndPrivilegeController@SuperUsersList');
        Route::post('/users-and-privileges/create-super-admin', 'MainMenu\UserAndPrivilegeController@createSuperAdmin');
        Route::get('/users-and-privileges/super-admin/{id}/edit', 'MainMenu\UserAndPrivilegeController@editSuperAdmin');
        Route::patch('/users-and-privileges/update-super-admin/{id}', 'MainMenu\UserAndPrivilegeController@updateSuperAdmin');

        Route::get('/users-and-privileges/limited-users', 'MainMenu\UserAndPrivilegeController@LimitedUsersList');
        Route::post('/users-and-privileges/create-limited-user', 'MainMenu\UserAndPrivilegeController@createUser');
        Route::get('/users-and-privileges/limited-user/{id}/edit', 'MainMenu\UserAndPrivilegeController@edit');
        Route::patch('/users-and-privileges/update-limited-user/{id}', 'MainMenu\UserAndPrivilegeController@update');
        Route::get('/users-and-privileges/limited-user/{id}/change-password', 'MainMenu\UserAndPrivilegeController@changePassword');
        Route::post('/users-and-privileges/limited-user/change-password', 'MainMenu\UserAndPrivilegeController@updatePassword');

        // Route::get('/users-and-privileges/create', 'MainMenu\UserAndPrivilegeController@create');
        // Route::delete('/users-and-privileges/{id}', 'MainMenu\UserAndPrivilegeController@destroy');


        //Country and Location Controller
        Route::get('/countries-and-locations', 'MainMenu\CountryAndLocationController@index');
        Route::get('/countries-and-locations/create', 'MainMenu\CountryAndLocationController@create');
        Route::get('/countries-and-locations/country/{id}/edit', 'MainMenu\CountryAndLocationController@edit_country');
        Route::get('/countries-and-locations/location/{id}/edit', 'MainMenu\CountryAndLocationController@edit_location');
        Route::patch('/countries-and-locations/country/{id}/update', 'MainMenu\CountryAndLocationController@update_country');
        Route::patch('/countries-and-locations/location/{id}/update', 'MainMenu\CountryAndLocationController@update_location');
        Route::post('/countries-and-locations/create-country', 'MainMenu\CountryAndLocationController@createCountry');
        Route::post('/countries-and-locations/create-location', 'MainMenu\CountryAndLocationController@createLocation');
        Route::patch('/countries-and-locations/{id}', 'MainMenu\CountryAndLocationController@update');
        Route::delete('/countries-and-locations/location/{id}', 'MainMenu\CountryAndLocationController@destroy_location');
        Route::delete('/countries-and-locations/country/{id}', 'MainMenu\CountryAndLocationController@destroy_country');

        //Remainder Controller
        Route::get('/remainders', 'MainMenu\RemainderController@index');
        Route::post('/remainders/', 'MainMenu\RemainderController@store');
        Route::get('/remainder/{id}/view', 'MainMenu\RemainderController@show');
        Route::delete('/remainder/{id}', 'MainMenu\RemainderController@destroy');
        // Route::get('/remainders/create', 'MainMenu\RemainderController@create');
        // Route::get('/remainders/{id}/edit', 'MainMenu\RemainderController@edit');
        // Route::patch('/remainders/{id}', 'MainMenu\RemainderController@update');


        //Notification Controller
        Route::get('/notifications', 'MainMenu\NotificationController@index');
        Route::post('/notification', 'MainMenu\NotificationController@store');
        Route::get('/notification/{id}/view', 'MainMenu\NotificationController@show');
        Route::delete('/notification/{id}', 'MainMenu\NotificationController@destroy');

        //Chat Controller
        Route::get('/chat', 'MainMenu\ChatController@index');
        Route::get('/live-chat/', 'MainMenu\ChatController@live');

        //Trial Balance Controller
        Route::get('/trial-balance/select-date', 'MainMenu\TrialBalanceController@display');
        Route::post('/trial-balance-report', 'MainMenu\TrialBalanceController@index');

        //Trial Balance Controller
        Route::get('/balance-sheet/select-date', 'MainMenu\BalanceSheetController@display');
        Route::post('/balance-sheet-report', 'MainMenu\BalanceSheetController@index');

        //Profit & Loss
        Route::get('/profit-and-loss/select-date', 'MainMenu\ProfitLossController@display');
        Route::post('/profit-and-loss-report', 'MainMenu\ProfitLossController@index');
    });

    //select Country and Location Controller
    Route::group(['prefix' => 'select-country-and-location'], function () {
        Route::get('/', 'SelectCountryAndLocationController@index');
        Route::post('/', 'SelectCountryAndLocationController@moveToDashboard');
    });

    //Master Controller
    Route::group(['prefix' => 'masters'], function () {

        Route::group(['prefix' => 'account-masters'], function () {

            Route::get('/customers', 'Master\AccountMaster\CustomerController@index');
            Route::get('/customers/create', 'Master\AccountMaster\CustomerController@create');
            Route::get('/customers/{id}/edit', 'Master\AccountMaster\CustomerController@edit');
            Route::post('/customers', 'Master\AccountMaster\CustomerController@store');
            Route::patch('/customers/{id}', 'Master\AccountMaster\CustomerController@update');
            Route::delete('/customers/{id}', 'Master\AccountMaster\CustomerController@destroy');
            Route::delete('/customers/{id}/softdelete', 'Master\AccountMaster\CustomerController@softdelete');

            Route::get('/{type}/docs/{id}', 'Master\AccountMaster\AccountMasterController@viewDocs');
            Route::post('/check-password/{id}', 'Master\AccountMaster\AccountMasterController@checkPassword');
            Route::get('/password/{id}', 'Master\AccountMaster\AccountMasterController@password');

            Route::get('/suppliers', 'Master\AccountMaster\SupplierController@index');
            Route::get('/suppliers/create', 'Master\AccountMaster\SupplierController@create');
            Route::get('/suppliers/{id}/edit', 'Master\AccountMaster\SupplierController@edit');
            Route::post('/suppliers', 'Master\AccountMaster\SupplierController@store');
            Route::patch('/suppliers/{id}', 'Master\AccountMaster\SupplierController@update');
            Route::delete('/suppliers/{id}', 'Master\AccountMaster\SupplierController@destroy');
            Route::delete('/suppliers/{id}/softdelete', 'Master\AccountMaster\SupplierController@softdelete');

            Route::get('/expenses', 'Master\AccountMaster\ExpenseController@index');
            Route::get('/expenses/create', 'Master\AccountMaster\ExpenseController@create');
            Route::get('/expenses/{id}/edit', 'Master\AccountMaster\ExpenseController@edit');
            Route::post('/expenses', 'Master\AccountMaster\ExpenseController@store');
            Route::patch('/expenses/{id}', 'Master\AccountMaster\ExpenseController@update');
            Route::delete('/expenses/{id}', 'Master\AccountMaster\ExpenseController@destroy');
            Route::delete('/expenses/{id}/softdelete', 'Master\AccountMaster\ExpenseController@softdelete');

            Route::get('/other-accounts', 'Master\AccountMaster\OtherAccountController@index');
            Route::get('/other-accounts/create', 'Master\AccountMaster\OtherAccountController@create');
            Route::get('/other-accounts/{id}/edit', 'Master\AccountMaster\OtherAccountController@edit');
            Route::post('/other-accounts', 'Master\AccountMaster\OtherAccountController@store');
            Route::patch('/other-accounts/{id}', 'Master\AccountMaster\OtherAccountController@update');
            Route::delete('/other-accounts/{id}', 'Master\AccountMaster\OtherAccountController@destroy');
            Route::delete('/other-accounts/{id}/softdelete', 'Master\AccountMaster\OtherAccountController@softdelete');

            Route::get('/staff-and-salesmen', 'Master\AccountMaster\StaffAndSalesmanController@index');
            Route::get('/staff-and-salesmen/create', 'Master\AccountMaster\StaffAndSalesmanController@create');
            Route::get('/staff-and-salesmen/{id}/edit', 'Master\AccountMaster\StaffAndSalesmanController@edit');
            Route::post('/staff-and-salesmen', 'Master\AccountMaster\StaffAndSalesmanController@store');
            Route::patch('/staff-and-salesmen/{id}', 'Master\AccountMaster\StaffAndSalesmanController@update');
            Route::delete('/staff-and-salesmen/{id}', 'Master\AccountMaster\StaffAndSalesmanController@destroy');
            Route::delete('/staff-and-salesmen/{id}/softdelete', 'Master\AccountMaster\StaffAndSalesmanController@softdelete');

        });

        Route::get('/currencies', 'Master\CurrencyController@index');
        Route::get('/currencies/create', 'Master\CurrencyController@create');
        Route::get('/currencies/{id}/edit', 'Master\CurrencyController@edit');
        Route::post('/currencies', 'Master\CurrencyController@store');
        Route::patch('/currencies/{id}', 'Master\CurrencyController@update');
        Route::delete('/currencies/{id}', 'Master\CurrencyController@destroy');

        Route::get('/warehouses', 'Master\WarehouseController@index');
        Route::get('/warehouses/create', 'Master\WarehouseController@create');
        Route::get('/warehouses/{id}/edit', 'Master\WarehouseController@edit');
        Route::post('/warehouses', 'Master\WarehouseController@store');
        Route::patch('/warehouses/{id}', 'Master\WarehouseController@update');
        Route::delete('/warehouses/{id}', 'Master\WarehouseController@destroy');
        Route::delete('/warehouses/{id}/softdelete', 'Master\WarehouseController@softdelete');

        Route::get('/companies', 'Master\CompanyController@index');
        Route::get('/companies/create', 'Master\CompanyController@create');
        Route::get('/companies/{id}/edit', 'Master\CompanyController@edit');
        Route::post('/companies', 'Master\CompanyController@store');
        Route::patch('/companies/{id}', 'Master\CompanyController@update');
        Route::delete('/companies/{id}', 'Master\CompanyController@destroy');

        Route::get('/period-closing', 'Master\PeriodClosingController@index');
        Route::get('/period-closing/create', 'Master\PeriodClosingController@create');
        // Route::get('/period-closing/{id}/edit', 'Master\PeriodClosingController@edit');
        // Route::post('/period-closing', 'Master\PeriodClosingController@store');
        // Route::patch('/period-closing/{id}', 'Master\PeriodClosingController@update');
        // Route::delete('/period-closing/{id}', 'Master\PeriodClosingController@destroy');

        Route::get('/item-groups', 'Master\ItemGroupController@index');
        Route::get('/item-groups/create', 'Master\ItemGroupController@create');
        Route::get('/item-groups/{id}/edit', 'Master\ItemGroupController@edit');
        Route::post('/item-groups', 'Master\ItemGroupController@store');
        Route::patch('/item-groups/{id}', 'Master\ItemGroupController@update');
        Route::delete('/item-groups/{id}', 'Master\ItemGroupController@destroy');
        Route::delete('/item-groups/{id}/softdelete', 'Master\ItemGroupController@softdelete');

        Route::get('/item-names', 'Master\ItemNameController@index');
        Route::get('/item-names/create', 'Master\ItemNameController@create');
        Route::get('/item-names/{id}/edit', 'Master\ItemNameController@edit');
        Route::post('/item-names', 'Master\ItemNameController@store');
        Route::patch('/item-names/{id}', 'Master\ItemNameController@update');
        Route::delete('/item-names/{id}', 'Master\ItemNameController@destroy');
        Route::delete('/item-names/{id}/softdelete', 'Master\ItemNameController@softdelete');

        Route::get('/item-units', 'Master\ItemUnitController@index');
        Route::get('/item-units/create', 'Master\ItemUnitController@create');
        Route::get('/item-units/{id}/edit', 'Master\ItemUnitController@edit');
        Route::post('/item-units', 'Master\ItemUnitController@store');
        Route::patch('/item-units/{id}', 'Master\ItemUnitController@update');
        Route::delete('/item-units/{id}', 'Master\ItemUnitController@destroy');
        Route::delete('/item-units/{id}/softdelete', 'Master\ItemUnitController@softdelete');



        Route::group(['prefix' => 'terms-and-conditions'], function () {

            Route::get('/approval-voucher', 'Master\TermsAndConditions\ApprovalVoucherController@index');
            Route::get('/approval-voucher/create', 'Master\TermsAndConditions\ApprovalVoucherController@create');
            Route::get('/approval-voucher/{id}/edit', 'Master\TermsAndConditions\ApprovalVoucherController@edit');
            Route::post('/approval-voucher', 'Master\TermsAndConditions\ApprovalVoucherController@store');
            Route::patch('/approval-voucher/{id}', 'Master\TermsAndConditions\ApprovalVoucherController@update');
            Route::delete('/approval-voucher/{id}', 'Master\TermsAndConditions\ApprovalVoucherController@destroy');

            Route::get('/sales-invoice', 'Master\TermsAndConditions\SalesInvoiceController@index');
            Route::get('/sales-invoice/create', 'Master\TermsAndConditions\SalesInvoiceController@create');
            Route::get('/sales-invoice/{id}/edit', 'Master\TermsAndConditions\SalesInvoiceController@edit');
            Route::post('/sales-invoice', 'Master\TermsAndConditions\SalesInvoiceController@store');
            Route::patch('/sales-invoice/{id}', 'Master\TermsAndConditions\SalesInvoiceController@update');
            Route::delete('/sales-invoice/{id}', 'Master\TermsAndConditions\SalesInvoiceController@destroy');

            Route::get('/purchase-invoice', 'Master\TermsAndConditions\PurchaseInvoiceController@index');
            Route::get('/purchase-invoice/create', 'Master\TermsAndConditions\PurchaseInvoiceController@create');
            Route::get('/purchase-invoice/{id}/edit', 'Master\TermsAndConditions\PurchaseInvoiceController@edit');
            Route::post('/purchase-invoice', 'Master\TermsAndConditions\PurchaseInvoiceController@store');
            Route::patch('/purchase-invoice/{id}', 'Master\TermsAndConditions\PurchaseInvoiceController@update');
            Route::delete('/purchase-invoice/{id}', 'Master\TermsAndConditions\PurchaseInvoiceController@destroy');

            Route::get('/sales-return-voucher', 'Master\TermsAndConditions\SalesReturnVoucherController@index');
            Route::get('/sales-return-voucher/create', 'Master\TermsAndConditions\SalesReturnVoucherController@create');
            Route::get('/sales-return-voucher/{id}/edit', 'Master\TermsAndConditions\SalesReturnVoucherController@edit');
            Route::post('/sales-return-voucher', 'Master\TermsAndConditions\SalesReturnVoucherController@store');
            Route::patch('/sales-return-voucher/{id}', 'Master\TermsAndConditions\SalesReturnVoucherController@update');
            Route::delete('/sales-return-voucher/{id}', 'Master\TermsAndConditions\SalesReturnVoucherController@destroy');

            Route::get('/purchase-return-voucher', 'Master\TermsAndConditions\PurchaseReturnVoucherController@index');
            Route::get('/purchase-return-voucher/create', 'Master\TermsAndConditions\PurchaseReturnVoucherController@create');
            Route::get('/purchase-return-voucher/{id}/edit', 'Master\TermsAndConditions\PurchaseReturnVoucherController@edit');
            Route::post('/purchase-return-voucher', 'Master\TermsAndConditions\PurchaseReturnVoucherController@store');
            Route::patch('/purchase-return-voucher/{id}', 'Master\TermsAndConditions\PurchaseReturnVoucherController@update');
            Route::delete('/purchase-return-voucher/{id}', 'Master\TermsAndConditions\PurchaseReturnVoucherController@destroy');
        });

    });

    //Transactions pages

    Route::get('/country/locations/stock-transfer/{country_id}', 'Transaction\CountryLocationWiseTransfer\StockTransferController@countryLocationsStock_transfer');
    Route::get('/country/locations/stock-transfer/warehouse/{country_id}', 'Transaction\CountryLocationWiseTransfer\StockTransferController@countryLocationsStock_transfer_warehouse');
    Route::get('/country/locations/stock-transfer/warehouse/to-item/{location_id}', 'Transaction\CountryLocationWiseTransfer\StockTransferController@countryLocationsStock_transfer_warehouse_to_item');

    Route::get('/country/locations/cash-transfer/{country_id}', 'Transaction\CountryLocationWiseTransfer\CashTransferController@countryLocationsCash_transfer');

    Route::group(['prefix' => 'transactions'], function () {

        //approval voucher
        Route::get('/approval-vouchers', 'Transaction\ApprovalVoucherController@index');
        Route::get('/approval-vouchers/create', 'Transaction\ApprovalVoucherController@create');
        Route::get('/approval-vouchers/{id}/edit', 'Transaction\ApprovalVoucherController@edit');
        Route::post('/approval-vouchers', 'Transaction\ApprovalVoucherController@store');
        Route::patch('/approval-vouchers/{id}', 'Transaction\ApprovalVoucherController@update');
        Route::delete('/approval-vouchers/{id}', 'Transaction\ApprovalVoucherController@destroy');
        Route::delete('/approval-vouchers/{id}/softdelete', 'Transaction\ApprovalVoucherController@softdelete');
        Route::get('/approval-vouchers/{id}/view', 'Transaction\ApprovalVoucherController@view');
        // Route::get('/approval-vouchers/{id}/view_signatures', 'Transaction\ApprovalVoucherController@view_signature');
        Route::get('/approval-vouchers/signature/{id}/create', 'Transaction\ApprovalVoucherController@signature');
        Route::post('/approval-vouchers/signature/{id}', 'Transaction\ApprovalVoucherController@signatureUpload');

        // country and location wise cash transfer
        // Route::get('/country-location-wise-cash-transfers', 'Transaction\CountryLocationWiseCashTransferController@index');
        // Route::get('/country-location-wise-cash-transfers/create', 'Transaction\CountryLocationWiseCashTransferController@create');
        // Route::get('/country-location-wise-cash-transfers/{id}/edit', 'Transaction\CountryLocationWiseCashTransferController@edit');
        // Route::post('/country-location-wise-cash-transfers', 'Transaction\CountryLocationWiseCashTransferController@store');
        // Route::patch('/country-location-wise-cash-transfers/{id}', 'Transaction\CountryLocationWiseCashTransferController@update');
        // Route::delete('/country-location-wise-cash-transfers/{id}', 'Transaction\CountryLocationWiseCashTransferController@destroy');

        // country and location wise stock transfers
        // Route::get('/country-location-wise-stock-transfers', 'Transaction\CountryLocationWiseStockTransferController@index');
        // Route::get('/country-location-wise-stock-transfers/create', 'Transaction\CountryLocationWiseStockTransferController@create');
        // Route::get('/country-location-wise-stock-transfers/{id}/edit', 'Transaction\CountryLocationWiseStockTransferController@edit');
        // Route::post('/country-location-wise-stock-transfers', 'Transaction\CountryLocationWiseStockTransferController@store');
        // Route::patch('/country-location-wise-stock-transfers/{id}', 'Transaction\CountryLocationWiseStockTransferController@update');
        // Route::delete('/country-location-wise-stock-transfers/{id}', 'Transaction\CountryLocationWiseStockTransferController@destroy');
        // Route::delete('/country-location-wise-stock-transfers/{id}/softdelete', 'Transaction\CountryLocationWiseStockTransferController@softdelete');


        //deposit and withdraw vouchers
        Route::get('/deposit-withdraw-vouchers', 'Transaction\DepositWithdrawVoucherController@index');
        Route::get('/deposit-withdraw-vouchers/create', 'Transaction\DepositWithdrawVoucherController@create');
        Route::get('/deposit-withdraw-vouchers/{id}/edit', 'Transaction\DepositWithdrawVoucherController@edit');
        Route::post('/deposit-withdraw-vouchers', 'Transaction\DepositWithdrawVoucherController@store');
        Route::patch('/deposit-withdraw-vouchers/{id}', 'Transaction\DepositWithdrawVoucherController@update');
        Route::delete('/deposit-withdraw-vouchers/{id}', 'Transaction\DepositWithdrawVoucherController@destroy');
        Route::delete('/deposit-withdraw-vouchers/{id}/softdelete', 'Transaction\DepositWithdrawVoucherController@softdelete');

        //warehouse stock transfer
        Route::get('/warehouse-stock-transfers', 'Transaction\WarehouseStockTransferController@index');
        Route::get('/warehouse-stock-transfers/create', 'Transaction\WarehouseStockTransferController@create');
        Route::get('/warehouse-stock-transfers/{id}/edit', 'Transaction\WarehouseStockTransferController@edit');
        Route::get('/warehouse-stock-transfers/{id}/details', 'Transaction\WarehouseStockTransferController@viewDetails');
        Route::post('/warehouse-stock-transfers', 'Transaction\WarehouseStockTransferController@store');
        Route::patch('/warehouse-stock-transfers/{id}', 'Transaction\WarehouseStockTransferController@update');
        Route::delete('/warehouse-stock-transfers/{id}', 'Transaction\WarehouseStockTransferController@destroy');
        Route::delete('/warehouse-stock-transfers/{id}/softdelete', 'Transaction\WarehouseStockTransferController@softdelete');


        //inventory opening balances
        Route::get('/inventory-opening-balances', 'Transaction\InventoryOpeningBalanceController@index');
        Route::get('/inventory-opening-balances/create', 'Transaction\InventoryOpeningBalanceController@create');
        Route::get('/inventory-opening-balances/{id}/edit', 'Transaction\InventoryOpeningBalanceController@edit');
        Route::post('/inventory-opening-balances', 'Transaction\InventoryOpeningBalanceController@store');
        Route::patch('/inventory-opening-balances/{id}', 'Transaction\InventoryOpeningBalanceController@update');
        Route::delete('/inventory-opening-balances/{id}', 'Transaction\InventoryOpeningBalanceController@destroy');

        //journal_vouchers
        Route::get('/journal-vouchers', 'Transaction\JournalVoucherController@index');
        Route::get('/journal-vouchers/create', 'Transaction\JournalVoucherController@create');
        Route::get('/journal-vouchers/{id}/edit', 'Transaction\JournalVoucherController@edit');
        Route::post('/journal-vouchers', 'Transaction\JournalVoucherController@store');
        Route::patch('/journal-vouchers/{id}', 'Transaction\JournalVoucherController@update');
        Route::delete('/journal-vouchers/{id}', 'Transaction\JournalVoucherController@destroy');
        Route::delete('/journal-vouchers/{id}/softdelete', 'Transaction\JournalVoucherController@softdelete');

        //purchase invoice
        Route::get('/purchase-invoices', 'Transaction\PurchaseInvoiceController@index');
        Route::get('/purchase-invoices/create', 'Transaction\PurchaseInvoiceController@create');
        Route::get('/purchase-invoices/{id}/edit', 'Transaction\PurchaseInvoiceController@edit');
        Route::post('/purchase-invoices', 'Transaction\PurchaseInvoiceController@store');
        Route::patch('/purchase-invoices/{id}', 'Transaction\PurchaseInvoiceController@update');
        Route::delete('/purchase-invoices/{id}', 'Transaction\PurchaseInvoiceController@destroy');
        Route::get('/purchase-invoices/{id}/view', 'Transaction\PurchaseInvoiceController@view');
        Route::delete('/purchase-invoices/{id}/softdelete', 'Transaction\PurchaseInvoiceController@softdelete');
        Route::get('/purchase-invoices/signature/{id}/create', 'Transaction\PurchaseInvoiceController@signature');
        Route::post('/purchase-invoices/signature/{id}', 'Transaction\PurchaseInvoiceController@signatureUpload');

        //purchase return vouchers
        Route::get('/purchase-return-vouchers', 'Transaction\PurchaseReturnVoucherController@index');
        Route::get('/purchase-return-vouchers/create', 'Transaction\PurchaseReturnVoucherController@create');
        Route::get('/purchase-return-vouchers/{id}/edit', 'Transaction\PurchaseReturnVoucherController@edit');
        Route::post('/purchase-return-vouchers', 'Transaction\PurchaseReturnVoucherController@store');
        Route::patch('/purchase-return-vouchers/{id}', 'Transaction\PurchaseReturnVoucherController@update');
        Route::delete('/purchase-return-vouchers/{id}', 'Transaction\PurchaseReturnVoucherController@destroy');
        Route::get('/purchase-return-vouchers/{id}/view', 'Transaction\PurchaseReturnVoucherController@view');
        Route::delete('/purchase-return-vouchers/{id}/softdelete', 'Transaction\PurchaseReturnVoucherController@softdelete');
        Route::get('/purchase-return-vouchers/signature/{id}/create', 'Transaction\PurchaseReturnVoucherController@signature');
        Route::post('/purchase-return-vouchers/signature/{id}', 'Transaction\PurchaseReturnVoucherController@signatureUpload');

        //payment vouchers
        Route::get('/payment-vouchers', 'Transaction\PaymentVoucherController@index');
        Route::get('/payment-vouchers/create', 'Transaction\PaymentVoucherController@create');
        Route::get('/payment-vouchers/{id}/edit', 'Transaction\PaymentVoucherController@edit');
        Route::post('/payment-vouchers', 'Transaction\PaymentVoucherController@store');
        Route::patch('/payment-vouchers/{id}', 'Transaction\PaymentVoucherController@update');
        Route::delete('/payment-vouchers/{id}', 'Transaction\PaymentVoucherController@destroy');
        Route::delete('/payment-vouchers/{id}/softdelete', 'Transaction\PaymentVoucherController@softdelete');

        // receipt vouchers
        Route::get('/receipt-vouchers', 'Transaction\ReceiptVoucherController@index');
        Route::get('/receipt-vouchers/create', 'Transaction\ReceiptVoucherController@create');
        Route::get('/receipt-vouchers/{id}/edit', 'Transaction\ReceiptVoucherController@edit');
        Route::post('/receipt-vouchers', 'Transaction\ReceiptVoucherController@store');
        Route::patch('/receipt-vouchers/{id}', 'Transaction\ReceiptVoucherController@update');
        Route::delete('/receipt-vouchers/{id}', 'Transaction\ReceiptVoucherController@destroy');
        Route::delete('/receipt-vouchers/{id}/softdelete', 'Transaction\ReceiptVoucherController@softdelete');

        //sale return vouchers
        Route::get('/sales-return-vouchers', 'Transaction\SalesReturnVoucherController@index');
        Route::get('/sales-return-vouchers/create', 'Transaction\SalesReturnVoucherController@create');
        Route::get('/sales-return-vouchers/{id}/edit', 'Transaction\SalesReturnVoucherController@edit');
        Route::post('/sales-return-vouchers', 'Transaction\SalesReturnVoucherController@store');
        Route::patch('/sales-return-vouchers/{id}', 'Transaction\SalesReturnVoucherController@update');
        Route::delete('/sales-return-vouchers/{id}', 'Transaction\SalesReturnVoucherController@destroy');
        Route::get('/sales-return-vouchers/{id}/view', 'Transaction\SalesReturnVoucherController@view');
        Route::delete('/sales-return-vouchers/{id}/softdelete', 'Transaction\SalesReturnVoucherController@softdelete');
        Route::get('/sales-return-vouchers/signature/{id}/create', 'Transaction\SalesReturnVoucherController@signature');
        Route::post('/sales-return-vouchers/signature/{id}', 'Transaction\SalesReturnVoucherController@signatureUpload');

        //sales invoices
        Route::get('/sales-invoices', 'Transaction\SaleInvoiceController@index');
        Route::get('/sales-invoices/create', 'Transaction\SaleInvoiceController@create');
        Route::get('/sales-invoices/{id}/edit', 'Transaction\SaleInvoiceController@edit');
        Route::post('/sales-invoices', 'Transaction\SaleInvoiceController@store');
        Route::patch('/sales-invoices/{id}', 'Transaction\SaleInvoiceController@update');
        Route::delete('/sales-invoices/{id}', 'Transaction\SaleInvoiceController@destroy');
        Route::get('/sales-invoices/{id}/view', 'Transaction\SaleInvoiceController@view');
        Route::delete('/sales-invoices/{id}/softdelete', 'Transaction\SaleInvoiceController@softdelete');
        Route::get('/sales-invoices/signature/{id}/create', 'Transaction\SaleInvoiceController@signature');
        Route::post('/sales-invoices/signature/{id}', 'Transaction\SaleInvoiceController@signatureUpload');



        Route::group(['prefix' => 'country-location-wise-transfer'], function () {

            Route::get('/stock-transfers', 'Transaction\CountryLocationWiseTransfer\StockTransferController@index');
            Route::get('/stock-transfers/create', 'Transaction\CountryLocationWiseTransfer\StockTransferController@create');
            Route::get('/stock-transfers/{id}/edit', 'Transaction\CountryLocationWiseTransfer\StockTransferController@edit');
            Route::post('/stock-transfers', 'Transaction\CountryLocationWiseTransfer\StockTransferController@store');
            Route::patch('/stock-transfers/{id}', 'Transaction\CountryLocationWiseTransfer\StockTransferController@update');
            Route::delete('/stock-transfers/{id}', 'Transaction\CountryLocationWiseTransfer\StockTransferController@destroy');
            Route::delete('/stock-transfers/{id}/softdelete', 'Transaction\CountryLocationWiseTransfer\StockTransferController@softdelete');

            Route::get('/cash-transfers', 'Transaction\CountryLocationWiseTransfer\CashTransferController@index');
            Route::get('/cash-transfers/create', 'Transaction\CountryLocationWiseTransfer\CashTransferController@create');
            Route::get('/cash-transfers/{id}/edit', 'Transaction\CountryLocationWiseTransfer\CashTransferController@edit');
            Route::post('/cash-transfers', 'Transaction\CountryLocationWiseTransfer\CashTransferController@store');
            Route::patch('/cash-transfers/{id}', 'Transaction\CountryLocationWiseTransfer\CashTransferController@update');
            Route::delete('/cash-transfers/{id}', 'Transaction\CountryLocationWiseTransfer\CashTransferController@destroy');
            Route::delete('/cash-transfers/{id}/softdelete', 'Transaction\CountryLocationWiseTransfer\CashTransferController@softdelete');
        });
    });
    Route::group(['prefix' => 'reports'], function () {

        //approval voucher report
        Route::get('/approval-vouchers-report', 'Report\ApprovalReportController@index');
        Route::get('/approval-vouchers-report/create/{id}', 'Report\ApprovalReportController@create');
        Route::get('/approval-vouchers-report/pdfview' , 'Report\ApprovalReportController@pdfView');
        //Balance Sheet report
        Route::get('/balance-sheet-select', 'Report\BalanceSheetController@display');
        Route::post('/balance-sheet', 'Report\BalanceSheetController@index');
        Route::get('/balance-sheet/pdfview' , 'Report\BalanceSheetController@pdfView');
        //Purchase report
        Route::get('/purchase-report-select', 'Report\PurchaseReportController@display');
        Route::post('/purchase-report', 'Report\PurchaseReportController@index');
        Route::get('/purchase-invoice/pdfview/{from_date}/{to_date}' , 'Report\PurchaseReportController@pdfView');
        //Sale report
        Route::get('/sale-report-select', 'Report\SaleReportController@display');
        Route::post('/sale-report', 'Report\SaleReportController@index');
        Route::get('/sale-invoice/pdfview/{from_date}/{to_date}' , 'Report\SaleReportController@pdfView');
        //Group Summary
        Route::get('/group-summary-select', 'Report\GroupSummaryController@display');
        Route::post('/group-summary', 'Report\GroupSummaryController@index');
        Route::get('/group-summary/pdfview/{from_date}/{to_date}/{id}' , 'Report\GroupSummaryController@pdfView');
        //Official VAT Report
        Route::get('/vat-report-select', 'Report\VatReportController@display');
        Route::post('/vat-report', 'Report\VatReportController@index');
        Route::get('/vat-report/pdfview/{from_date}/{to_date}' , 'Report\VatReportController@pdfView');
        //Statement of accounts
        Route::get('/statement-of-accounts', 'Report\StatementOfAccountsController@display');
        Route::post('/statement-of-accounts/class', 'Report\StatementOfAccountsController@index_class');
        Route::post('/statement-of-accounts/ledger', 'Report\StatementOfAccountsController@index_ledger');
        Route::post('/statement-of-accounts/ledger/billwise', 'Report\StatementOfAccountsController@index_ledger_billwise');
        Route::post('/statement-of-accounts/ledger/vatwise', 'Report\StatementOfAccountsController@index_ledger_vatwise');
        Route::get('/statement-of-accounts/ledgerInfo/{id}', 'Report\StatementOfAccountsController@infoledger');

        Route::get('/statement-of-accounts/pdfview/ledger/{from_date}/{to_date}/{id}' , 'Report\StatementOfAccountsController@pdfViewLedger');
        Route::get('/statement-of-accounts/pdfview/ledger/billwise/{from_date}/{to_date}/{id}' , 'Report\StatementOfAccountsController@pdfViewLedgerBillwise');
        Route::get('/statement-of-accounts/pdfview/ledger/vatwise/{from_date}/{to_date}/{id}' , 'Report\StatementOfAccountsController@pdfViewLedgerVatwise');
        Route::get('/statement-of-accounts/pdfview/class/{from_date}/{to_date}/{id}' , 'Report\StatementOfAccountsController@pdfViewClass');
        //Day Book
        Route::get('/day-book', 'Report\DayBookController@display');
        Route::post('/day-book-report', 'Report\DayBookController@index');
        Route::get('/day-book/pdfview/{from_date}/{to_date}' , 'Report\DayBookController@pdfView');
        //Salesman Report
        Route::get('/salesman-report-select', 'Report\SalesmanReportController@display');
        Route::post('/salesman-report', 'Report\SalesmanReportController@index');
        Route::get('/salesman-report/pdfview/{from_date}/{to_date}/{id}' , 'Report\SalesmanReportController@pdfView');
        //Stock Report
        Route::get('/stock-report-select', 'Report\StockReportController@display');
        Route::post('/stock-report', 'Report\StockReportController@index');
        Route::get('/stock-report/pdfview/item/{from_date}/{to_date}/{id}/{show_cost}' , 'Report\StockReportController@pdfViewItem');
        Route::get('/stock-report/pdfview/group/{from_date}/{to_date}/{id}/{show_cost}' , 'Report\StockReportController@pdfViewGroup');
        Route::get('/stock-report/pdfview/complete/{from_date}/{to_date}/{show_cost}' , 'Report\StockReportController@pdfViewComplete');
        //Trial Balance Report
        Route::get('/trial-balance-report-select', 'Report\TrialBalanceReportController@display');
        Route::post('/trial-balance-report', 'Report\TrialBalanceReportController@index');
        Route::get('/trial-balance-report/pdfview/{from_date}/{to_date}' , 'Report\TrialBalanceReportController@pdfView');
        //Profit & Loss Report
        Route::get('/profit-loss-report-select', 'Report\ProfitLossReportController@display');
        Route::post('/profit-loss-report', 'Report\ProfitLossReportController@index');
        Route::get('/profit-loss-report/pdfview/{from_date}/{to_date}' , 'Report\ProfitLossReportController@pdfView');
    });


    Route::group(['prefix' => 'others'], function () {
        Route::get('admin-remainders', 'RemainderController@adminRemainder');
        Route::get('remainders', 'RemainderController@index');
        Route::get('remainders/create', 'RemainderController@create');
        Route::post('remainders', 'RemainderController@store');
        Route::delete('remainders/{id}', 'RemainderController@destroy');

        Route::get('notifications', 'NotificationsController@index');
        Route::get('document-expiry', 'DashboardController@document_expiry');
    });

});

        Route::get('login', 'AuthController@login')->name('login');
        Route::post('sign-in', 'AuthController@login_submit');
        Route::get('verification', 'AuthController@verification');
        Route::post('verify', 'AuthController@verify');
        Route::get('forget-password', 'AuthController@forget_password');
        Route::post('reset', 'AuthController@reset');
        Route::get('reset-pass/{id}', 'AuthController@reset_pass');
        Route::post('reset-password', 'AuthController@reset_password');
        Route::get('logout', 'AuthController@logout');
        Route::get('resend', 'AuthController@resend');
        Route::get('dashboard', 'SuperadminController@index');

        Route::resource('client', ClientController::class);
        Route::post('client/store', 'ClientController@store');
        Route::get('client/view/{id}', 'ClientController@show');
        Route::get('client/edit/{id}', 'ClientController@edit');
        Route::post('client/update/{id}', 'ClientController@update');

        Route::get('company', 'CompanyController@index');
        Route::get('company/add', 'CompanyController@add');
        Route::post('company/insert', 'CompanyController@insert');
        Route::get('company/view/{id}', 'CompanyController@view');
        Route::get('company/edit/{id}', 'CompanyController@edit');
        Route::post('company/update/{id}', 'CompanyController@update');
        Route::get('company/update/{id}', 'CompanyController@update');

      

