<?php

namespace App\Http\Controllers\MainMenu;

use App\User;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Hash;
use DB;
use Auth;
use Session;

use App\Country;
use App\Location;
use App\LocationPermission;
use App\LocationPermissionTrack;
use Illuminate\Support\Facades\DB as FacadesDB;
use Illuminate\Support\Facades\Hash as FacadesHash;
use Spatie\Permission\Models\Role;
use Spatie\Permission\Models\Permission;

class UserAndPrivilegeController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $user = Auth::user();
        if (!$user->can('users-and-privileges-master')) {
            abort(403, 'Unauthorized action.');
        }

        $countries = Country::all();
        $locations = Location::all();
        return view('user.main_menu.users_and_privileges.index', compact('countries', 'locations'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function createSuperAdmin(Request $request)
    {
        // $role = Role::create(['name' => 'super-admin']);
        // $role->givePermissionTo(Permission::all());

        // return redirect()->route('users.index')
        // ->with('success','User created successfully');

        $this->validate($request, [
            'email' => 'required|email|unique:users,email',
            'password' => 'required|same:confirm-password',
        ]);

        $input = $request->all();
        $input['name'] = 'Super Admin';
        $input['password'] = Hash::make($input['password']);

        $user = User::create($input);
        $user->assignRole('super-admin');
        // $user->givePermissionTo('full');

        Session::flash('alert-success','User created successfully');
        return redirect('/main-menu/users-and-privileges');
    }

    public function createUser(Request $request)
    {

        DB::beginTransaction();

        try {
            $this->validate($request, [
                'email' => 'required|email|unique:users,email',
                'password' => 'required|same:confirm-password',
            ]);

            $input = $request->all();
            $input['name'] = 'User';
            $input['password'] = Hash::make($input['password']);


            $user = User::create($input);


            if ($request->option == "all_countries_locations") {
                // dd("All Countries And Locations");
                $locations = Location::all();
                // dd($locations);
                foreach ($locations as $location) {
                    $location_permission = new LocationPermission;
                    $location_permission->country_id = $location->country_id;
                    $location_permission->location_id = $location->id;
                    $location_permission->user_id = $user-> id;
                    $location_permission->save();
                }
            }
            elseif ($request->option == "multiple_country_all_locations") {
                // dd("Multiple Countries All Locations");
                foreach($request->multiple_country as $country){
                    $locations = Location::Where('country_id', $country)->get();
                    foreach ($locations as $location) {
                        $location_permission = new LocationPermission;
                        $location_permission->country_id = $location->country_id;
                        $location_permission->location_id = $location->id;
                        $location_permission->user_id = $user-> id;
                        $location_permission->save();
                    }
                }
            }
            elseif ($request->option == "specific_country_multiple_locations") {
                // dd($request->single_country);
                // $locations = Location::Where('country_id', $request->single_country)->get();
                foreach ($request->location as $location) {
                    $location_permission = new LocationPermission;
                    $location_permission->country_id = $request->single_country;
                    $location_permission->location_id = $location;
                    $location_permission->user_id = $user-> id;
                    $location_permission->save();
                }
            }

            $location_permission_track = new LocationPermissionTrack();
            $location_permission_track->user_id = $user->id;
            $location_permission_track->permission_option = $request->option;
            $location_permission_track->save();

            $user->assignRole('user');
            $user->givePermissionTo($request-> permissions);

            DB::commit();
            Session::flash('alert-success','User created successfully');
            return redirect('/main-menu/users-and-privileges');
        }catch(Exception $e) {
            DB::rollback();
            return redirect()->back()->withErrors($e);
        }
    }

    public function SuperUsersList()
    {
        $user = Auth::user();
        if (!$user->can('users-and-privileges-master')) {
            abort(403, 'Unauthorized action.');
        }

        $users = User::all();
        $super_users = [];
        foreach ($users as $user) {
            if ($user->hasRole('super-admin')) {
                $super_users[] = $user;
            }
        }
        return view('user.main_menu.users_and_privileges.super_users_list', compact('super_users'));
    }
    public function LimitedUsersList()
    {
        $user = Auth::user();
        if (!$user->can('users-and-privileges-master')) {
            abort(403, 'Unauthorized action.');
        }

        $users = User::all();
        $limited_users = [];
        foreach ($users as $user) {
            if ($user->hasRole('user')) {
                $limited_users[] = $user;
            }
        }
        return view('user.main_menu.users_and_privileges.limited_users_list', compact('limited_users'));
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\User  $user
     * @return \Illuminate\Http\Response
     */
    public function show(User $user)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\User  $user
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $user = Auth::user();
        if (!$user->can('users-and-privileges-master')) {
            abort(403, 'Unauthorized action.');
        }

        $user = User::Find($id);
        $user_permissions = $user->getAllPermissions()->pluck('name');
        $countries = Country::all();
        $location_permission_track = LocationPermissionTrack::where('user_id', $user->id)->first();
        $location_permissions = LocationPermission::where('user_id', $user->id)->get();
        $selected_countries = [];
        if ($location_permission_track->permission_option == "multiple_country_all_locations") {
            $selected_countries = LocationPermission::where('user_id', $user->id)->pluck('country_id');
        }
        $selected_country = "";
        $locations = [];
        $locations_selected = [];
        if ($location_permission_track->permission_option == "specific_country_multiple_locations") {
            $selected_country = LocationPermission::where('user_id', $user->id)->pluck('country_id')->first();
            $locations = Location::Where('country_id', $selected_country)->get();
            $locations_selected = LocationPermission::where('user_id', $user->id)->pluck('location_id');
        }
        // dd($locations_selected);

        return view('user.main_menu.users_and_privileges.edit_limited_user', compact('locations_selected','locations','selected_country','selected_countries','location_permission_track','countries','user', 'user_permissions'));
    }

    public function editSuperAdmin($id){
        $user = Auth::user();
        if (!$user->can('users-and-privileges-master')) {
            abort(403, 'Unauthorized action.');
        }

        $user = User::Find($id);
        return view('user.main_menu.users_and_privileges.edit_super_admin', compact('user'));
    }

    public function updateSuperAdmin(Request $request)
    {
        $this->validate($request, [

            'email' => 'required',
        ]);
        $user = User::Find($request->id);
        $user->email = $request->email;
        $user->save();
        Session::flash('alert-success','User Updated successfully');
        return redirect('/main-menu/users-and-privileges/super-users');
    }

    public function changePassword($id)
    {
        $user = Auth::user();
        if (!$user->can('users-and-privileges-master')) {
            abort(403, 'Unauthorized action.');
        }

        $user = User::Find($id);
        return view('user.main_menu.users_and_privileges.change_limited_user_password', compact('user'));
    }

    public function updatePassword(Request $request)
    {
        $this->validate($request, [

            'password' => 'required|same:confirm-password',
        ]);
        $user = User::Find($request->id);
        $user->password = Hash::make($request->password);
        $user->save();
        Session::flash('alert-success','User Password Updated successfully');
        return redirect('/main-menu/users-and-privileges/limited-users');
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\User  $user
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        DB::beginTransaction();

        try {
            $user = User::Find($id);

            LocationPermission::where('user_id', $id)->delete();

            if ($request->option == "all_countries_locations") {
                $locations = Location::all();
                foreach ($locations as $location) {
                    $location_permission = new LocationPermission;
                    $location_permission->country_id = $location->country_id;
                    $location_permission->location_id = $location->id;
                    $location_permission->user_id = $user-> id;
                    $location_permission->save();
                }
            }
            elseif ($request->option == "multiple_country_all_locations") {
                foreach($request->multiple_country as $country){
                    $locations = Location::Where('country_id', $country)->get();
                    foreach ($locations as $location) {
                        $location_permission = new LocationPermission;
                        $location_permission->country_id = $location->country_id;
                        $location_permission->location_id = $location->id;
                        $location_permission->user_id = $user-> id;
                        $location_permission->save();
                    }
                }
            }
            elseif ($request->option == "specific_country_multiple_locations") {
                foreach ($request->location as $location) {
                    $location_permission = new LocationPermission;
                    $location_permission->country_id = $request->single_country;
                    $location_permission->location_id = $location;
                    $location_permission->user_id = $user-> id;
                    $location_permission->save();
                }
            }

            LocationPermissionTrack::where('user_id', $id)->delete();

            $location_permission_track = new LocationPermissionTrack();
            $location_permission_track->user_id = $user->id;
            $location_permission_track->permission_option = $request->option;
            $location_permission_track->save();

            $user->syncPermissions();

            $user->givePermissionTo($request-> permissions);

            DB::commit();
            Session::flash('alert-success','User updated successfully');
            return redirect('/main-menu/users-and-privileges');
        }catch(Exception $e) {
            DB::rollback();
            return redirect()->back()->withErrors($e);
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\User  $user
     * @return \Illuminate\Http\Response
     */
    public function destroy(User $user)
    {
        //
    }
}
