<?php

namespace App\Http\Controllers\Report;

use App\AccountMastersAccountsDetail;
use App\ClassOfAccount;
use App\Currency;
use App\PaymentVoucher;
use App\ItemGroup;
use App\Http\Controllers\Controller;
use App\Services\Utils;
use Illuminate\Http\Request;
use Auth;

class BalanceSheetController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $user = Auth::user();
        if (!$user->can('balance-sheet-report')) {
            abort(403, 'Unauthorized action.');
        }

        // dd($request->all());
        $location_id = Utils::getLocation();
        $from_date = $request->from_date;
        $to_date = $request->to_date;

        $bank_account_total = 0;
        $bank_account_class = ClassOfAccount::Where('name', 'Bank Account')->first();
        $bank_account = $this->classOfAccount($bank_account_class->id, $location_id, $from_date, $to_date);
        foreach ($bank_account as $bank) {
            $bank_account_total = $bank_account_total + $bank['closing_balance'];
        }
        // dd($bank_account);

        $cash_in_hand_total = 0;
        $cash_in_hand_class = ClassOfAccount::Where('name', 'Cash in Hand')->first();
        $cash_in_hand = $this->classOfAccount($cash_in_hand_class->id, $location_id, $from_date, $to_date);
        foreach ($cash_in_hand as $item) {
            $cash_in_hand_total = $cash_in_hand_total + $item['closing_balance'];
        }
        // dd($cash_in_hand_total);

        $advance_total = 0;
        $advance_class = ClassOfAccount::Where('name', 'Advance')->first();
        $advance = $this->classOfAccount($advance_class->id, $location_id, $from_date, $to_date);
        foreach ($advance as $item) {
            $advance_total = $advance_total + $item['closing_balance'];
        }
        // dd($advance_total);

        $stock_in_hand_total = 0;
        // $stock_in_hand_class = ClassOfAccount::Where('name', 'Stock in Hand')->first();
        // $stock_in_hand = $this->classOfAccount($stock_in_hand_class->id, $location_id, $from_date, $to_date);
        // foreach ($stock_in_hand as $item) {
        //     $stock_in_hand_total = $stock_in_hand_total + $item['closing_balance'];
        // }
         $groups = ItemGroup::with(['item_names.purchase_sales_transfer_stock_tracks' => function($q) use ($location_id, $from_date, $to_date) {
            $q->where('location_id', $location_id)->Where('created_at', '>=' , '2000-01-01'.' 00:00:00')->Where('created_at', '<=' , $to_date.' 23:59:59');}])->get();

            foreach ($groups as $key => $group) {
                foreach ($group->item_names as $key => $item_name) {
                    foreach ($item_name->purchase_sales_transfer_stock_tracks as $key => $purchase_sales_transfer_stock_track) {
                        if ($purchase_sales_transfer_stock_track->quantity != 0) {
                            $stock_in_hand_total = $stock_in_hand_total + $purchase_sales_transfer_stock_track->amount;
                        }
                    }
                }
            }
            // return $stock_in_hand_total;

        $sundry_debtors_total = 0;
        $sundry_debtors_class = ClassOfAccount::Where('name', 'Sundry Debtors')->first();
        $sundry_debtors = $this->classOfAccount($sundry_debtors_class->id, $location_id, $from_date, $to_date);
        foreach ($sundry_debtors as $item) {
            $sundry_debtors_total = $sundry_debtors_total + $item['closing_balance'];
        }
        // dd($sundry_debtors_total);

        $current_assets = $bank_account_total + $cash_in_hand_total + $advance_total + $stock_in_hand_total + $sundry_debtors_total;
        // dd($current_assets);

        $sundry_creditors_total = 0;
        $sundry_creditors_class = ClassOfAccount::Where('name', 'Sundry Creditors')->first();
        $sundry_creditors = $this->classOfAccount($sundry_creditors_class->id, $location_id, $from_date, $to_date);
        foreach ($sundry_creditors as $item) {
            $sundry_creditors_total = $sundry_creditors_total + $item['closing_balance'];
        }
        // dd($sundry_creditors_total);

        $reserve_and_surplus_total = 0;
        $reserve_and_surplus_class = ClassOfAccount::Where('name', 'Reserves & Surplus')->first();
        $reserve_and_surplus = $this->classOfAccount($reserve_and_surplus_class->id, $location_id, $from_date, $to_date);
        foreach ($reserve_and_surplus as $item) {
            $reserve_and_surplus_total = $reserve_and_surplus_total + $item['closing_balance'];
        }
        // dd($reserve_and_surplus_total);

        $retained_earnings_total = 0;
        $retained_earnings_class = ClassOfAccount::Where('name', 'Retained Earnings')->first();
        $retained_earnings = $this->classOfAccount($retained_earnings_class->id, $location_id, $from_date, $to_date);
        foreach ($retained_earnings as $item) {
            $retained_earnings_total = $retained_earnings_total + $item['closing_balance'];
        }
        // dd($retained_earnings_total);


        $capital_account_total = 0;
        $capital_account_class = ClassOfAccount::Where('name', 'Capital Account')->first();
        $capital_account = $this->classOfAccount($capital_account_class->id, $location_id, $from_date, $to_date);
        foreach ($capital_account as $capital_act) {
            $capital_account_total = $capital_account_total + $capital_act['closing_balance'];
        }

        // $capital_account = $reserve_and_surplus_total + $retained_earnings_total;
        // $total = $capital_account + $sundry_creditors_total;

        $decimal = 0;

        $currency = Currency::Where('location_id', $location_id)->first();
        if ($currency) {
            $decimal = $currency->decimal_currency;
        }

        $vat_payable_receiveable = PaymentVoucher::sum('vat_amount');

        return view('user.reports.balance_sheet.index', compact('from_date', 'to_date', 'bank_account', 'bank_account_total', 'cash_in_hand', 'cash_in_hand_total', 'advance', 'advance_total', 'stock_in_hand_total', 'sundry_debtors', 'sundry_debtors_total', 'current_assets', 'sundry_creditors', 'sundry_creditors_total', 'reserve_and_surplus', 'reserve_and_surplus_total', 'retained_earnings', 'retained_earnings_total', 'capital_account_total', 'decimal', 'vat_payable_receiveable'));
    }

    public function classOfAccount($id, $location_id, $from_date, $to_date)
    {
        $trial_balance_closing_balance = [];
        $decimal = 0;

        $currency = Currency::Where('location_id', $location_id)->first();
        if ($currency) {
            $decimal = $currency->decimal_currency;
        }
        $class_of_account = ClassOfAccount::with(['account_master' => function($q) use ($location_id) {
            $q->where('location_id', $location_id);}])->where('id', $id)->first();
        foreach ($class_of_account->account_master as $account_master){
            $debit = 0;
            $credit = 0;
            $opening_balance = 0;
            $closing_balance = 0;
            $debit = AccountMastersAccountsDetail::Where('account_master_id', $account_master->id)->where('voucher_type', '!=', 'opening balance')->Where('date', '>=' , $from_date)->Where('date', '<=' , $to_date)->sum('debit');
            $credit = AccountMastersAccountsDetail::Where('account_master_id', $account_master->id)->where('voucher_type', '!=', 'opening balance')->Where('date', '>=' , $from_date)->Where('date', '<=' , $to_date)->sum('credit');
            $first_account = AccountMastersAccountsDetail::with('account_master')->Where('account_master_id', $account_master->id)->first();
            if($first_account){
                $with_opening_balance_debit = AccountMastersAccountsDetail::Where('account_master_id', $account_master->id)->Where('date', '>=' , $first_account->date)->Where('date', '<=' , date('Y-m-d', strtotime('-1 day', strtotime($from_date))))->sum('debit');
                $with_opening_balance_credit = AccountMastersAccountsDetail::Where('account_master_id', $account_master->id)->Where('date', '>=' , $first_account->date)->Where('date', '<=' , date('Y-m-d', strtotime('-1 day', strtotime($from_date))))->sum('credit');
            }else{
                $with_opening_balance_debit = 0;
                $with_opening_balance_credit = 0;
            }
            $voucher_type_opening_balance = AccountMastersAccountsDetail::Where('account_master_id', $account_master->id)->Where('voucher_type', 'opening balance')->Where('date', '>=' , $from_date)->Where('date', '<=' , $to_date)->first();
            if($voucher_type_opening_balance){
                if($voucher_type_opening_balance-> debit > 0){
                    $opening_balance = $voucher_type_opening_balance-> debit;
                }else{
                    $opening_balance = $voucher_type_opening_balance->credit;
                }
            }else {
                if($account_master-> account_master_type == 'Supplier'){
                        $opening_balance = ($with_opening_balance_credit) - $with_opening_balance_debit;
                }else{
                    $opening_balance = ($with_opening_balance_debit) - $with_opening_balance_credit;
                }
            }
            if($account_master-> account_master_type == 'Supplier'){
                $closing_balance = ($opening_balance + $credit) - $debit;
            }else{
                $closing_balance = ($opening_balance + $debit) - $credit;
            }
            $trial_balance_closing_balance[] = [
                "ledger" => $account_master,
                "closing_balance" => $closing_balance,
                "closing_balance_decimal" => number_format($closing_balance, $decimal, '.', '')
            ];
        }
        return $trial_balance_closing_balance;
    }

    public function display()
    {
        $user = Auth::user();
        if (!$user->can('balance-sheet-report')) {
            abort(403, 'Unauthorized action.');
        }
        return view('user.reports.balance_sheet.select_date');
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
}
