<?php

namespace App\Http\Controllers\Report;

use App\Currency;
use App\Http\Controllers\Controller;
use App\ItemGroup;
use App\ItemName;
use App\PurchaseInvoice;
use App\PurchaseInvoiceItem;
use App\PurchaseReturnVoucher;
use App\PurchaseReturnVoucherItem;
use App\SaleInvoice;
use App\SaleInvoiceItem;
use App\SalesReturnVoucher;
use App\SalesReturnVoucherItem;
use App\PurchaseSalesTransferStockTrack;
use App\Services\Utils;
use Illuminate\Http\Request;
use stdClass;
use PDF;
use Auth;

class StockReportController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function display()
    {
        $user = Auth::user();
        if (!$user->can('stock-report')) {
            abort(403, 'Unauthorized action.');
        }

        $location_id = Utils::getLocation();
        $particular_items = ItemName::Where('location_id', $location_id)->get();
        $group_stocks = ItemGroup::Where('location_id', $location_id)->get();
        return view('user.reports.stock_report.select_date', compact('particular_items', 'group_stocks'));
    }

    public function index(Request $request)
    {
        $user = Auth::user();
        if (!$user->can('stock-report')) {
            abort(403, 'Unauthorized action.');
        }

        $location_id = Utils::getLocation();
        $from_date = $request->from_date;
        $to_date = $request->to_date;
        if ($request->show_cost == "") {
            $show_cost = 0;
        }elseif ($request->show_cost == "on") {
            $show_cost = 1;
        }

        $decimal = 0;

        $currency = Currency::Where('location_id', $location_id)->first();
        if ($currency) {
            $decimal = $currency->decimal_currency;
        }

        // dd($show_cost);

        if ($request->ledger_account_class_name == "item_query") {
            $item_name = ItemName::with('units')->Where('id', $request->item_stock)->first();
// dd($item_name);
            $sale_invoices = SaleInvoiceItem::with('invoice.account', 'purchase_items')->Where('item_name_id', $request->item_stock)->Where('created_at', '>=' , $from_date.' 00:00:00')->Where('created_at', '<=' , $to_date.' 23:59:59')->get();
            foreach ($sale_invoices as $key => $sale_invoice) {
                $sale_invoice-> invoice_type = 'sales';
            }
            $purchase_invoices = PurchaseInvoiceItem::with('invoice.account')->Where('item_name_id', $request->item_stock)->Where('created_at', '>=' , $from_date.' 00:00:00')->Where('created_at', '<=' , $to_date.' 23:59:59')->get();
            foreach ($purchase_invoices as $key => $purchase_invoice) {
                $purchase_invoice-> invoice_type = 'purchase';
            }
            $purchase_return = PurchaseReturnVoucherItem::with('invoice.account', 'purchase_items')->Where('item_name_id', $request->item_stock)->Where('created_at', '>=' , $from_date.' 00:00:00')->Where('created_at', '<=' , $to_date.' 23:59:59')->get();
            foreach ($purchase_return as $key => $_purchase_return) {
                $_purchase_return-> invoice_type = 'purchase return';
            }
            
            $sale_return = SalesReturnVoucherItem::with('invoice.account')->Where('item_name_id', $request->item_stock)->Where('created_at', '>=' , $from_date.' 00:00:00')->Where('created_at', '<=' , $to_date.' 23:59:59')->get();
            foreach ($sale_return as $key => $_sale_return) {
                $_sale_return-> invoice_type = 'sale return';
            }
            $country_location_wise_stock_transfer_outward = PurchaseSalesTransferStockTrack::Where('form_item_name_id', $request->item_stock)->Where('from_location_id', $location_id)->Where('updated_at', '>=' , $from_date.' 00:00:00')->Where('updated_at', '<=' , $to_date.' 23:59:59')->get();
            // return $country_location_wise_stock_transfer_outward;
            foreach ($country_location_wise_stock_transfer_outward as $key => $stock_transfer_outward) {
                $stock_transfer_outward-> invoice_type = 'stock transfer outward';
            }
            $country_location_wise_stock_transfer_inward = PurchaseSalesTransferStockTrack::Where('item_name_id', $request->item_stock)->Where('location_id', $location_id)->Where('form_item_name_id', '!=', '')->Where('from_location_id', '!=', '')->Where('updated_at', '>=' , $from_date.' 00:00:00')->Where('updated_at', '<=' , $to_date.' 23:59:59')->get();
            // return $country_location_wise_stock_transfer_inward;
            foreach ($country_location_wise_stock_transfer_inward as $key => $stock_transfer_inward) {
                $stock_transfer_inward-> invoice_type = 'stock transfer inward';
            }

            $unsorted_stockreport_data  = $sale_invoices->concat($purchase_invoices)->concat($purchase_return)->concat($sale_return)->concat($country_location_wise_stock_transfer_outward)->concat($country_location_wise_stock_transfer_inward);
            $collection = collect($unsorted_stockreport_data);
            $sorted_stockreport_data = $collection->sortBy('updated_at')->values()->all();

            $sale_quantity = $sale_invoices->sum('quantity');
            $purchase_quantity = $purchase_invoices->sum('quantity');
            $purchase_return_quantity = $purchase_return->sum('quantity');
            $sale_return_quantity = $sale_return->sum('quantity');
            $stock_transfer_outward_quantity = $country_location_wise_stock_transfer_outward->sum('quantity');
            $stock_transfer_inward_quantity = $country_location_wise_stock_transfer_inward->sum('quantity');

            // return $stock_transfer_inward_quantity;
            $inward_quantity = $purchase_quantity + $sale_return_quantity + $stock_transfer_inward_quantity;
            $outward_quantity = $sale_quantity + $purchase_return_quantity + $stock_transfer_outward_quantity;
            $closing_quantity = $inward_quantity - $outward_quantity;
            return view('user.reports.stock_report.item_query', compact('decimal','show_cost','closing_quantity','item_name','from_date','to_date','sorted_stockreport_data'));
        }
        elseif ($request->ledger_account_class_name == "stock_query") {

            // $groups = ItemGroup::with('item_names.purchase_sales_transfer_stock_tracks')->with('item_names.purchase_invoice')->Where('location_id', $location_id)->get();
            $groups = ItemGroup::with('item_names.purchase_invoice')->with(['item_names.purchase_sales_transfer_stock_tracks' => function($q) use ($location_id, $from_date, $to_date) {
                $q->where('location_id', $location_id)->Where('created_at', '>=' , $from_date.' 00:00:00')->Where('created_at', '<=' , $to_date.' 23:59:59');}])->get();

            return view('user.reports.stock_report.complete_stock_query', compact('show_cost','decimal','groups','from_date','to_date'));

            // foreach ($groups as $i => $group) {

            //     $closing_quantity_i = [];
            //     $net_total_i = [];
            //     $rate_per_quantity_i = [];

            //     foreach ($groups[$i]->item_names as $key => $single) {

            //         $sale_invoices[$key] = SaleInvoiceItem::with('invoice.account', 'purchase_items')->Where('item_name_id', $single->id)->Where('created_at', '>=' , $from_date.' 00:00:00')->Where('created_at', '<=' , $to_date.' 23:59:59')->first();
            //         $purchase_invoices[$key] = PurchaseInvoiceItem::with('invoice.account')->Where('item_name_id', $single->id)->Where('created_at', '>=' , $from_date.' 00:00:00')->Where('created_at', '<=' , $to_date.' 23:59:59')->first();
            //         $purchase_return[$key] = PurchaseReturnVoucherItem::with('invoice.account', 'purchase_items')->Where('item_name_id', $single->id)->Where('created_at', '>=' , $from_date.' 00:00:00')->Where('created_at', '<=' , $to_date.' 23:59:59')->first();
            //         $sale_return[$key] = SaleInvoiceItem::with('invoice.account')->Where('item_name_id', $single->id)->Where('created_at', '>=' , $from_date.' 00:00:00')->Where('created_at', '<=' , $to_date.' 23:59:59')->first();

            //         $sale_quantity = 0;
            //         $purchase_quantity = 0;
            //         $purchase_return_quantity = 0;
            //         $sale_return_quantity = 0;

            //         if ($sale_invoices[$key] != "") {
            //             $sale_quantity = $sale_invoices[$key]->quantity;
            //         }
            //         if ($purchase_invoices[$key] != "") {
            //             $purchase_quantity = $purchase_invoices[$key]->quantity;
            //         }
            //         if ($purchase_return[$key] != "") {
            //             $purchase_return_quantity = $purchase_return[$key]->quantity;
            //         }
            //         if ($sale_return[$key] != "") {
            //             $sale_return_quantity = $sale_return[$key]->quantity;
            //         }
            //         $inward_quantity = $purchase_quantity + $sale_return_quantity;
            //         $outward_quantity = $sale_quantity + $purchase_return_quantity;
            //         $closing_quantity[] = $inward_quantity - $outward_quantity;

            //         $closing_quantity_i[] = $inward_quantity - $outward_quantity;
            //         $item[] = $single->name;
            //         if ($purchase_invoices[$key] != "") {
            //             $rate = $purchase_invoices[$key]->rate_per_quantity;
            //             $rate_per_quantity[] = (float)$rate;
            //             $rate_per_quantity_i[] = (float)$rate;

            //             $net_total[] = (float)($inward_quantity - $outward_quantity) * (float)$rate;
            //             $net_total_i[] = (float)($inward_quantity - $outward_quantity) * (float)$rate;
            //         }else{
            //             $rate_per_quantity[] = "";
            //             $rate_per_quantity_i[] = "";

            //             $net_total[] = "";
            //             $net_total_i[] = "";
            //         }

            //     }
            //     $net_total_sum = 0;
            //     $net_total_sum = array_sum($net_total_i);
            //     $average_net_total[] = $net_total_sum;


            //     $rate_per_quantity_count = count(array_filter($rate_per_quantity_i));

            //     if ($rate_per_quantity_count > 0) {
            //         $rate_per_quantity_sum = array_sum($rate_per_quantity_i);
            //         $average_rate_per_quantity[] = $rate_per_quantity_sum / $rate_per_quantity_count;
            //     }else {
            //         $average_rate_per_quantity[] = "";
            //     }

            //     $quantity_sum = 0;
            //     $quantity_sum = array_sum($closing_quantity_i);
            //     $group_quantity[] = $quantity_sum;
            // }
            // // dd($net_total);
            // return view('user.reports.stock_report.complete_stock_query', compact('group_quantity','average_rate_per_quantity','average_net_total','closing_quantity','groups','from_date','to_date','item','rate_per_quantity','net_total'));
            // // return view('user.reports.stock_report.complete_stock_query', compact('item_names','item_groups','from_date','to_date'));
        }

        // elseif ($request->ledger_account_class_name == "group_query") {
        //     $group = ItemGroup::with('item_names')->Where('id', $request->group_stock)->first();
        //     foreach ($group->item_names as $key => $single) {
        //         $sale_invoices[$key] = SaleInvoiceItem::with('invoice.account', 'purchase_items')->Where('item_name_id', $single->id)->Where('created_at', '>=' , $from_date.' 00:00:00')->Where('created_at', '<=' , $to_date.' 23:59:59')->first();
        //         $purchase_invoices[$key] = PurchaseInvoiceItem::with('invoice.account')->Where('item_name_id', $single->id)->Where('created_at', '>=' , $from_date.' 00:00:00')->Where('created_at', '<=' , $to_date.' 23:59:59')->first();
        //         $purchase_return[$key] = PurchaseReturnVoucherItem::with('invoice.account', 'purchase_items')->Where('item_name_id', $single->id)->Where('created_at', '>=' , $from_date.' 00:00:00')->Where('created_at', '<=' , $to_date.' 23:59:59')->first();
        //         $sale_return[$key] = SalesReturnVoucherItem::with('invoice.account')->Where('item_name_id', $single->id)->Where('created_at', '>=' , $from_date.' 00:00:00')->Where('created_at', '<=' , $to_date.' 23:59:59')->first();

        //         $sale_quantity = 0;
        //         $purchase_quantity = 0;
        //         $purchase_return_quantity = 0;
        //         $sale_return_quantity = 0;

        //         if ($sale_invoices[$key] != "") {
        //             $sale_quantity = $sale_invoices[$key]->quantity;
        //         }
        //         if ($purchase_invoices[$key] != "") {
        //             $purchase_quantity = $purchase_invoices[$key]->quantity;
        //         }
        //         if ($purchase_return[$key] != "") {
        //             $purchase_return_quantity = $purchase_return[$key]->quantity;
        //         }
        //         if ($sale_return[$key] != "") {
        //             $sale_return_quantity = $sale_return[$key]->quantity;
        //         }
        //         $inward_quantity = $purchase_quantity + $sale_return_quantity;
        //         $outward_quantity = $sale_quantity + $purchase_return_quantity;
        //         $closing_quantity[] = $inward_quantity - $outward_quantity;
        //         $item[] = $single->name;
        //         if ($purchase_invoices[$key] != "") {
        //             $rate_per_quantity[] = $purchase_invoices[$key]->rate_per_quantity;
        //         }else{
        //             $rate_per_quantity[] = "";
        //         }
        //         if ($purchase_invoices[$key] != "") {
        //             $net_total[] = $closing_quantity[$key] * $purchase_invoices[$key]->rate_per_quantity;
        //         }else{
        //             $net_total[] = "";
        //         }
        //     }

        //     return view('user.reports.stock_report.group_query', compact('closing_quantity','group','from_date','to_date','item','rate_per_quantity','net_total'));

        // }
        elseif ($request->ledger_account_class_name == "group_query") {
            $closing_quantity = [];
            $item = [];
            $rate_per_quantity = [];
            $net_total = [];
            $group = ItemGroup::with('item_names.purchase_invoice')->with(['item_names.purchase_sales_transfer_stock_tracks' => function($q) use ($location_id, $from_date, $to_date) {
                $q->where('location_id', $location_id)->Where('created_at', '>=' , $from_date.' 00:00:00')->Where('created_at', '<=' , $to_date.' 23:59:59');}])->Where('id', $request->group_stock)->first();
            // foreach ($group->item_names as $single) {
            //     $sale_invoices = SaleInvoiceItem::with('invoice.account', 'purchase_items')->Where('item_name_id', $single->id)->Where('created_at', '>=' , $from_date.' 00:00:00')->Where('created_at', '<=' , $to_date.' 23:59:59')->get();
            //     $purchase_invoices = PurchaseInvoiceItem::with('invoice.account')->Where('item_name_id', $single->id)->Where('created_at', '>=' , $from_date.' 00:00:00')->Where('created_at', '<=' , $to_date.' 23:59:59')->get();
            //     $purchase_return = PurchaseReturnVoucherItem::with('invoice.account', 'purchase_items')->Where('item_name_id', $single->id)->Where('created_at', '>=' , $from_date.' 00:00:00')->Where('created_at', '<=' , $to_date.' 23:59:59')->get();
            //     $sale_return = SalesReturnVoucherItem::with('invoice.account')->Where('item_name_id', $single->id)->Where('created_at', '>=' , $from_date.' 00:00:00')->Where('created_at', '<=' , $to_date.' 23:59:59')->get();

            //     $sale_quantity = 0;
            //     $purchase_quantity = 0;
            //     $purchase_return_quantity = 0;
            //     $sale_return_quantity = 0;

            //     $sale_amount_sum = 0;
            //     $purchase_amount = 0;
            //     $purchase_return_amount_sum = 0;
            //     $sale_return_amount = 0;

            //     $purchase_return_amount = 0;
            //     $sale_amount = 0;

            //     if (count($sale_invoices) > 0) {
            //         $sale_quantity = $sale_invoices->sum('quantity');
            //         foreach ($sale_invoices as $sale) {
            //             $sale_amount_sum = $sale_amount_sum + ($sale->purchase_items->rate_per_quantity * $sale->quantity);
            //         }
            //         // $sale_amount_sum = array_sum($sale_amount);
            //     }
            //     if (count($purchase_invoices) > 0) {
            //         $purchase_quantity = $purchase_invoices->sum('quantity');
            //         $purchase_amount = $purchase_invoices->sum('amount');
            //     }
            //     if (count($purchase_return) > 0) {
            //         $purchase_return_quantity = $purchase_return->sum('quantity');
            //         foreach ($purchase_return as $pr) {
            //             $purchase_return_amount_sum = $purchase_return_amount_sum + ($pr->purchase_items->rate_per_quantity * $pr->quantity);
            //         }
            //         // $purchase_return_amount_sum = array_sum($purchase_return_amount);
            //     }
            //     if (count($sale_return) > 0) {
            //         $sale_return_quantity = $sale_return->sum('quantity');
            //         $sale_return_amount = $sale_return->sum('amount');
            //     }
            //     $inward_quantity = $purchase_quantity + $sale_return_quantity;
            //     $outward_quantity = $sale_quantity + $purchase_return_quantity;
            //     $quantity = $inward_quantity - $outward_quantity;
            //     $closing_quantity[] = $inward_quantity - $outward_quantity;

            //     $inward_amount = $purchase_amount + $sale_return_amount;
            //     $outward_amount = $sale_amount_sum + $purchase_return_amount_sum;
            //     $amount = $inward_amount - $outward_amount;
            //     $net_total[] = $amount;
            //     if ($quantity == 0) {
            //         $rate_per_quantity[] = 0;
            //     }else {
            //         $rate_per_quantity[] = $amount / $quantity;
            //     }


            //     $item[] = $single->name;
            // }
            // dd($net_total);
            return view('user.reports.stock_report.group_query', compact('decimal','show_cost','closing_quantity','group','from_date','to_date','item','rate_per_quantity','net_total'));

        }
        else{
            return redirect()->back();
        }

    }

    public function pdfViewComplete($from_date, $to_date, $show_cost)
    {
        $user = Auth::user();
        if (!$user->can('stock-report')) {
            abort(403, 'Unauthorized action.');
        }

        $location_id = Utils::getLocation();
        $decimal = 0;

        $currency = Currency::Where('location_id', $location_id)->first();
        if ($currency) {
            $decimal = $currency->decimal_currency;
        }
        $groups = ItemGroup::with('item_names.purchase_invoice')->with(['item_names.purchase_sales_transfer_stock_tracks' => function($q) use ($location_id, $from_date, $to_date) {
            $q->where('location_id', $location_id)->Where('created_at', '>=' , $from_date.' 00:00:00')->Where('created_at', '<=' , $to_date.' 23:59:59');}])->get();
        $pdf = PDF::loadView('user.reports.stock_report.list_stock', compact('decimal','groups','from_date','to_date','show_cost'));
        return $pdf->stream();
    }

    public function pdfViewItem($from_date, $to_date, $id, $show_cost)
    {
        $user = Auth::user();
        if (!$user->can('stock-report')) {
            abort(403, 'Unauthorized action.');
        }

        $location_id = Utils::getLocation();
        $decimal = 0;

        $currency = Currency::Where('location_id', $location_id)->first();
        if ($currency) {
            $decimal = $currency->decimal_currency;
        }
        $item_name = ItemName::Find($id);

            $sale_invoices = SaleInvoiceItem::with('invoice.account', 'purchase_items')->Where('item_name_id', $id)->Where('created_at', '>=' , $from_date.' 00:00:00')->Where('created_at', '<=' , $to_date.' 23:59:59')->get();
            foreach ($sale_invoices as $key => $sale_invoice) {
                $sale_invoice-> invoice_type = 'sales';
            }
            $purchase_invoices = PurchaseInvoiceItem::with('invoice.account')->Where('item_name_id', $id)->Where('created_at', '>=' , $from_date.' 00:00:00')->Where('created_at', '<=' , $to_date.' 23:59:59')->get();
            foreach ($purchase_invoices as $key => $purchase_invoice) {
                $purchase_invoice-> invoice_type = 'purchase';
            }
            $purchase_return = PurchaseReturnVoucherItem::with('invoice.account', 'purchase_items')->Where('item_name_id', $id)->Where('created_at', '>=' , $from_date.' 00:00:00')->Where('created_at', '<=' , $to_date.' 23:59:59')->get();
            foreach ($purchase_return as $key => $_purchase_return) {
                $_purchase_return-> invoice_type = 'purchase return';
            }
            $sale_return = SalesReturnVoucherItem::with('invoice.account')->Where('item_name_id', $id)->Where('created_at', '>=' , $from_date.' 00:00:00')->Where('created_at', '<=' , $to_date.' 23:59:59')->get();
            foreach ($sale_return as $key => $_sale_return) {
                $_sale_return-> invoice_type = 'sale return';
            }

            $country_location_wise_stock_transfer_outward = PurchaseSalesTransferStockTrack::Where('form_item_name_id', $id)->Where('from_location_id', $location_id)->Where('updated_at', '>=' , $from_date.' 00:00:00')->Where('updated_at', '<=' , $to_date.' 23:59:59')->get();
            // return $country_location_wise_stock_transfer_outward;
            foreach ($country_location_wise_stock_transfer_outward as $key => $stock_transfer_outward) {
                $stock_transfer_outward-> invoice_type = 'stock transfer outward';
            }
            $country_location_wise_stock_transfer_inward = PurchaseSalesTransferStockTrack::Where('item_name_id', $id)->Where('location_id', $location_id)->Where('updated_at', '>=' , $from_date.' 00:00:00')->Where('updated_at', '<=' , $to_date.' 23:59:59')->get();
            // return $country_location_wise_stock_transfer_outward;
            foreach ($country_location_wise_stock_transfer_inward as $key => $stock_transfer_inward) {
                $stock_transfer_inward-> invoice_type = 'stock transfer inward';
            }

            $unsorted_stockreport_data  = $sale_invoices->concat($purchase_invoices)->concat($purchase_return)->concat($sale_return)->concat($country_location_wise_stock_transfer_outward)->concat($country_location_wise_stock_transfer_inward);
            $collection = collect($unsorted_stockreport_data);
            $sorted_stockreport_data = $collection->sortBy('updated_at')->values()->all();

            $sale_quantity = $sale_invoices->sum('quantity');
            $purchase_quantity = $purchase_invoices->sum('quantity');
            $purchase_return_quantity = $purchase_return->sum('quantity');
            $sale_return_quantity = $sale_return->sum('quantity');
            $stock_transfer_outward_quantity = $country_location_wise_stock_transfer_outward->sum('quantity');
            $stock_transfer_inward_quantity = $country_location_wise_stock_transfer_inward->sum('quantity');

            $inward_quantity = $purchase_quantity + $sale_return_quantity + $stock_transfer_inward_quantity;
            $outward_quantity = $sale_quantity + $purchase_return_quantity - $stock_transfer_outward_quantity;
            $closing_quantity = $inward_quantity - $outward_quantity ;
            // return view('user.reports.stock_report.item_query', compact('show_cost','closing_quantity','item_name','from_date','to_date','sorted_stockreport_data'));
            $pdf = PDF::loadView('user.reports.stock_report.list_item', compact('decimal','show_cost','closing_quantity','item_name','from_date','to_date','sorted_stockreport_data'));
            return $pdf->stream();
    }

    public function pdfViewGroup($from_date, $to_date, $id, $show_cost)
    {
        $user = Auth::user();
        if (!$user->can('stock-report')) {
            abort(403, 'Unauthorized action.');
        }

        $location_id = Utils::getLocation();
        $decimal = 0;

        $currency = Currency::Where('location_id', $location_id)->first();
        if ($currency) {
            $decimal = $currency->decimal_currency;
        }
        $group = ItemGroup::with('item_names.purchase_invoice')->with(['item_names.purchase_sales_transfer_stock_tracks' => function($q) use ($location_id, $from_date, $to_date) {
            $q->where('location_id', $location_id)->Where('created_at', '>=' , $from_date.' 00:00:00')->Where('created_at', '<=' , $to_date.' 23:59:59');}])->Where('id', $id)->first();
            // foreach ($group->item_names as $single) {
            //     $sale_invoices = SaleInvoiceItem::with('invoice.account', 'purchase_items')->Where('item_name_id', $single->id)->Where('created_at', '>=' , $from_date.' 00:00:00')->Where('created_at', '<=' , $to_date.' 23:59:59')->get();
            //     $purchase_invoices = PurchaseInvoiceItem::with('invoice.account')->Where('item_name_id', $single->id)->Where('created_at', '>=' , $from_date.' 00:00:00')->Where('created_at', '<=' , $to_date.' 23:59:59')->get();
            //     $purchase_return = PurchaseReturnVoucherItem::with('invoice.account', 'purchase_items')->Where('item_name_id', $single->id)->Where('created_at', '>=' , $from_date.' 00:00:00')->Where('created_at', '<=' , $to_date.' 23:59:59')->get();
            //     $sale_return = SalesReturnVoucherItem::with('invoice.account')->Where('item_name_id', $single->id)->Where('created_at', '>=' , $from_date.' 00:00:00')->Where('created_at', '<=' , $to_date.' 23:59:59')->get();

            //     $sale_quantity = 0;
            //     $purchase_quantity = 0;
            //     $purchase_return_quantity = 0;
            //     $sale_return_quantity = 0;

            //     $sale_amount_sum = 0;
            //     $purchase_amount = 0;
            //     $purchase_return_amount_sum = 0;
            //     $sale_return_amount = 0;

            //     $purchase_return_amount = 0;
            //     $sale_amount = 0;

            //     if (count($sale_invoices) > 0) {
            //         $sale_quantity = $sale_invoices->sum('quantity');
            //         foreach ($sale_invoices as $sale) {
            //             $sale_amount_sum = $sale_amount_sum + ($sale->purchase_items->rate_per_quantity * $sale->quantity);
            //         }
            //     }
            //     if (count($purchase_invoices) > 0) {
            //         $purchase_quantity = $purchase_invoices->sum('quantity');
            //         $purchase_amount = $purchase_invoices->sum('amount');
            //     }
            //     if (count($purchase_return) > 0) {
            //         $purchase_return_quantity = $purchase_return->sum('quantity');
            //         foreach ($purchase_return as $pr) {
            //             $purchase_return_amount_sum = $purchase_return_amount_sum + ($pr->purchase_items->rate_per_quantity * $pr->quantity);
            //         }
            //     }
            //     if (count($sale_return) > 0) {
            //         $sale_return_quantity = $sale_return->sum('quantity');
            //         $sale_return_amount = $sale_return->sum('amount');
            //     }
            //     $inward_quantity = $purchase_quantity + $sale_return_quantity;
            //     $outward_quantity = $sale_quantity + $purchase_return_quantity;
            //     $quantity = $inward_quantity - $outward_quantity;
            //     $closing_quantity[] = $inward_quantity - $outward_quantity;

            //     $inward_amount = $purchase_amount + $sale_return_amount;
            //     $outward_amount = $sale_amount_sum + $purchase_return_amount_sum;
            //     $amount = $inward_amount - $outward_amount;
            //     $net_total[] = $amount;
            //     if ($quantity == 0) {
            //         $rate_per_quantity[] = 0;
            //     }else {
            //         $rate_per_quantity[] = $amount / $quantity;
            //     }

            //     $item[] = $single->name;
            // }
            // return view('user.reports.stock_report.group_query', compact('show_cost','closing_quantity','group','from_date','to_date','item','rate_per_quantity','net_total'));
            $pdf = PDF::loadView('user.reports.stock_report.list_group', compact('decimal','show_cost','group','from_date','to_date'));
            return $pdf->stream();
    }



    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
}
