<?php

namespace App\Http\Controllers\Transaction;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;


use Auth;
use DB;
use Storage;
use Session;
use Carbon\Carbon;
use App\Services\Utils;
use App\Services\Slug;
use App\WareHouse;
use App\ItemName;
use App\PurchaseInvoice;
use App\PurchaseReturnVoucher;
use App\PurchaseReturnVoucherItem;
use App\StaffAndSalesman;
use App\Supplier;
use App\AccountMasterTrack;
use App\AccountMaster;
use App\AccountMastersAccountsDetail;
use App\TermsAndConditionsPurchaseReturnVoucher;
use App\Company;
use App\Currency;
use App\PurchaseSalesTransferStockTrack;
use App\SalesReturnVoucherItem;
use App\WareHouseTrack;

class PurchaseReturnVoucherController extends Controller
{
    protected $utils;
    protected $slug;

    public function __construct(Utils $utils, Slug $slug)
    {
        $this->utils = $utils;
        $this->slug = $slug;
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $user = Auth::user();
        if (!$user->can('debit-note-purchase-return-voucher')) {
            abort(403, 'Unauthorized action.');
        }

        $location_id = $this->getLocationId();
        $purchase_return_vouchers = PurchaseReturnVoucher::withTrashed()->with('account')->where('location_id', $location_id)->orderBy('created_at','DESC')->paginate(100);
        return view('user.transactions.purchase_return_vouchers.index', compact('purchase_return_vouchers'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $user = Auth::user();
        if (!$user->can('debit-note-purchase-return-voucher')) {
            abort(403, 'Unauthorized action.');
        }

        $location_id = $this->getLocationId();
        $latest_invoice_vat = PurchaseReturnVoucher::where('location_id', $location_id)->Where('vat_check', 1)->withTrashed()->orderByRaw('CONVERT(invoice_no, SIGNED) desc')->first();
        if($latest_invoice_vat){
            $invoice_no_vat = $latest_invoice_vat-> invoice_no + 1;
        }else{
            $invoice_no_vat = 1;
        }

        $latest_invoice = PurchaseReturnVoucher::where('location_id', $location_id)->Where('vat_check', 0)->withTrashed()->orderByRaw('CONVERT(invoice_no, SIGNED) desc')->first();
        if($latest_invoice){
            $invoice_no = (int)$latest_invoice-> invoice_no + 1 .'A' ;

        }else{
            $invoice_no = '1A';
        }

        $salesmen = StaffAndSalesman::where('job_designation', 'salesman')->get();


        $warehouses = WareHouseTrack::with(['warehouse' => function($q) use ($location_id) {
            $q->where('location_id', $location_id);}])->Where('user_id', auth()->user()->id)->get();

        $account_masters = AccountMasterTrack::with(['account_master' => function($q) use ($location_id) {
            $q->where('location_id', $location_id);}])->Where('user_id', auth()->user()->id)->get();


        $item_names = ItemName::all();
        // $items = [];
        // $purchase_invoices = PurchaseInvoice::with('items')->where('location_id', $location_id)->get();
        // foreach ($purchase_invoices as $key => $purchase_invoice) {
        //     foreach ($purchase_invoice->items as $key => $item) {
        //         $items[] = $item;
        //     }
        // }
        $items = PurchaseSalesTransferStockTrack::Where('location_id', $location_id)->Where('quantity', '!=', 0)->get();
        $currency = Currency::Where('location_id', $location_id)->first();
        $terms_and_conditions_purchase_return_voucher = TermsAndConditionsPurchaseReturnVoucher::where('location_id', $location_id)->first();
        return view('user.transactions.purchase_return_vouchers.create', compact('currency','invoice_no_vat','invoice_no', 'warehouses', 'salesmen','account_masters','item_names', 'items', 'terms_and_conditions_purchase_return_voucher'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        // dd($request->all());
        DB::beginTransaction();

        try {
            $location_id = $this->getLocationId();
            $purchase_return_voucher = new PurchaseReturnVoucher();
            $purchase_return_voucher->location_id = $location_id;
            $purchase_return_voucher->invoice_no = $request->invoice_no;
            $purchase_return_voucher->mode_of_payment = $request->mode_of_payment;
            $purchase_return_voucher->date = $request->date;
            // $purchase_return_voucher->warehouse_id = $request->warehouse_id;
            if ($request->vat_check == "") {
                $purchase_return_voucher->vat_check = 0;
            }else {
                $purchase_return_voucher->vat_check = $request->vat_check;
            }
            $purchase_return_voucher->account_id = $request->account_id;
            $purchase_return_voucher->total_quantity = $request->total_quantity;
            $purchase_return_voucher->gross_total = $request->gross_total;
            $purchase_return_voucher->discount = $request->discount_amount;
            $purchase_return_voucher->vat_percentage = $request->vat_percentage;
            $purchase_return_voucher->vat_amount = $request->vat_amount;
            $purchase_return_voucher->net_total = $request->net_total;
            $purchase_return_voucher->amount_in_words = $request->amount_in_words;
            $purchase_return_voucher->narrations = $request->narrations;
            $purchase_return_voucher->buyer_name = $request->buyer_name;
            $purchase_return_voucher->buyer_mobile = $request->buyer_mobile;
            $purchase_return_voucher->buyer_email = $request->buyer_email;
            $purchase_return_voucher->buyer_address = $request->buyer_address;
            $purchase_return_voucher->buyer_vat_number = $request->buyer_vat_number;
            $purchase_return_voucher->is_signed = 0;
            $purchase_return_voucher->save();

            foreach ($request->imei_serial_no as $key => $imei_serial_no) {
                $purchase_return_voucher_item = new PurchaseReturnVoucherItem();
                $purchase_return_voucher_item-> purchase_return_voucher_id = $purchase_return_voucher-> id;
                $purchase_return_voucher_item-> item_name_id = $request->item_name_id[$key];
                $purchase_return_voucher_item-> item_unit_id = $request->item_unit[$key];
                $purchase_return_voucher_item-> imei_serial_no = $request->imei_serial_no[$key];
                $purchase_return_voucher_item-> warehouse_id = $request->warehouse_id[$key];
                $purchase_return_voucher_item-> quantity = $request->quantity[$key];
                $purchase_return_voucher_item-> rate_per_quantity = $request->rate_per_quantity[$key];
                $purchase_return_voucher_item-> amount = $request->amount[$key];
                $purchase_return_voucher_item-> remarks = $request->remarks[$key];
                $purchase_return_voucher_item-> save();

                $purchase_sales_transfer_stock_track = PurchaseSalesTransferStockTrack::Where('imei_serial_no', $request->imei_serial_no[$key])->Where('location_id', $location_id)->first();
                if ($purchase_sales_transfer_stock_track) {
                    $purchase_sales_transfer_stock_track->quantity = $purchase_sales_transfer_stock_track->quantity - $request->quantity[$key];
                    $purchase_sales_transfer_stock_track->save();
                }else{
                    return redirect()->back()->withErrors("IMEI Not Found In This Location");
                }
            }

            $account = new AccountMastersAccountsDetail();
            $account->account_master_id = $request->account_id;
            $account->credit = 0;
            $account->debit = $request->net_total;
            $account->date = $request->date;
            $account->voucher_type = "debit-note";
            $account->voucher_no = $request->invoice_no;
            $account->save();

            DB::commit();
            Session::flash('alert-success','Purchase Return Vouchers created successfully');
            return redirect('/transactions/purchase-return-vouchers');
        }catch(Exception $e) {
            DB::rollback();
            return redirect()->back()->withErrors($e);
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\PurchaseReturnVoucher  $purchaseInvoice
     * @return \Illuminate\Http\Response
     */
    public function show(PurchaseReturnVoucher $purchaseInvoice)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\PurchaseReturnVoucher  $purchaseInvoice
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $user = Auth::user();
        if (!$user->can('edit-debit-note-purchase-return-voucher')) {
            abort(403, 'Unauthorized action.');
        }

        $location_id = $this->getLocationId();
        $purchase_return_voucher = PurchaseReturnVoucher::with('items.name')->where('id', $id)->first();

        if ($purchase_return_voucher->vat_check == 1) {

            $invoice_no_vat = $purchase_return_voucher->invoice_no;

            $latest_invoice = PurchaseReturnVoucher::where('location_id', $location_id)->Where('vat_check', 0)->withTrashed()->orderByRaw('CONVERT(invoice_no, SIGNED) desc')->first();
            if($latest_invoice){
                $invoice_no = (int)$latest_invoice-> invoice_no + 1 .'A' ;

            }else{
                $invoice_no = '1A';
            }

        }elseif ($purchase_return_voucher->vat_check == 0) {

            $invoice_no = $purchase_return_voucher->invoice_no;

            $latest_invoice_vat = PurchaseReturnVoucher::where('location_id', $location_id)->Where('vat_check', 1)->withTrashed()->orderByRaw('CONVERT(invoice_no, SIGNED) desc')->first();
            if($latest_invoice_vat){
                $invoice_no_vat = $latest_invoice_vat-> invoice_no + 1;
            }else{
                $invoice_no_vat = 1;
            }
        }

        $company = Company::where('id', 1)->first();
        // return $company;
        $salesmen = StaffAndSalesman::where('job_designation', 'salesman')->get();

        $warehouses = WareHouseTrack::with(['warehouse' => function($q) use ($location_id) {
            $q->where('location_id', $location_id);}])->Where('user_id', auth()->user()->id)->get();

        $account_masters = AccountMasterTrack::with(['account_master' => function($q) use ($location_id) {
            $q->where('location_id', $location_id);}])->Where('user_id', auth()->user()->id)->get();

        $item_names = ItemName::all();
        $items = PurchaseSalesTransferStockTrack::Where('location_id', $location_id)->get();
        // $items = PurchaseSalesTransferStockTrack::Where('location_id', $location_id)->Where('quantity', '!=', 0)->get();

        $account_id = $purchase_return_voucher->account_id;
        $account = AccountMaster::Find($account_id);

        if ($account->transactions_password != "") {
            $pass_check = "yes";
        }elseif ($account->transactions_password == "") {
            $pass_check = "no";
        }
        $currency = Currency::Where('location_id', $location_id)->first();
        $terms_and_conditions_purchase_return_voucher = TermsAndConditionsPurchaseReturnVoucher::where('location_id', $location_id)->first();
        return view('user.transactions.purchase_return_vouchers.edit', compact('invoice_no','invoice_no_vat','currency','pass_check','purchase_return_voucher', 'company', 'warehouses', 'salesmen','account_masters','item_names', 'items', 'terms_and_conditions_purchase_return_voucher', 'account'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\PurchaseReturnVoucher  $purchaseInvoice
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        DB::beginTransaction();

        try {
            $location_id = $this->getLocationId();
            $purchase_return_voucher = PurchaseReturnVoucher::where('id', $id)->first();
            $previous_net_total = (float)$purchase_return_voucher->net_total;
            $current_net_total = (float)$request->net_total;
            $account = AccountMastersAccountsDetail::Where('account_master_id', $purchase_return_voucher->account_id)->Where('voucher_type', "debit-note")->Where('voucher_no', $purchase_return_voucher->invoice_no)->first();
            $purchase_return_voucher->location_id = $location_id;
            $purchase_return_voucher->invoice_no = $request->invoice_no;
            $purchase_return_voucher->mode_of_payment = $request->mode_of_payment;
            $purchase_return_voucher->date = $request->date;
            // $purchase_return_voucher->warehouse_id = $request->warehouse_id;
            if ($request->vat_check == "") {
                $purchase_return_voucher->vat_check = 0;
            }else {
                $purchase_return_voucher->vat_check = $request->vat_check;
            }
            $purchase_return_voucher->account_id = $request->account_id;
            $purchase_return_voucher->total_quantity = $request->total_quantity;
            $purchase_return_voucher->gross_total = $request->gross_total;
            $purchase_return_voucher->discount = $request->discount_amount;
            $purchase_return_voucher->vat_percentage = $request->vat_percentage;
            $purchase_return_voucher->vat_amount = $request->vat_amount;
            $purchase_return_voucher->net_total = $request->net_total;
            $purchase_return_voucher->amount_in_words = $request->amount_in_words;
            $purchase_return_voucher->narrations = $request->narrations;
            $purchase_return_voucher->buyer_name = $request->buyer_name;
            $purchase_return_voucher->buyer_mobile = $request->buyer_mobile;
            $purchase_return_voucher->buyer_email = $request->buyer_email;
            $purchase_return_voucher->buyer_address = $request->buyer_address;
            $purchase_return_voucher->buyer_vat_number = $request->buyer_vat_number;
            $purchase_return_voucher->save();


            // PurchaseReturnVoucherItem::where('purchase_return_voucher_id', $id)->forcedelete();
            $purchase_return_items = PurchaseReturnVoucherItem::where('purchase_return_voucher_id', $id)->get();
            foreach ($purchase_return_items as $item) {
                $purchase_sale_track = PurchaseSalesTransferStockTrack::Where('imei_serial_no', $item->imei_serial_no)->first();
                $quantity = $item->quantity;
                $purchase_sale_track->quantity = $purchase_sale_track->quantity + $quantity;
                $purchase_sale_track->save();

                $item->forcedelete();
            }

            foreach ($request->imei_serial_no as $key => $imei_serial_no) {
                $purchase_return_voucher_item = new PurchaseReturnVoucherItem();
                $purchase_return_voucher_item-> purchase_return_voucher_id = $purchase_return_voucher-> id;
                $purchase_return_voucher_item-> item_name_id = $request->item_name_id[$key];
                $purchase_return_voucher_item-> item_unit_id = $request->item_unit[$key];
                $purchase_return_voucher_item-> imei_serial_no = $request->imei_serial_no[$key];
                $purchase_return_voucher_item-> warehouse_id = $request->warehouse_id[$key];
                $purchase_return_voucher_item-> quantity = $request->quantity[$key];
                $purchase_return_voucher_item-> rate_per_quantity = $request->rate_per_quantity[$key];
                $purchase_return_voucher_item-> amount = $request->amount[$key];
                $purchase_return_voucher_item-> remarks = $request->remarks[$key];
                $purchase_return_voucher_item-> save();

                $purchase_sales_transfer_stock_track = PurchaseSalesTransferStockTrack::Where('imei_serial_no', $request->imei_serial_no[$key])->Where('location_id', $location_id)->first();
                if ($purchase_sales_transfer_stock_track) {
                    $purchase_sales_transfer_stock_track->quantity = $purchase_sales_transfer_stock_track->quantity - $request->quantity[$key];
                    $purchase_sales_transfer_stock_track->save();
                }else{
                    return redirect()->back()->withErrors("IMEI Not Found In This Location");
                }
            }

            // $account = AccountMastersAccountsDetail::Where('account_master_id', $request->account_id)->Where('voucher_type', "debit-note")->Where('voucher_no', $purchase_return_voucher->invoice_no)->first();
            $account->account_master_id = $request->account_id;
            if ($previous_net_total > $current_net_total) {
                $diff = $previous_net_total - $current_net_total;
                $diff_calculate =  (float)$account->debit - (float)$diff;
                $account->debit =  number_format((float)$diff_calculate, $request->currency_decimal, '.', '');
            }
            elseif ($previous_net_total < $current_net_total) {
                $diff = $current_net_total - $previous_net_total;
                $diff_calculate = (float)$account->debit + (float)$diff;
                $account->debit = number_format((float)$diff_calculate, $request->currency_decimal, '.', '');
            }

            $account->save();

            DB::commit();
            Session::flash('alert-success','Purchase Return Vouchers Updated successfully');
            return redirect('/transactions/purchase-return-vouchers');
        }catch(Exception $e) {
            DB::rollback();
            return redirect()->back()->withErrors($e);
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\PurchaseReturnVoucher  $purchaseInvoice
     * @return \Illuminate\Http\Response
     */
    public function destroy(PurchaseReturnVoucher $purchaseInvoice)
    {
        //
    }

    public function view($id)
    {
        $user = Auth::user();
        if (!$user->can('view-print-debit-note-purchase-return-voucher')) {
            abort(403, 'Unauthorized action.');
        }

        $location_id = $this->getLocationId();
        $purchase_return_voucher = PurchaseReturnVoucher::withTrashed()->with('items_cancelled.name')->where('id', $id)->first();
        $buyer = AccountMaster::Where('id', $purchase_return_voucher->account_id)->first();
        $company = Company::where('location_id', $location_id)->first();;
        // return $company;
        $warehouses = WareHouse::all();
        $salesmen = StaffAndSalesman::where('job_designation', 'salesman')->get();

        $account_masters = [];
        $account_master_tracks = AccountMasterTrack::Where('user_id', auth()->user()->id)->get();
        foreach ($account_master_tracks as $key => $account_master_track){
            $account_masters[] = AccountMaster::Where('location_id', $location_id)->Where('id', $account_master_track->account_master_id)->first();
        }

        $item_names = ItemName::all();
        $currency = Currency::Where('location_id', $location_id)->first();
        $terms_and_conditions_purchase_return_voucher = TermsAndConditionsPurchaseReturnVoucher::where('location_id', $location_id)->first();
        return view('user.print.purchase_return_voucher.index', compact('buyer','currency', 'purchase_return_voucher', 'company', 'warehouses', 'salesmen','account_masters','item_names', 'terms_and_conditions_purchase_return_voucher'));
    }

    public function softdelete($id)
    {
        $user = Auth::user();
        if (!$user->can('cancel-debit-note-purchase-return-voucher')) {
            abort(403, 'Unauthorized action.');
        }

        $purchase_return_voucher = PurchaseReturnVoucher::Find($id);
        $net_total = $purchase_return_voucher->net_total;
        $account_id = $purchase_return_voucher->account_id;

        $account = AccountMastersAccountsDetail::Where('account_master_id', $account_id)->Where('voucher_type', "debit-note")->Where('voucher_no', $purchase_return_voucher->invoice_no)->first();

        // $debit = $account->debit;
        // $account->debit = (float)$debit - (float)$net_total;
        $account->delete();

        $purchase_return_voucher->delete();

        $purchase_return_voucher_items = PurchaseReturnVoucherItem::Where('purchase_return_voucher_id', $id)->get();
        foreach ($purchase_return_voucher_items as $item) {
            $purchase_sales_transfer_stock_track = PurchaseSalesTransferStockTrack::Where('imei_serial_no', $item->imei_serial_no)->first();
            if ($purchase_sales_transfer_stock_track) {
                $purchase_sales_transfer_stock_track->quantity = $purchase_sales_transfer_stock_track->quantity + $item->quantity;
                $purchase_sales_transfer_stock_track->save();
            }else{
                return redirect()->back()->withErrors("IMEI Not Found");
            }

            $item->delete();
        }
        Session::flash('alert-success','Purchase Return Voucehr Cancelled successfully');
        return redirect('/transactions/purchase-return-vouchers');
    }

    public function signature($id){
        $user = Auth::user();
        if (!$user->can('debit-note-purchase-return-voucher')) {
            abort(403, 'Unauthorized action.');
        }

        $purchase_return = PurchaseReturnVoucher::Find($id);
        return view('user.transactions.purchase_return_vouchers.signature', compact('purchase_return'));
    }

    public function signatureUpload(Request $request, $id){
        $purchase_return = PurchaseReturnVoucher::Find($id);
        $folderPath = public_path('/user_files/img/client_signs/');
        $image_parts = explode(";base64,", $request->signed);
        $image_type_aux = explode("image/", $image_parts[0]);
        $image_type = $image_type_aux[1];
        $image_base64 = base64_decode($image_parts[1]);
        $file_name = 'purchasereturnvoucher-' . $id . '.'.$image_type;
        $file = $folderPath . $file_name;
        file_put_contents($file, $image_base64);

        $purchase_return->is_signed = 1;
        $purchase_return->signature_path = $file_name;
        $purchase_return->save();

        Session::flash('alert-success','Purchase Return Voucher Signature Uploaded successfully');
        return redirect('/transactions/purchase-return-vouchers');
    }
}
