<?php

namespace App\Http\Controllers;

use App\Branches;
use App\Http\Requests\StoreItemUnitRequest;
use App\Http\Requests\UpdateItemUnitRequest;
use App\ItemUnit;
use Illuminate\Http\Request;
use Illuminate\Database\Eloquent\SoftDeletes;

class ItemunitMasterController extends Controller
{
    use SoftDeletes;

    public function index()
    {
        $itemUnits = ItemUnit::where('branch_id', session()->get('selected_branch'))->orderBy('id', 'desc')->get();
        return view('crusher.itemunit_master.index', compact('itemUnits'));
    }

    public function create()
    {
        return view('crusher.itemunit_master.create');
    }

    function store(StoreItemUnitRequest $request)
    {
        try {
            $validatedData = $request->validated();

            foreach ($validatedData['units'] as $key => $unit) {
                ItemUnit::create(['branch_id'=>session()->get('selected_branch'), 'unit'=>$unit]);
            }


            flash()->addSuccess('Record Created');
            return redirect()->route('crusher.item_units.index');
        } catch (\Throwable $th) {
            flash()->addError($th->getMessage());
            return redirect()->back()->withInput();
        }
    }

    public function edit($itemUnit)
    {
        $itemUnit = ItemUnit::find($itemUnit);
        return view('crusher.itemunit_master.edit', compact('itemUnit'));
    }

    function update(UpdateItemUnitRequest $request, $itemUnit)
    {
        try {
            $validatedData = $request->validated();

            $itemUnit = ItemUnit::find($itemUnit)->update($validatedData);

            flash()->addSuccess('Record Updated');
            return redirect()->route('crusher.item_units.index');
        } catch (\Throwable $th) {
            flash()->addError($th->getMessage());
            return redirect()->back()->withInput();
        }
    }

    public function show($itemUnit)
    {
        $itemUnit = ItemUnit::find($itemUnit);
        return view('crusher.itemunit_master.view', compact('itemUnit'));
    }

    public function softDelete($itemUnit)
    {
        $itemUnit = ItemUnit::findOrFail($itemUnit);
        $itemUnit->delete();
        flash()->addSuccess('Success');
        return redirect()->route('crusher.item_units.index');
    }

    // TRANSFER
    function createTransfer()
    {
        $itemUnits = ItemUnit::where('branch_id', session()->get('selected_branch'))->get();
        $branches = Branches::whereHas('company', function($q){$q->where('user_id', auth()->id());})->where('id','!=',session()->get('selected_branch'))->get();
        return view('crusher.itemunit_master.transfer_create', compact('itemUnits', 'branches'));
    }

    function transfer(Request $request)
    {
        try {
            $validatedData = $request->validate([
                'branch' => 'required|numeric',
                'units' => 'required|array',
                'units.*' => 'required|exists:item_units,id',
            ]);

            foreach ($validatedData['units'] as $key => $unit) {
                $existingUnit = ItemUnit::find($unit);
                ItemUnit::create(['branch_id'=>$validatedData['branch'], 'unit'=>$existingUnit->unit]);
            }


            flash()->addSuccess('Success');
            return redirect()->route('crusher.item_units.index');
        } catch (\Throwable $th) {
            flash()->addError($th->getMessage());
            return redirect()->back()->withInput();
        }
    }
}
