<?php

namespace App\Http\Controllers;
use App\AdminSalesInvoice;
use App\CreditNote;
use Illuminate\Support\Facades\DB;
use Illuminate\Http\Request;

class SalesReportController extends Controller
{
    public function view()
    {
        $selectedBranchId = session('selected_branch');

        $Debits = AdminSalesInvoice::with('account')->addSelect(DB::raw('id, account_id, account_type'), DB::raw('DATE(date) as date'), 'invoice_no', DB::raw('(total_gross_amount) as total_gross_amount'))
            ->where('branch_id', $selectedBranchId)
            ->groupBy(DB::raw('DATE(date)'), 'invoice_no')
            ->orderBy(DB::raw('DATE(date)'))
            ->get();


        $Credits = CreditNote::with('account')->addSelect(DB::raw('id, account_id, account_type'), DB::raw('DATE(date) as date'), 'invoice_no', DB::raw('(total_gross_amount) as total_gross_amount'))
            ->where('branch_id', $selectedBranchId)
            ->groupBy(DB::raw('DATE(date)'), 'invoice_no')
            ->orderBy(DB::raw('DATE(date)'))
            ->get();

        $mergedData = $Debits->concat($Credits);
        $totalDebits = $Debits->sum('total_gross_amount');
        $totalCredits = $Credits->sum('total_gross_amount');
        // dd($totalDebits,$totalCredits);

      
        return view('crusher.reports.sales_report', [
            'mergedData' => $mergedData,
            'totalDebits' => $totalDebits,
            'totalCredits' => $totalCredits,
        ]);
    }
    public function selectSalesReport()
    {
        $selectedBranchId = session('selected_branch');

        $Debits = AdminSalesInvoice::with('account')->addSelect(DB::raw('id, account_id, account_type'), DB::raw('DATE(date) as date'), 'invoice_no', DB::raw('SUM(total_gross_amount) as total_gross_amount'))
            ->where('branch_id', $selectedBranchId)
            ->groupBy(DB::raw('DATE(date)'), 'invoice_no')
            ->orderBy(DB::raw('DATE(date)'))
            ->get();


        $Credits = CreditNote::with('account')->addSelect(DB::raw('id, account_id, account_type'), DB::raw('DATE(date) as date'), 'invoice_no', DB::raw('SUM(total_gross_amount) as total_gross_amount'))
            ->where('branch_id', $selectedBranchId)
            ->groupBy(DB::raw('DATE(date)'), 'invoice_no')
            ->orderBy(DB::raw('DATE(date)'))
            ->get();

        $mergedData = $Debits->concat($Credits);
        // dd($mergedData);
        $totalDebits = $Debits->sum('total_gross_amount');
        $totalCredits = $Credits->sum('total_gross_amount');

        return view('crusher.reports.select-sales-report', [
            'mergedData' => $mergedData,
            'totalDebits' => $totalDebits,
            'totalCredits' => $totalCredits,
        ]);
    }

    public function salesReports(request $request){

        $from_date = $request->from_date;
        $to_date = $request->to_date;

        $SaleInvoice = AdminSalesInvoice::with('account')
            ->where('branch_id', session()->get('selected_branch'))
            ->where('date', '>=', $from_date . ' 00:00:00')
            ->where('date', '<=', $to_date . ' 23:59:59')
            ->groupBy('invoice_no')
            ->select('invoice_no', DB::raw('(total_gross_amount) as total_amount'))
            ->get();

        $CreditNote = CreditNote::with('account')
            ->where('branch_id', session()->get('selected_branch'))
            ->where('date', '>=', $from_date . ' 00:00:00')
            ->where('date', '<=', $to_date . ' 23:59:59')
            ->groupBy('invoice_no')
            ->select('invoice_no', DB::raw('(total_gross_amount) as total_amount'))
            ->get();

        dd([
            'SaleInvoice' => $SaleInvoice->map(function ($item) {
                return [
                    'account' => $item->account->name_of_organisation,
                    'invoice_no' => $item->invoice_no,
                    'total_gross_amount' => $item->total_amount,
                ];
            }),
            'CreditNote' => $CreditNote->map(function ($item) {
                return [
                    'account' => $item->account->name_of_organisation,
                    'invoice_no' => $item->invoice_no,
                    'total_gross_amount' => $item->total_amount,
                ];
            }),
        ]);


}
}
