<?php

namespace App\Http\Controllers\Transaction\CountryLocationWiseTransfer;
use App\Http\Controllers\Controller;
use App\CountryLocationWiseCashTransfer;
use App\CountryLocationWiseCashTransferItem;
use Illuminate\Http\Request;

use Session;
use Auth;
use Carbon\Carbon;
use App\Supplier;
use App\Services\Utils;
use App\Services\Slug;
use App\WareHouse;
use App\Country;
use App\CountryLocationWiseCashTransferItemController;
use App\Currency;
use App\Location;


class CashTransferController extends Controller
{
    protected $utils;
    protected $slug;

    public function __construct(Utils $utils, Slug $slug)
    {
        $this->utils = $utils;
        $this->slug = $slug;
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $user = Auth::user();
        if (!$user->can('country-location-wise-cash-transfer')) {
            abort(403, 'Unauthorized action.');
        }

        $country_location_wise_cash_transfers = CountryLocationWiseCashTransfer::withTrashed()->orderBy('created_at','DESC')->paginate(100);
        return view('user.transactions.country_location_wise_transfer.cash_transfer.index', compact('country_location_wise_cash_transfers'));

    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $user = Auth::user();
        if (!$user->can('country-location-wise-cash-transfer')) {
            abort(403, 'Unauthorized action.');
        }

        $location_id = $this->getLocationId();
        $countries = Country::all();
        $locations = Location::all();
        $latest_country_location_wise_cash_transfers = CountryLocationWiseCashtransfer::where('location_id', $location_id)->withTrashed()->latest()->first();
        if($latest_country_location_wise_cash_transfers){
            $country_location_wise_cash_transfer_no = $latest_country_location_wise_cash_transfers-> country_location_wise_cash_transfers_no + 1;
        }else{
            $country_location_wise_cash_transfer_no = 1;
        }
        $warehouses=WareHouse::all();
        $location = Location::where(['id' => $location_id])->first()->name;
        $country = Location::with('country')->where(['id' => $location_id])->first();

        $country_id = $country->country->id;
        $country = $country->country->name;
        $from_currency = Currency::Where('location_id', $location_id)->first();
        // dd($from_currency->currency_id);
        return view('user.transactions.country_location_wise_transfer.cash_transfer.create',compact('from_currency','warehouses','countries', 'locations', 'country_id', 'country', 'location', 'country_location_wise_cash_transfer_no'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        // dd($request->all());
        $selected_location = $this->utils->getLocation();
        if($selected_location){
           $selected_location = $selected_location;
        }
        else{
            return redirect('/logout');
        }
        $country = Location::with('country')->where(['id' => $selected_location])->first()->country->id;
        // dd($country);
        $country_location_wise_cash_transfer = new CountryLocationWiseCashTransfer();
        $country_location_wise_cash_transfer->location_id = $selected_location;
        $country_location_wise_cash_transfer->country_location_wise_cash_transfer_no= $request->country_location_wise_cash_transfer_no;
        $country_location_wise_cash_transfer->date = $request->date;
        $country_location_wise_cash_transfer->from_country = $country;
        $country_location_wise_cash_transfer->from_location = $selected_location;
        $country_location_wise_cash_transfer->to_country = $request->to_country;
        $country_location_wise_cash_transfer->to_location = $request->to_location;
        $country_location_wise_cash_transfer->save();

        foreach ($request->from_currency_id as $key => $from_currency_id) {
            $country_location_wise_cash_transfer_item = new CountryLocationWiseCashTransferItem();
            // $country_location_wise_cash_transfer_item->location_id = $selected_location;
            $country_location_wise_cash_transfer_item->country_location_wise_cash_transfer_id = $country_location_wise_cash_transfer->id;
            $country_location_wise_cash_transfer_item->from_currency_id = $request->from_currency_id[$key];
            $country_location_wise_cash_transfer_item->from_amount = $request->from_amount[$key];
            $country_location_wise_cash_transfer_item->multiply_divide = $request->multiply_divide[$key];
            $country_location_wise_cash_transfer_item->to_currency_id = $request->to_currency_id[$key];
            $country_location_wise_cash_transfer_item->to_amount = $request->to_amount[$key];
            $country_location_wise_cash_transfer_item->save();
        }

        Session::flash('alert-success','Cash Transfer created successfully');
        return redirect('/transactions/country-location-wise-transfer/cash-transfers');
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\CountryLocationWiseCashTransfer  $countryLocationWiseCashTransfer
     * @return \Illuminate\Http\Response
     */
    public function show(CountryLocationWiseCashTransfer $countryLocationWiseCashTransfer)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\CountryLocationWiseCashTransfer  $countryLocationWiseCashTransfer
     * @return \Illuminate\Http\Response
     */
    public function edit(CountryLocationWiseCashTransfer $countryLocationWiseCashTransfer, $id)
    {
        $user = Auth::user();
        if (!$user->can('edit-country-location-wise-cash-transfer')) {
            abort(403, 'Unauthorized action.');
        }

        $location_id = $this->getLocationId();
        $cash_transfer = CountryLocationWiseCashTransfer::find($id);
        $location = Location::where(['id' => $cash_transfer->location_id])->first()->name;
        $country = Location::with('country')->where(['id' => $cash_transfer->location_id])->first()->country->name;
        $countries = Country::all();
        $locations = Location::all();
        $to_location = Location::where(['id' => $cash_transfer->to_location])->first();
        $from_currency = Currency::Where('location_id', $cash_transfer->location_id)->first();
        $to_currency = Currency::Where('location_id', $to_location->id)->first();
        $cash_transfer_items = CountryLocationWiseCashTransferItem::Where('country_location_wise_cash_transfer_id', $id)->get();
        // dd($cash_transfer);
        return view('user.transactions.country_location_wise_transfer.cash_transfer.edit',compact('to_currency','to_location','cash_transfer', 'countries', 'locations', 'country', 'location', 'cash_transfer_items', 'from_currency'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\CountryLocationWiseCashTransfer  $countryLocationWiseCashTransfer
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        // dd($request->all());
        $selected_location = $this->utils->getLocation();
        if($selected_location){
           $selected_location = $selected_location;
        }
        else{
            return redirect('/logout');
        }
        $country = Location::with('country')->where(['id' => $selected_location])->first()->country->id;
        // dd($country);
        $country_location_wise_cash_transfer = CountryLocationWiseCashTransfer::find($id);
        $country_location_wise_cash_transfer->location_id = $selected_location;
        $country_location_wise_cash_transfer->country_location_wise_cash_transfers_no= $request->country_location_wise_cash_transfer_no;
        $country_location_wise_cash_transfer->date = $request->date;
        $country_location_wise_cash_transfer->from_country = $country;
        $country_location_wise_cash_transfer->from_location = $selected_location;
        $country_location_wise_cash_transfer->to_country = $request->to_country;
        $country_location_wise_cash_transfer->to_location = $request->to_location;
        $country_location_wise_cash_transfer->save();

        CountryLocationWiseCashTransferItem::where('country_location_wise_cash_transfer_id', $id)->forcedelete();

        foreach ($request->from_currency_id as $key => $from_currency_id) {
            $country_location_wise_cash_transfer_item = new CountryLocationWiseCashTransferItem();
            $country_location_wise_cash_transfer_item->location_id = $selected_location;
            $country_location_wise_cash_transfer_item->country_location_wise_cash_transfer_id = $id;
            $country_location_wise_cash_transfer_item->from_currency_id = $request->from_currency_id[$key];
            $country_location_wise_cash_transfer_item->from_amount = $request->from_amount[$key];
            $country_location_wise_cash_transfer_item->multiply_divide = $request->multiply_divide[$key];
            $country_location_wise_cash_transfer_item->to_currency_id = $request->to_currency_id[$key];
            $country_location_wise_cash_transfer_item->to_amount = $request->to_amount[$key];
            $country_location_wise_cash_transfer_item->save();
        }

        Session::flash('alert-success','Cash Transfer Updated successfully');
        return redirect('/transactions/country-location-wise-transfer/cash-transfers');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\CountryLocationWiseCashTransfer  $countryLocationWiseCashTransfer
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $cash_transfer = CountryLocationWiseCashTransfer::find($id);
        $cash_transfer->delete();
        CountryLocationWiseCashTransferItem::where('country_location_wise_cash_transfer_id', $id)->delete();
        Session::flash('alert-success','Cash Transfer Deleted successfully');
        return redirect('/transactions/country-location-wise-transfer/cash-transfers');
    }

    public function softdelete($id)
    {
        $user = Auth::user();
        if (!$user->can('cancel-country-location-wise-cash-transfer')) {
            abort(403, 'Unauthorized action.');
        }

        $country_location_wise_cash_transfer = CountryLocationWiseCashTransfer::Find($id);
        $country_location_wise_cash_transfer->delete();
        $country_location_wise_cash_transfer_item = CountryLocationWiseCashTransferItem::Where('country_location_wise_cash_transfer_id', $id)->get();
        foreach ($country_location_wise_cash_transfer_item as $item) {
            $item->delete();
        }
        Session::flash('alert-success','Country Location Wise Cash Transfer Cancelled successfully');
        return redirect('/transactions/country-location-wise-transfer/cash-transfers');
    }

    public function countryLocationsCash_transfer($country_id){
        $location_id = $this->getLocationId();
        $locations = Location::where('country_id', $country_id)->Where('id', '!=', $location_id)->get();
        $to_warehouse = [];
        foreach ($locations as $location) {
            $to_warehouse[] = Warehouse::where('location_id', $location->id)->first();
        }
        if($locations) {
            return response()->json(['status' => 'success', 'data' => $locations, 'to_warehouse' => $to_warehouse]);
        }else {
            return response()->json(['status' => 'not-found']);
        }
    }
}
