<?php

namespace App\Http\Controllers\Transaction;
use App\Http\Controllers\Controller;
use App\JournalVoucher;
use App\JournalVoucherItem;
use Illuminate\Http\Request;
use DB;
use Auth;
use Session;
use App\Services\Utils;
use App\Services\Slug;
use App\Supplier;
use App\AccountMaster;
use App\AccountMastersAccountsDetail;
use App\AccountMasterTrack;
use App\Currency;
use App\PurchaseSalesTransferStockTrack;

class JournalVoucherController extends Controller
{
    protected $utils;
    protected $slug;

    public function __construct(Utils $utils, Slug $slug)
    {
        $this->utils = $utils;
        $this->slug = $slug;
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $user = Auth::user();
        if (!$user->can('journal-voucher')) {
            abort(403, 'Unauthorized action.');
        }

        $location_id = $this->getLocationId();
        $journal_vouchers = JournalVoucher::withTrashed()->Where('location_id', $location_id)
                            ->orderBy('created_at','DESC')->paginate(100);
        return view('user.transactions.journal_voucher.index', compact('journal_vouchers'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $user = Auth::user();
        if (!$user->can('journal-voucher')) {
            abort(403, 'Unauthorized action.');
        }

        $location_id = $this->getLocationId();
        $latest_voucher = JournalVoucher::where('location_id', $location_id)->withTrashed()->latest()->first();
        if($latest_voucher){
            $invoice_no = $latest_voucher-> voucher_no + 1;
        }else{
            $invoice_no = 1;
        }

        $account_masters = AccountMasterTrack::with(['account_master' => function($q) use ($location_id) {
            $q->where('location_id', $location_id);}])->Where('user_id', auth()->user()->id)->get();
        $currency = Currency::Where('location_id', $location_id)->first();
        return view('user.transactions.journal_voucher.create', compact('currency','invoice_no','account_masters'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        // dd($request->all());
        DB::beginTransaction();

        try {
            $selected_location = $this->utils->getLocation();
            if($selected_location){
            $selected_location = $selected_location;
            }
            else{
                return redirect('/logout');
            }
            $journal_voucher = new JournalVoucher();
            $journal_voucher->location_id = $selected_location;
            $journal_voucher->voucher_no = $request->voucher_no;
            $journal_voucher->date = $request->date;
            $journal_voucher->credit_amount = $request->credit_amount;
            $journal_voucher->debit_amount = $request->debit_amount;
            $journal_voucher->difference = $request->difference;
            $journal_voucher->save();

            foreach ($request->account_id as $key => $account_id) {
                $journal_voucher_item = new JournalVoucherItem();
                // $journal_voucher_item->location_id = $selected_location;
                $journal_voucher_item->journal_voucher_id = $journal_voucher->id;
                $journal_voucher_item->account_name = $request->account_id[$key];
                $journal_voucher_item->debit_credit = $request->debit_credit[$key];
                $journal_voucher_item->amount = $request->amount[$key];
                $journal_voucher_item->narrations = $request->narrations[$key];
                $journal_voucher_item->save();

                $account = new AccountMastersAccountsDetail();
                $account->account_master_id = $request->account_id[$key];
                if ($request->debit_credit[$key] == "debit") {
                    $account->debit = $request->amount[$key];
                    $account->credit = 0;
                }
                elseif ($request->debit_credit[$key] == "credit") {
                    $account->debit = 0;
                    $account->credit = $request->amount[$key];
                }
                $account->date = $request->date;
                $account->voucher_type = "journal";
                $account->voucher_no = $request->voucher_no;
                $account->save();
            }
            DB::commit();
            Session::flash('alert-success','Journal Voucher Created successfully');
            return redirect('/transactions/journal-vouchers');
        }catch(Exception $e) {
            DB::rollback();
            return redirect()->back()->withErrors($e);
        }

    }

    /**
     * Display the specified resource.
     *
     * @param  \App\JournalVoucher  $journalVoucher
     * @return \Illuminate\Http\Response
     */
    public function show(JournalVoucher $journalVoucher)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\JournalVoucher  $journalVoucher
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $user = Auth::user();
        if (!$user->can('edit-journal-voucher')) {
            abort(403, 'Unauthorized action.');
        }

        $location_id = $this->getLocationId();
        $journal_voucher = JournalVoucher::find($id);
        $journal_voucher_items = JournalVoucherItem::Where('journal_voucher_id', $id)->get();
        $currency = Currency::Where('location_id', $location_id)->first();
        $account_masters = AccountMasterTrack::with(['account_master' => function($q) use ($location_id) {
            $q->where('location_id', $location_id);}])->Where('user_id', auth()->user()->id)->get();

        return view('user.transactions.journal_voucher.edit', compact('currency','journal_voucher', 'journal_voucher_items', 'account_masters'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\JournalVoucher  $journalVoucher
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        DB::beginTransaction();

        try {
            $selected_location = $this->utils->getLocation();
            if($selected_location){
            $selected_location = $selected_location;
            }
            else{
                return redirect('/logout');
            }
            $journal_voucher = JournalVoucher::find($id);
            $journal_voucher->location_id = $selected_location;
            $journal_voucher->voucher_no = $request->voucher_no;
            $journal_voucher->date = $request->date;
            $journal_voucher->credit_amount = $request->credit_amount;
            $journal_voucher->debit_amount = $request->debit_amount;
            $journal_voucher->difference = $request->difference;
            $journal_voucher->save();

            // JournalVoucherItem::Where('journal_voucher_id', $id)->forcedelete();
            $journal_items = JournalVoucherItem::Where('journal_voucher_id', $id)->get();
            foreach ($journal_items as $item) {
                $account_master_detail = AccountMastersAccountsDetail::Where('account_master_id', $item->account_name)->Where('voucher_type', "journal")->Where('voucher_no', $request->voucher_no)->first();
                $account_master_detail->forcedelete();

                $item->forcedelete();
            }

            foreach ($request->account_id as $key => $account_id) {
                $journal_voucher_item = new JournalVoucherItem();
                // $journal_voucher_item->location_id = $selected_location;
                $journal_voucher_item->journal_voucher_id = $id;
                $journal_voucher_item->account_name = $request->account_id[$key];
                $journal_voucher_item->debit_credit = $request->debit_credit[$key];
                $journal_voucher_item->amount = $request->amount[$key];
                $journal_voucher_item->narrations = $request->narrations[$key];
                $journal_voucher_item->save();

                $account = new AccountMastersAccountsDetail();
                $account->account_master_id = $request->account_id[$key];
                if ($request->debit_credit[$key] == "debit") {
                    $account->debit = $request->amount[$key];
                    $account->credit = 0;
                }
                elseif ($request->debit_credit[$key] == "credit") {
                    $account->debit = 0;
                    $account->credit = $request->amount[$key];
                }
                $account->date = $request->date;
                $account->voucher_type = "journal";
                $account->voucher_no = $request->voucher_no;
                $account->save();
            }

            DB::commit();
            Session::flash('alert-success','Journal Voucher Updated successfully');
            return redirect('/transactions/journal-vouchers');

        }catch(Exception $e) {
            DB::rollback();
            return redirect()->back()->withErrors($e);
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\JournalVoucher  $journalVoucher
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $journal_voucher = JournalVoucher::find($id);
        $journal_voucher_item = JournalVoucherItem::Where('journal_voucher_id', $journal_voucher->id)->get();
        $journal_voucher->delete();
        foreach ($journal_voucher_item as $item) {
            $item->delete();
        }
        Session::flash('alert-success','Journal Voucher Deleted successfully');
        return redirect('/transactions/journal-vouchers');
    }

    public function softdelete($id)
    {
        $user = Auth::user();
        if (!$user->can('cancel-journal-voucher')) {
            abort(403, 'Unauthorized action.');
        }

        $journal_voucher = JournalVoucher::Find($id);

        $journal_voucher_items = JournalVoucherItem::where('branch_id', session()->get('selected_branch'))->Where('journal_voucher_id', $id)->get();
        foreach ($journal_voucher_items as $item) {
            $account_master_detail = AccountMastersAccountsDetail::Where('account_master_id', $item->account_name)->Where('voucher_type', "journal")->Where('voucher_no', $journal_voucher->voucher_no)->first();
            $account_master_detail->delete();
            $item->delete();
        }
        $journal_voucher->delete();
        Session::flash('alert-success','Journal Vouchers Cancelled successfully');
        return redirect('/transactions/journal-vouchers');
    }
}
